@@ -5,8 +5,8 @@ import attr
 
 if TYPE_CHECKING:
     # pylint: disable=unused-import
-    from homeassistant.helpers import entity_registry as ent_reg  # noqa
-    from homeassistant.helpers import device_registry as dev_reg  # noqa
+    from homeassistant.helpers import entity_registry as ent_reg  # noqa: F401
+    from homeassistant.helpers import device_registry as dev_reg  # noqa: F401
 
 
 @attr.s(slots=True)
