@@ -1,6 +1,4 @@
 """Support for Abode Security System alarm control panels."""
-import logging
-
 import homeassistant.components.alarm_control_panel as alarm
 from homeassistant.components.alarm_control_panel.const import (
     SUPPORT_ALARM_ARM_AWAY,
@@ -16,16 +14,9 @@ from homeassistant.const import (
 from . import AbodeDevice
 from .const import ATTRIBUTION, DOMAIN
 
-_LOGGER = logging.getLogger(__name__)
-
 ICON = "mdi:security"
 
 
-async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
-    """Platform uses config entry setup."""
-    pass
-
-
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up Abode alarm control panel device."""
     data = hass.data[DOMAIN]
@@ -55,6 +46,11 @@ class AbodeAlarm(AbodeDevice, alarm.AlarmControlPanel):
             state = None
         return state
 
+    @property
+    def code_arm_required(self):
+        """Whether the code is required for arm actions."""
+        return False
+
     @property
     def supported_features(self) -> int:
         """Return the list of supported features."""
