@@ -10,8 +10,11 @@ from homeassistant.config_entries import SOURCE_IMPORT
 from homeassistant.const import (
     ATTR_LOCATION,
     ATTR_NAME,
+    CONCENTRATION_PARTS_PER_MILLION,
     CONF_API_KEY,
     EVENT_HOMEASSISTANT_STOP,
+    SPEED_MILES_PER_HOUR,
+    UNIT_PERCENTAGE,
 )
 from homeassistant.core import callback
 from homeassistant.exceptions import ConfigEntryNotReady
@@ -23,14 +26,12 @@ from homeassistant.helpers.dispatcher import (
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.event import async_call_later
 
-from .config_flow import configured_instances
 from .const import (
     ATTR_LAST_DATA,
     ATTR_MONITORED_CONDITIONS,
     CONF_APP_KEY,
     DATA_CLIENT,
     DOMAIN,
-    TOPIC_UPDATE,
     TYPE_BINARY_SENSOR,
     TYPE_SENSOR,
 )
@@ -148,26 +149,26 @@ SENSOR_TYPES = {
     TYPE_BATT8: ("Battery 8", None, TYPE_BINARY_SENSOR, "battery"),
     TYPE_BATT9: ("Battery 9", None, TYPE_BINARY_SENSOR, "battery"),
     TYPE_BATTOUT: ("Battery", None, TYPE_BINARY_SENSOR, "battery"),
-    TYPE_CO2: ("co2", "ppm", TYPE_SENSOR, None),
+    TYPE_CO2: ("co2", CONCENTRATION_PARTS_PER_MILLION, TYPE_SENSOR, None),
     TYPE_DAILYRAININ: ("Daily Rain", "in", TYPE_SENSOR, None),
     TYPE_DEWPOINT: ("Dew Point", "°F", TYPE_SENSOR, "temperature"),
     TYPE_EVENTRAININ: ("Event Rain", "in", TYPE_SENSOR, None),
     TYPE_FEELSLIKE: ("Feels Like", "°F", TYPE_SENSOR, "temperature"),
     TYPE_HOURLYRAININ: ("Hourly Rain Rate", "in/hr", TYPE_SENSOR, None),
-    TYPE_HUMIDITY10: ("Humidity 10", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY1: ("Humidity 1", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY2: ("Humidity 2", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY3: ("Humidity 3", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY4: ("Humidity 4", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY5: ("Humidity 5", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY6: ("Humidity 6", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY7: ("Humidity 7", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY8: ("Humidity 8", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY9: ("Humidity 9", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITY: ("Humidity", "%", TYPE_SENSOR, "humidity"),
-    TYPE_HUMIDITYIN: ("Humidity In", "%", TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY10: ("Humidity 10", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY1: ("Humidity 1", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY2: ("Humidity 2", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY3: ("Humidity 3", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY4: ("Humidity 4", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY5: ("Humidity 5", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY6: ("Humidity 6", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY7: ("Humidity 7", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY8: ("Humidity 8", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY9: ("Humidity 9", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITY: ("Humidity", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_HUMIDITYIN: ("Humidity In", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
     TYPE_LASTRAIN: ("Last Rain", None, TYPE_SENSOR, "timestamp"),
-    TYPE_MAXDAILYGUST: ("Max Gust", "mph", TYPE_SENSOR, None),
+    TYPE_MAXDAILYGUST: ("Max Gust", SPEED_MILES_PER_HOUR, TYPE_SENSOR, None),
     TYPE_MONTHLYRAININ: ("Monthly Rain", "in", TYPE_SENSOR, None),
     TYPE_RELAY10: ("Relay 10", None, TYPE_BINARY_SENSOR, "connectivity"),
     TYPE_RELAY1: ("Relay 1", None, TYPE_BINARY_SENSOR, "connectivity"),
@@ -179,16 +180,16 @@ SENSOR_TYPES = {
     TYPE_RELAY7: ("Relay 7", None, TYPE_BINARY_SENSOR, "connectivity"),
     TYPE_RELAY8: ("Relay 8", None, TYPE_BINARY_SENSOR, "connectivity"),
     TYPE_RELAY9: ("Relay 9", None, TYPE_BINARY_SENSOR, "connectivity"),
-    TYPE_SOILHUM10: ("Soil Humidity 10", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM1: ("Soil Humidity 1", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM2: ("Soil Humidity 2", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM3: ("Soil Humidity 3", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM4: ("Soil Humidity 4", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM5: ("Soil Humidity 5", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM6: ("Soil Humidity 6", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM7: ("Soil Humidity 7", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM8: ("Soil Humidity 8", "%", TYPE_SENSOR, "humidity"),
-    TYPE_SOILHUM9: ("Soil Humidity 9", "%", TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM10: ("Soil Humidity 10", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM1: ("Soil Humidity 1", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM2: ("Soil Humidity 2", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM3: ("Soil Humidity 3", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM4: ("Soil Humidity 4", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM5: ("Soil Humidity 5", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM6: ("Soil Humidity 6", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM7: ("Soil Humidity 7", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM8: ("Soil Humidity 8", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
+    TYPE_SOILHUM9: ("Soil Humidity 9", UNIT_PERCENTAGE, TYPE_SENSOR, "humidity"),
     TYPE_SOILTEMP10F: ("Soil Temp 10", "°F", TYPE_SENSOR, "temperature"),
     TYPE_SOILTEMP1F: ("Soil Temp 1", "°F", TYPE_SENSOR, "temperature"),
     TYPE_SOILTEMP2F: ("Soil Temp 2", "°F", TYPE_SENSOR, "temperature"),
@@ -218,12 +219,12 @@ SENSOR_TYPES = {
     TYPE_WEEKLYRAININ: ("Weekly Rain", "in", TYPE_SENSOR, None),
     TYPE_WINDDIR: ("Wind Dir", "°", TYPE_SENSOR, None),
     TYPE_WINDDIR_AVG10M: ("Wind Dir Avg 10m", "°", TYPE_SENSOR, None),
-    TYPE_WINDDIR_AVG2M: ("Wind Dir Avg 2m", "mph", TYPE_SENSOR, None),
+    TYPE_WINDDIR_AVG2M: ("Wind Dir Avg 2m", SPEED_MILES_PER_HOUR, TYPE_SENSOR, None),
     TYPE_WINDGUSTDIR: ("Gust Dir", "°", TYPE_SENSOR, None),
-    TYPE_WINDGUSTMPH: ("Wind Gust", "mph", TYPE_SENSOR, None),
-    TYPE_WINDSPDMPH_AVG10M: ("Wind Avg 10m", "mph", TYPE_SENSOR, None),
-    TYPE_WINDSPDMPH_AVG2M: ("Wind Avg 2m", "mph", TYPE_SENSOR, None),
-    TYPE_WINDSPEEDMPH: ("Wind Speed", "mph", TYPE_SENSOR, None),
+    TYPE_WINDGUSTMPH: ("Wind Gust", SPEED_MILES_PER_HOUR, TYPE_SENSOR, None),
+    TYPE_WINDSPDMPH_AVG10M: ("Wind Avg 10m", SPEED_MILES_PER_HOUR, TYPE_SENSOR, None),
+    TYPE_WINDSPDMPH_AVG2M: ("Wind Avg 2m", SPEED_MILES_PER_HOUR, TYPE_SENSOR, None),
+    TYPE_WINDSPEEDMPH: ("Wind Speed", SPEED_MILES_PER_HOUR, TYPE_SENSOR, None),
     TYPE_YEARLYRAININ: ("Yearly Rain", "in", TYPE_SENSOR, None),
 }
 
@@ -253,9 +254,6 @@ async def async_setup(hass, config):
     # Store config for use during entry setup:
     hass.data[DOMAIN][DATA_CONFIG] = conf
 
-    if conf[CONF_APP_KEY] in configured_instances(hass):
-        return True
-
     hass.async_create_task(
         hass.config_entries.flow.async_init(
             DOMAIN,
@@ -269,6 +267,11 @@ async def async_setup(hass, config):
 
 async def async_setup_entry(hass, config_entry):
     """Set up the Ambient PWS as config entry."""
+    if not config_entry.unique_id:
+        hass.config_entries.async_update_entry(
+            config_entry, unique_id=config_entry.data[CONF_APP_KEY]
+        )
+
     session = aiohttp_client.async_get_clientsession(hass)
 
     try:
@@ -378,7 +381,9 @@ class AmbientStation:
             if data != self.stations[mac_address][ATTR_LAST_DATA]:
                 _LOGGER.debug("New data received: %s", data)
                 self.stations[mac_address][ATTR_LAST_DATA] = data
-                async_dispatcher_send(self._hass, TOPIC_UPDATE)
+                async_dispatcher_send(
+                    self._hass, f"ambient_station_data_update_{mac_address}"
+                )
 
             _LOGGER.debug("Resetting watchdog")
             self._watchdog_listener()
@@ -518,7 +523,7 @@ class AmbientWeatherEntity(Entity):
             self.async_schedule_update_ha_state(True)
 
         self._async_unsub_dispatcher_connect = async_dispatcher_connect(
-            self.hass, TOPIC_UPDATE, update
+            self.hass, f"ambient_station_data_update_{self._mac_address}", update
         )
 
     async def async_will_remove_from_hass(self):
