@@ -6,6 +6,9 @@ DEVICES = "devices"
 
 BINARY_SENSOR_SCAN_INTERVAL_SECS = 5
 CAMERA_WEB_SESSION_TIMEOUT = 10
+COMM_RETRIES = 1
+COMM_TIMEOUT = 6.05
 SENSOR_SCAN_INTERVAL_SECS = 10
+SNAPSHOT_TIMEOUT = 20
 
 SERVICE_UPDATE = "update"
