@@ -4,7 +4,7 @@ import logging
 import voluptuous as vol
 
 from homeassistant.components import arduino
-from homeassistant.components.switch import SwitchDevice, PLATFORM_SCHEMA
+from homeassistant.components.switch import PLATFORM_SCHEMA, SwitchDevice
 from homeassistant.const import CONF_NAME
 import homeassistant.helpers.config_validation as cv
 
