@@ -6,10 +6,12 @@ import voluptuous as vol
 from homeassistant.components.sensor import PLATFORM_SCHEMA
 from homeassistant.const import (
     ATTR_ATTRIBUTION,
+    CONCENTRATION_PARTS_PER_MILLION,
     CONF_MONITORED_CONDITIONS,
     DEVICE_CLASS_HUMIDITY,
     DEVICE_CLASS_TEMPERATURE,
     TEMP_CELSIUS,
+    UNIT_PERCENTAGE,
 )
 from homeassistant.core import callback
 import homeassistant.helpers.config_validation as cv
@@ -26,11 +28,11 @@ SENSOR_TYPES = {
     "last_capture": ["Last", None, "run-fast"],
     "total_cameras": ["Arlo Cameras", None, "video"],
     "captured_today": ["Captured Today", None, "file-video"],
-    "battery_level": ["Battery Level", "%", "battery-50"],
+    "battery_level": ["Battery Level", UNIT_PERCENTAGE, "battery-50"],
     "signal_strength": ["Signal Strength", None, "signal"],
     "temperature": ["Temperature", TEMP_CELSIUS, "thermometer"],
-    "humidity": ["Humidity", "%", "water-percent"],
-    "air_quality": ["Air Quality", "ppm", "biohazard"],
+    "humidity": ["Humidity", UNIT_PERCENTAGE, "water-percent"],
+    "air_quality": ["Air Quality", CONCENTRATION_PARTS_PER_MILLION, "biohazard"],
 }
 
 PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
@@ -57,7 +59,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
                 if sensor_type in ("temperature", "humidity", "air_quality"):
                     continue
 
-                name = "{0} {1}".format(SENSOR_TYPES[sensor_type][0], camera.name)
+                name = f"{SENSOR_TYPES[sensor_type][0]} {camera.name}"
                 sensors.append(ArloSensor(name, camera, sensor_type))
 
             for base_station in arlo.base_stations:
@@ -65,9 +67,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
                     sensor_type in ("temperature", "humidity", "air_quality")
                     and base_station.model_id == "ABC1000"
                 ):
-                    name = "{0} {1}".format(
-                        SENSOR_TYPES[sensor_type][0], base_station.name
-                    )
+                    name = f"{SENSOR_TYPES[sensor_type][0]} {base_station.name}"
                     sensors.append(ArloSensor(name, base_station, sensor_type))
 
     add_entities(sensors, True)
@@ -83,7 +83,7 @@ class ArloSensor(Entity):
         self._data = device
         self._sensor_type = sensor_type
         self._state = None
-        self._icon = "mdi:{}".format(SENSOR_TYPES.get(self._sensor_type)[2])
+        self._icon = f"mdi:{SENSOR_TYPES.get(self._sensor_type)[2]}"
 
     @property
     def name(self):
@@ -141,8 +141,9 @@ class ArloSensor(Entity):
                 video = self._data.last_video
                 self._state = video.created_at_pretty("%m-%d-%Y %H:%M:%S")
             except (AttributeError, IndexError):
-                error_msg = "Video not found for {0}. Older than {1} days?".format(
-                    self.name, self._data.min_days_vdo_cache
+                error_msg = (
+                    f"Video not found for {self.name}. "
+                    f"Older than {self._data.min_days_vdo_cache} days?"
                 )
                 _LOGGER.debug(error_msg)
                 self._state = None
