@@ -17,6 +17,8 @@ from homeassistant.helpers.discovery import async_load_platform
 
 _LOGGER = logging.getLogger(__name__)
 
+CONF_DNSMASQ = "dnsmasq"
+CONF_INTERFACE = "interface"
 CONF_PUB_KEY = "pub_key"
 CONF_REQUIRE_IP = "require_ip"
 CONF_SENSORS = "sensors"
@@ -24,7 +26,10 @@ CONF_SSH_KEY = "ssh_key"
 
 DOMAIN = "asuswrt"
 DATA_ASUSWRT = DOMAIN
+
 DEFAULT_SSH_PORT = 22
+DEFAULT_INTERFACE = "eth0"
+DEFAULT_DNSMASQ = "/var/lib/misc"
 
 SECRET_GROUP = "Password or SSH Key"
 SENSOR_TYPES = ["upload_speed", "download_speed", "download", "upload"]
@@ -45,6 +50,8 @@ CONFIG_SCHEMA = vol.Schema(
                 vol.Optional(CONF_SENSORS): vol.All(
                     cv.ensure_list, [vol.In(SENSOR_TYPES)]
                 ),
+                vol.Optional(CONF_INTERFACE, default=DEFAULT_INTERFACE): cv.string,
+                vol.Optional(CONF_DNSMASQ, default=DEFAULT_DNSMASQ): cv.isdir,
             }
         )
     },
@@ -59,18 +66,20 @@ async def async_setup(hass, config):
 
     api = AsusWrt(
         conf[CONF_HOST],
-        conf.get(CONF_PORT),
-        conf.get(CONF_PROTOCOL) == "telnet",
+        conf[CONF_PORT],
+        conf[CONF_PROTOCOL] == "telnet",
         conf[CONF_USERNAME],
         conf.get(CONF_PASSWORD, ""),
         conf.get("ssh_key", conf.get("pub_key", "")),
-        conf.get(CONF_MODE),
-        conf.get(CONF_REQUIRE_IP),
+        conf[CONF_MODE],
+        conf[CONF_REQUIRE_IP],
+        interface=conf[CONF_INTERFACE],
+        dnsmasq=conf[CONF_DNSMASQ],
     )
 
     await api.connection.async_connect()
     if not api.is_connected:
-        _LOGGER.error("Unable to setup asuswrt component")
+        _LOGGER.error("Unable to setup component")
         return False
 
     hass.data[DATA_ASUSWRT] = api
