@@ -1,17 +1,18 @@
 """Allow to set up simple automation rules via the config file."""
-import asyncio
-from functools import partial
 import importlib
 import logging
-from typing import Any, Awaitable, Callable
+from typing import Any, Awaitable, Callable, List, Optional, Set
 
 import voluptuous as vol
 
 from homeassistant.const import (
     ATTR_ENTITY_ID,
     ATTR_NAME,
+    CONF_DEVICE_ID,
+    CONF_ENTITY_ID,
     CONF_ID,
     CONF_PLATFORM,
+    CONF_ZONE,
     EVENT_AUTOMATION_TRIGGERED,
     EVENT_HOMEASSISTANT_START,
     SERVICE_RELOAD,
@@ -20,11 +21,10 @@ from homeassistant.const import (
     SERVICE_TURN_ON,
     STATE_ON,
 )
-from homeassistant.core import Context, CoreState, HomeAssistant
+from homeassistant.core import Context, CoreState, HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
 from homeassistant.helpers import condition, extract_domain_configs, script
 import homeassistant.helpers.config_validation as cv
-from homeassistant.helpers.config_validation import make_entity_service_schema
 from homeassistant.helpers.entity import ToggleEntity
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.restore_state import RestoreEntity
@@ -57,7 +57,6 @@ CONDITION_TYPE_AND = "and"
 CONDITION_TYPE_OR = "or"
 
 DEFAULT_CONDITION_TYPE = CONDITION_TYPE_AND
-DEFAULT_HIDE_ENTITY = False
 DEFAULT_INITIAL_STATE = True
 
 ATTR_LAST_TRIGGERED = "last_triggered"
@@ -72,9 +71,7 @@ AutomationActionType = Callable[[HomeAssistant, TemplateVarsType], Awaitable[Non
 def _platform_validator(config):
     """Validate it is a valid platform."""
     try:
-        platform = importlib.import_module(
-            ".{}".format(config[CONF_PLATFORM]), __name__
-        )
+        platform = importlib.import_module(f".{config[CONF_PLATFORM]}", __name__)
     except ImportError:
         raise vol.Invalid("Invalid platform specified") from None
 
@@ -93,29 +90,23 @@ _TRIGGER_SCHEMA = vol.All(
 
 _CONDITION_SCHEMA = vol.All(cv.ensure_list, [cv.CONDITION_SCHEMA])
 
-PLATFORM_SCHEMA = vol.Schema(
-    {
-        # str on purpose
-        CONF_ID: str,
-        CONF_ALIAS: cv.string,
-        vol.Optional(CONF_DESCRIPTION): cv.string,
-        vol.Optional(CONF_INITIAL_STATE): cv.boolean,
-        vol.Optional(CONF_HIDE_ENTITY, default=DEFAULT_HIDE_ENTITY): cv.boolean,
-        vol.Required(CONF_TRIGGER): _TRIGGER_SCHEMA,
-        vol.Optional(CONF_CONDITION): _CONDITION_SCHEMA,
-        vol.Required(CONF_ACTION): cv.SCRIPT_SCHEMA,
-    }
+PLATFORM_SCHEMA = vol.All(
+    cv.deprecated(CONF_HIDE_ENTITY, invalidation_version="0.110"),
+    vol.Schema(
+        {
+            # str on purpose
+            CONF_ID: str,
+            CONF_ALIAS: cv.string,
+            vol.Optional(CONF_DESCRIPTION): cv.string,
+            vol.Optional(CONF_INITIAL_STATE): cv.boolean,
+            vol.Optional(CONF_HIDE_ENTITY): cv.boolean,
+            vol.Required(CONF_TRIGGER): _TRIGGER_SCHEMA,
+            vol.Optional(CONF_CONDITION): _CONDITION_SCHEMA,
+            vol.Required(CONF_ACTION): cv.SCRIPT_SCHEMA,
+        }
+    ),
 )
 
-TRIGGER_SERVICE_SCHEMA = make_entity_service_schema(
-    {
-        vol.Optional(ATTR_VARIABLES, default={}): dict,
-        vol.Optional(CONF_SKIP_CONDITION, default=True): bool,
-    }
-)
-
-RELOAD_SERVICE_SCHEMA = vol.Schema({})
-
 
 @bind_hass
 def is_on(hass, entity_id):
@@ -127,48 +118,97 @@ def is_on(hass, entity_id):
     return hass.states.is_state(entity_id, STATE_ON)
 
 
+@callback
+def automations_with_entity(hass: HomeAssistant, entity_id: str) -> List[str]:
+    """Return all automations that reference the entity."""
+    if DOMAIN not in hass.data:
+        return []
+
+    component = hass.data[DOMAIN]
+
+    results = []
+
+    for automation_entity in component.entities:
+        if entity_id in automation_entity.referenced_entities:
+            results.append(automation_entity.entity_id)
+
+    return results
+
+
+@callback
+def entities_in_automation(hass: HomeAssistant, entity_id: str) -> List[str]:
+    """Return all entities in a scene."""
+    if DOMAIN not in hass.data:
+        return []
+
+    component = hass.data[DOMAIN]
+
+    automation_entity = component.get_entity(entity_id)
+
+    if automation_entity is None:
+        return []
+
+    return list(automation_entity.referenced_entities)
+
+
+@callback
+def automations_with_device(hass: HomeAssistant, device_id: str) -> List[str]:
+    """Return all automations that reference the device."""
+    if DOMAIN not in hass.data:
+        return []
+
+    component = hass.data[DOMAIN]
+
+    results = []
+
+    for automation_entity in component.entities:
+        if device_id in automation_entity.referenced_devices:
+            results.append(automation_entity.entity_id)
+
+    return results
+
+
+@callback
+def devices_in_automation(hass: HomeAssistant, entity_id: str) -> List[str]:
+    """Return all devices in a scene."""
+    if DOMAIN not in hass.data:
+        return []
+
+    component = hass.data[DOMAIN]
+
+    automation_entity = component.get_entity(entity_id)
+
+    if automation_entity is None:
+        return []
+
+    return list(automation_entity.referenced_devices)
+
+
 async def async_setup(hass, config):
     """Set up the automation."""
-    component = EntityComponent(_LOGGER, DOMAIN, hass)
+    hass.data[DOMAIN] = component = EntityComponent(_LOGGER, DOMAIN, hass)
 
     await _async_process_config(hass, config, component)
 
-    async def trigger_service_handler(service_call):
+    async def trigger_service_handler(entity, service_call):
         """Handle automation triggers."""
-        tasks = []
-        for entity in await component.async_extract_from_service(service_call):
-            tasks.append(
-                entity.async_trigger(
-                    service_call.data[ATTR_VARIABLES],
-                    skip_condition=service_call.data[CONF_SKIP_CONDITION],
-                    context=service_call.context,
-                )
-            )
+        await entity.async_trigger(
+            service_call.data[ATTR_VARIABLES],
+            skip_condition=service_call.data[CONF_SKIP_CONDITION],
+            context=service_call.context,
+        )
 
-        if tasks:
-            await asyncio.wait(tasks)
-
-    async def turn_onoff_service_handler(service_call):
-        """Handle automation turn on/off service calls."""
-        tasks = []
-        method = f"async_{service_call.service}"
-        for entity in await component.async_extract_from_service(service_call):
-            tasks.append(getattr(entity, method)())
-
-        if tasks:
-            await asyncio.wait(tasks)
-
-    async def toggle_service_handler(service_call):
-        """Handle automation toggle service calls."""
-        tasks = []
-        for entity in await component.async_extract_from_service(service_call):
-            if entity.is_on:
-                tasks.append(entity.async_turn_off())
-            else:
-                tasks.append(entity.async_turn_on())
-
-        if tasks:
-            await asyncio.wait(tasks)
+    component.async_register_entity_service(
+        SERVICE_TRIGGER,
+        {
+            vol.Optional(ATTR_VARIABLES, default={}): dict,
+            vol.Optional(CONF_SKIP_CONDITION, default=True): bool,
+        },
+        trigger_service_handler,
+    )
+    component.async_register_entity_service(SERVICE_TOGGLE, {}, "async_toggle")
+    component.async_register_entity_service(SERVICE_TURN_ON, {}, "async_turn_on")
+    component.async_register_entity_service(SERVICE_TURN_OFF, {}, "async_turn_off")
 
     async def reload_service_handler(service_call):
         """Remove all automations and load new ones from config."""
@@ -177,33 +217,10 @@ async def async_setup(hass, config):
             return
         await _async_process_config(hass, conf, component)
 
-    hass.services.async_register(
-        DOMAIN, SERVICE_TRIGGER, trigger_service_handler, schema=TRIGGER_SERVICE_SCHEMA
-    )
-
     async_register_admin_service(
-        hass,
-        DOMAIN,
-        SERVICE_RELOAD,
-        reload_service_handler,
-        schema=RELOAD_SERVICE_SCHEMA,
+        hass, DOMAIN, SERVICE_RELOAD, reload_service_handler, schema=vol.Schema({})
     )
 
-    hass.services.async_register(
-        DOMAIN,
-        SERVICE_TOGGLE,
-        toggle_service_handler,
-        schema=make_entity_service_schema({}),
-    )
-
-    for service in (SERVICE_TURN_ON, SERVICE_TURN_OFF):
-        hass.services.async_register(
-            DOMAIN,
-            service,
-            turn_onoff_service_handler,
-            schema=make_entity_service_schema({}),
-        )
-
     return True
 
 
@@ -214,29 +231,34 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
         self,
         automation_id,
         name,
-        async_attach_triggers,
+        trigger_config,
         cond_func,
-        async_action,
-        hidden,
+        action_script,
         initial_state,
     ):
         """Initialize an automation entity."""
         self._id = automation_id
         self._name = name
-        self._async_attach_triggers = async_attach_triggers
+        self._trigger_config = trigger_config
         self._async_detach_triggers = None
         self._cond_func = cond_func
-        self._async_action = async_action
+        self.action_script = action_script
         self._last_triggered = None
-        self._hidden = hidden
         self._initial_state = initial_state
         self._is_enabled = False
+        self._referenced_entities: Optional[Set[str]] = None
+        self._referenced_devices: Optional[Set[str]] = None
 
     @property
     def name(self):
         """Name of the automation."""
         return self._name
 
+    @property
+    def unique_id(self):
+        """Return unique ID."""
+        return self._id
+
     @property
     def should_poll(self):
         """No polling needed for automation entities."""
@@ -247,16 +269,50 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
         """Return the entity state attributes."""
         return {ATTR_LAST_TRIGGERED: self._last_triggered}
 
-    @property
-    def hidden(self) -> bool:
-        """Return True if the automation entity should be hidden from UIs."""
-        return self._hidden
-
     @property
     def is_on(self) -> bool:
         """Return True if entity is on."""
         return self._async_detach_triggers is not None or self._is_enabled
 
+    @property
+    def referenced_devices(self):
+        """Return a set of referenced devices."""
+        if self._referenced_devices is not None:
+            return self._referenced_devices
+
+        referenced = self.action_script.referenced_devices
+
+        if self._cond_func is not None:
+            for conf in self._cond_func.config:
+                referenced |= condition.async_extract_devices(conf)
+
+        for conf in self._trigger_config:
+            device = _trigger_extract_device(conf)
+            if device is not None:
+                referenced.add(device)
+
+        self._referenced_devices = referenced
+        return referenced
+
+    @property
+    def referenced_entities(self):
+        """Return a set of referenced entities."""
+        if self._referenced_entities is not None:
+            return self._referenced_entities
+
+        referenced = self.action_script.referenced_entities
+
+        if self._cond_func is not None:
+            for conf in self._cond_func.config:
+                referenced |= condition.async_extract_entities(conf)
+
+        for conf in self._trigger_config:
+            for entity_id in _trigger_extract_entities(conf):
+                referenced.add(entity_id)
+
+        self._referenced_entities = referenced
+        return referenced
+
     async def async_added_to_hass(self) -> None:
         """Startup with initial state or previous state."""
         await super().async_added_to_hass()
@@ -307,7 +363,11 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
 
         This method is a coroutine.
         """
-        if not skip_condition and not self._cond_func(variables):
+        if (
+            not skip_condition
+            and self._cond_func is not None
+            and not self._cond_func(variables)
+        ):
             return
 
         # Create a new context referring to the old context.
@@ -320,7 +380,14 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
             {ATTR_NAME: self._name, ATTR_ENTITY_ID: self.entity_id},
             context=trigger_context,
         )
-        await self._async_action(self.entity_id, variables, trigger_context)
+
+        _LOGGER.info("Executing %s", self._name)
+
+        try:
+            await self.action_script.async_run(variables, trigger_context)
+        except Exception:  # pylint: disable=broad-except
+            pass
+
         self._last_triggered = utcnow()
         await self.async_update_ha_state()
 
@@ -341,9 +408,7 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
 
         # HomeAssistant is starting up
         if self.hass.state != CoreState.not_running:
-            self._async_detach_triggers = await self._async_attach_triggers(
-                self.async_trigger
-            )
+            self._async_detach_triggers = await self._async_attach_triggers()
             self.async_write_ha_state()
             return
 
@@ -353,9 +418,7 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
             if not self._is_enabled or self._async_detach_triggers is not None:
                 return
 
-            self._async_detach_triggers = await self._async_attach_triggers(
-                self.async_trigger
-            )
+            self._async_detach_triggers = await self._async_attach_triggers()
 
         self.hass.bus.async_listen_once(
             EVENT_HOMEASSISTANT_START, async_enable_automation
@@ -375,6 +438,36 @@ class AutomationEntity(ToggleEntity, RestoreEntity):
 
         self.async_write_ha_state()
 
+    async def _async_attach_triggers(self):
+        """Set up the triggers."""
+        removes = []
+        info = {"name": self._name}
+
+        for conf in self._trigger_config:
+            platform = importlib.import_module(f".{conf[CONF_PLATFORM]}", __name__)
+
+            remove = await platform.async_attach_trigger(
+                self.hass, conf, self.async_trigger, info
+            )
+
+            if not remove:
+                _LOGGER.error("Error setting up trigger %s", self._name)
+                continue
+
+            _LOGGER.info("Initialized trigger %s", self._name)
+            removes.append(remove)
+
+        if not removes:
+            return None
+
+        @callback
+        def remove_triggers():
+            """Remove attached triggers."""
+            for remove in removes:
+                remove()
+
+        return remove_triggers
+
     @property
     def device_state_attributes(self):
         """Return automation attributes."""
@@ -398,10 +491,11 @@ async def _async_process_config(hass, config, component):
             automation_id = config_block.get(CONF_ID)
             name = config_block.get(CONF_ALIAS) or f"{config_key} {list_no}"
 
-            hidden = config_block[CONF_HIDE_ENTITY]
             initial_state = config_block.get(CONF_INITIAL_STATE)
 
-            action = _async_get_action(hass, config_block.get(CONF_ACTION, {}), name)
+            action_script = script.Script(
+                hass, config_block.get(CONF_ACTION, {}), name, logger=_LOGGER
+            )
 
             if CONF_CONDITION in config_block:
                 cond_func = await _async_process_if(hass, config, config_block)
@@ -409,25 +503,14 @@ async def _async_process_config(hass, config, component):
                 if cond_func is None:
                     continue
             else:
+                cond_func = None
 
-                def cond_func(variables):
-                    """Condition will always pass."""
-                    return True
-
-            async_attach_triggers = partial(
-                _async_process_trigger,
-                hass,
-                config,
-                config_block.get(CONF_TRIGGER, []),
-                name,
-            )
             entity = AutomationEntity(
                 automation_id,
                 name,
-                async_attach_triggers,
+                config_block[CONF_TRIGGER],
                 cond_func,
-                action,
-                hidden,
+                action_script,
                 initial_state,
             )
 
@@ -437,27 +520,9 @@ async def _async_process_config(hass, config, component):
         await component.async_add_entities(entities)
 
 
-def _async_get_action(hass, config, name):
-    """Return an action based on a configuration."""
-    script_obj = script.Script(hass, config, name)
-
-    async def action(entity_id, variables, context):
-        """Execute an action."""
-        _LOGGER.info("Executing %s", name)
-
-        try:
-            await script_obj.async_run(variables, context)
-        except Exception as err:  # pylint: disable=broad-except
-            script_obj.async_log_exception(
-                _LOGGER, f"Error while executing automation {entity_id}", err
-            )
-
-    return action
-
-
 async def _async_process_if(hass, config, p_config):
     """Process if checks."""
-    if_configs = p_config.get(CONF_CONDITION)
+    if_configs = p_config[CONF_CONDITION]
 
     checks = []
     for if_config in if_configs:
@@ -471,35 +536,33 @@ async def _async_process_if(hass, config, p_config):
         """AND all conditions."""
         return all(check(hass, variables) for check in checks)
 
+    if_action.config = if_configs
+
     return if_action
 
 
-async def _async_process_trigger(hass, config, trigger_configs, name, action):
-    """Set up the triggers.
-
-    This method is a coroutine.
-    """
-    removes = []
-    info = {"name": name}
-
-    for conf in trigger_configs:
-        platform = importlib.import_module(".{}".format(conf[CONF_PLATFORM]), __name__)
-
-        remove = await platform.async_attach_trigger(hass, conf, action, info)
-
-        if not remove:
-            _LOGGER.error("Error setting up trigger %s", name)
-            continue
-
-        _LOGGER.info("Initialized trigger %s", name)
-        removes.append(remove)
-
-    if not removes:
+@callback
+def _trigger_extract_device(trigger_conf: dict) -> Optional[str]:
+    """Extract devices from a trigger config."""
+    if trigger_conf[CONF_PLATFORM] != "device":
         return None
 
-    def remove_triggers():
-        """Remove attached triggers."""
-        for remove in removes:
-            remove()
+    return trigger_conf[CONF_DEVICE_ID]
 
-    return remove_triggers
+
+@callback
+def _trigger_extract_entities(trigger_conf: dict) -> List[str]:
+    """Extract entities from a trigger config."""
+    if trigger_conf[CONF_PLATFORM] in ("state", "numeric_state"):
+        return trigger_conf[CONF_ENTITY_ID]
+
+    if trigger_conf[CONF_PLATFORM] == "zone":
+        return trigger_conf[CONF_ENTITY_ID] + [trigger_conf[CONF_ZONE]]
+
+    if trigger_conf[CONF_PLATFORM] == "geo_location":
+        return [trigger_conf[CONF_ZONE]]
+
+    if trigger_conf[CONF_PLATFORM] == "sun":
+        return ["sun.sun"]
+
+    return []
