@@ -4,18 +4,18 @@ import logging
 
 import pygatt  # pylint: disable=import-error
 
-from homeassistant.helpers.event import track_point_in_utc_time
+from homeassistant.components.device_tracker.const import (
+    CONF_SCAN_INTERVAL,
+    CONF_TRACK_NEW,
+    SCAN_INTERVAL,
+    SOURCE_TYPE_BLUETOOTH_LE,
+)
 from homeassistant.components.device_tracker.legacy import (
     YAML_DEVICES,
     async_load_config,
 )
-from homeassistant.components.device_tracker.const import (
-    CONF_TRACK_NEW,
-    CONF_SCAN_INTERVAL,
-    SCAN_INTERVAL,
-    SOURCE_TYPE_BLUETOOTH_LE,
-)
 from homeassistant.const import EVENT_HOMEASSISTANT_STOP
+from homeassistant.helpers.event import track_point_in_utc_time
 import homeassistant.util.dt as dt_util
 
 _LOGGER = logging.getLogger(__name__)
@@ -44,23 +44,26 @@ def setup_scanner(hass, config, see, discovery_info=None):
 
     def see_device(address, name, new_device=False):
         """Mark a device as seen."""
-        if new_device:
-            if address in new_devices:
-                _LOGGER.debug("Seen %s %s times", address, new_devices[address])
-                new_devices[address] += 1
-                if new_devices[address] >= MIN_SEEN_NEW:
-                    _LOGGER.debug("Adding %s to tracked devices", address)
-                    devs_to_track.append(address)
-                else:
-                    return
-            else:
-                _LOGGER.debug("Seen %s for the first time", address)
-                new_devices[address] = 1
-                return
-
         if name is not None:
             name = name.strip("\x00")
 
+        if new_device:
+            if address in new_devices:
+                new_devices[address]["seen"] += 1
+                if name:
+                    new_devices[address]["name"] = name
+                else:
+                    name = new_devices[address]["name"]
+                _LOGGER.debug("Seen %s %s times", address, new_devices[address]["seen"])
+                if new_devices[address]["seen"] < MIN_SEEN_NEW:
+                    return
+                _LOGGER.debug("Adding %s to tracked devices", address)
+                devs_to_track.append(address)
+            else:
+                _LOGGER.debug("Seen %s for the first time", address)
+                new_devices[address] = {"seen": 1, "name": name}
+                return
+
         see(
             mac=BLE_PREFIX + address,
             host_name=name,
@@ -77,7 +80,7 @@ def setup_scanner(hass, config, see, discovery_info=None):
 
             devices = {x["address"]: x["name"] for x in devs}
             _LOGGER.debug("Bluetooth LE devices discovered = %s", devices)
-        except RuntimeError as error:
+        except (RuntimeError, pygatt.exceptions.BLEError) as error:
             _LOGGER.error("Error during Bluetooth LE scan: %s", error)
             return {}
         return devices
