@@ -4,9 +4,12 @@ import logging
 from bimmer_connected.state import ChargingState
 
 from homeassistant.const import (
+    ATTR_ATTRIBUTION,
     CONF_UNIT_SYSTEM_IMPERIAL,
     LENGTH_KILOMETERS,
     LENGTH_MILES,
+    TIME_HOURS,
+    UNIT_PERCENTAGE,
     VOLUME_GALLONS,
     VOLUME_LITERS,
 )
@@ -14,6 +17,7 @@ from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.icon import icon_for_battery_level
 
 from . import DOMAIN as BMW_DOMAIN
+from .const import ATTRIBUTION
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -24,10 +28,10 @@ ATTR_TO_HA_METRIC = {
     "remaining_range_fuel": ["mdi:map-marker-distance", LENGTH_KILOMETERS],
     "max_range_electric": ["mdi:map-marker-distance", LENGTH_KILOMETERS],
     "remaining_fuel": ["mdi:gas-station", VOLUME_LITERS],
-    "charging_time_remaining": ["mdi:update", "h"],
+    "charging_time_remaining": ["mdi:update", TIME_HOURS],
     "charging_status": ["mdi:battery-charging", None],
     # No icon as this is dealt with directly as a special case in icon()
-    "charging_level_hv": [None, "%"],
+    "charging_level_hv": [None, UNIT_PERCENTAGE],
 }
 
 ATTR_TO_HA_IMPERIAL = {
@@ -37,10 +41,10 @@ ATTR_TO_HA_IMPERIAL = {
     "remaining_range_fuel": ["mdi:map-marker-distance", LENGTH_MILES],
     "max_range_electric": ["mdi:map-marker-distance", LENGTH_MILES],
     "remaining_fuel": ["mdi:gas-station", VOLUME_GALLONS],
-    "charging_time_remaining": ["mdi:update", "h"],
+    "charging_time_remaining": ["mdi:update", TIME_HOURS],
     "charging_status": ["mdi:battery-charging", None],
     # No icon as this is dealt with directly as a special case in icon()
-    "charging_level_hv": [None, "%"],
+    "charging_level_hv": [None, UNIT_PERCENTAGE],
 }
 
 
@@ -99,7 +103,6 @@ class BMWConnectedDriveSensor(Entity):
     @property
     def icon(self):
         """Icon to use in the frontend, if any."""
-
         vehicle_state = self._vehicle.state
         charging_state = vehicle_state.charging_status in [ChargingState.CHARGING]
 
@@ -128,7 +131,10 @@ class BMWConnectedDriveSensor(Entity):
     @property
     def device_state_attributes(self):
         """Return the state attributes of the sensor."""
-        return {"car": self._vehicle.name}
+        return {
+            "car": self._vehicle.name,
+            ATTR_ATTRIBUTION: ATTRIBUTION,
+        }
 
     def update(self) -> None:
         """Read new state data from the library."""
