@@ -15,14 +15,16 @@ from homeassistant.util import dt as dt_util
 
 CONF_DIMENSION = "dimension"
 CONF_DELTA = "delta"
-
-RADAR_MAP_URL_TEMPLATE = "https://api.buienradar.nl/image/1.0/RadarMapNL?w={w}&h={h}"
+CONF_COUNTRY = "country_code"
 
 _LOG = logging.getLogger(__name__)
 
 # Maximum range according to docs
 DIM_RANGE = vol.All(vol.Coerce(int), vol.Range(min=120, max=700))
 
+# Multiple choice for available Radar Map URL
+SUPPORTED_COUNTRY_CODES = ["NL", "BE"]
+
 PLATFORM_SCHEMA = vol.All(
     PLATFORM_SCHEMA.extend(
         {
@@ -31,6 +33,9 @@ PLATFORM_SCHEMA = vol.All(
                 vol.Coerce(float), vol.Range(min=0)
             ),
             vol.Optional(CONF_NAME, default="Buienradar loop"): cv.string,
+            vol.Optional(CONF_COUNTRY, default="NL"): vol.All(
+                vol.Coerce(str), vol.In(SUPPORTED_COUNTRY_CODES)
+            ),
         }
     )
 )
@@ -41,8 +46,9 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
     dimension = config[CONF_DIMENSION]
     delta = config[CONF_DELTA]
     name = config[CONF_NAME]
+    country = config[CONF_COUNTRY]
 
-    async_add_entities([BuienradarCam(name, dimension, delta)])
+    async_add_entities([BuienradarCam(name, dimension, delta, country)])
 
 
 class BuienradarCam(Camera):
@@ -54,7 +60,7 @@ class BuienradarCam(Camera):
     [0]: https://www.buienradar.nl/overbuienradar/gratis-weerdata
     """
 
-    def __init__(self, name: str, dimension: int, delta: float):
+    def __init__(self, name: str, dimension: int, delta: float, country: str):
         """
         Initialize the component.
 
@@ -70,6 +76,9 @@ class BuienradarCam(Camera):
         # time a cached image stays valid for
         self._delta = delta
 
+        # country location
+        self._country = country
+
         # Condition that guards the loading indicator.
         #
         # Ensures that only one reader can cause an http request at the same
@@ -101,7 +110,10 @@ class BuienradarCam(Camera):
         """Retrieve new radar image and return whether this succeeded."""
         session = async_get_clientsession(self.hass)
 
-        url = RADAR_MAP_URL_TEMPLATE.format(w=self._dimension, h=self._dimension)
+        url = (
+            f"https://api.buienradar.nl/image/1.0/RadarMap{self._country}"
+            f"?w={self._dimension}&h={self._dimension}"
+        )
 
         if self._last_modified:
             headers = {"If-Modified-Since": self._last_modified}
