@@ -27,7 +27,11 @@ from homeassistant.const import (
     CONF_LONGITUDE,
     CONF_MONITORED_CONDITIONS,
     CONF_NAME,
+    IRRADIATION_WATTS_PER_SQUARE_METER,
+    SPEED_KILOMETERS_PER_HOUR,
     TEMP_CELSIUS,
+    TIME_HOURS,
+    UNIT_PERCENTAGE,
 )
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
@@ -64,21 +68,21 @@ SENSOR_TYPES = {
     "symbol": ["Symbol", None, None],
     # new in json api (>1.0.0):
     "feeltemperature": ["Feel temperature", TEMP_CELSIUS, "mdi:thermometer"],
-    "humidity": ["Humidity", "%", "mdi:water-percent"],
+    "humidity": ["Humidity", UNIT_PERCENTAGE, "mdi:water-percent"],
     "temperature": ["Temperature", TEMP_CELSIUS, "mdi:thermometer"],
     "groundtemperature": ["Ground temperature", TEMP_CELSIUS, "mdi:thermometer"],
-    "windspeed": ["Wind speed", "km/h", "mdi:weather-windy"],
+    "windspeed": ["Wind speed", SPEED_KILOMETERS_PER_HOUR, "mdi:weather-windy"],
     "windforce": ["Wind force", "Bft", "mdi:weather-windy"],
     "winddirection": ["Wind direction", None, "mdi:compass-outline"],
     "windazimuth": ["Wind direction azimuth", "°", "mdi:compass-outline"],
     "pressure": ["Pressure", "hPa", "mdi:gauge"],
     "visibility": ["Visibility", "km", None],
-    "windgust": ["Wind gust", "km/h", "mdi:weather-windy"],
-    "precipitation": ["Precipitation", "mm/h", "mdi:weather-pouring"],
-    "irradiance": ["Irradiance", "W/m2", "mdi:sunglasses"],
+    "windgust": ["Wind gust", SPEED_KILOMETERS_PER_HOUR, "mdi:weather-windy"],
+    "precipitation": ["Precipitation", f"mm/{TIME_HOURS}", "mdi:weather-pouring"],
+    "irradiance": ["Irradiance", IRRADIATION_WATTS_PER_SQUARE_METER, "mdi:sunglasses"],
     "precipitation_forecast_average": [
         "Precipitation forecast average",
-        "mm/h",
+        f"mm/{TIME_HOURS}",
         "mdi:weather-pouring",
     ],
     "precipitation_forecast_total": [
@@ -117,26 +121,26 @@ SENSOR_TYPES = {
     "maxrain_3d": ["Maximum rain 3d", "mm", "mdi:weather-pouring"],
     "maxrain_4d": ["Maximum rain 4d", "mm", "mdi:weather-pouring"],
     "maxrain_5d": ["Maximum rain 5d", "mm", "mdi:weather-pouring"],
-    "rainchance_1d": ["Rainchance 1d", "%", "mdi:weather-pouring"],
-    "rainchance_2d": ["Rainchance 2d", "%", "mdi:weather-pouring"],
-    "rainchance_3d": ["Rainchance 3d", "%", "mdi:weather-pouring"],
-    "rainchance_4d": ["Rainchance 4d", "%", "mdi:weather-pouring"],
-    "rainchance_5d": ["Rainchance 5d", "%", "mdi:weather-pouring"],
-    "sunchance_1d": ["Sunchance 1d", "%", "mdi:weather-partly-cloudy"],
-    "sunchance_2d": ["Sunchance 2d", "%", "mdi:weather-partly-cloudy"],
-    "sunchance_3d": ["Sunchance 3d", "%", "mdi:weather-partly-cloudy"],
-    "sunchance_4d": ["Sunchance 4d", "%", "mdi:weather-partly-cloudy"],
-    "sunchance_5d": ["Sunchance 5d", "%", "mdi:weather-partly-cloudy"],
+    "rainchance_1d": ["Rainchance 1d", UNIT_PERCENTAGE, "mdi:weather-pouring"],
+    "rainchance_2d": ["Rainchance 2d", UNIT_PERCENTAGE, "mdi:weather-pouring"],
+    "rainchance_3d": ["Rainchance 3d", UNIT_PERCENTAGE, "mdi:weather-pouring"],
+    "rainchance_4d": ["Rainchance 4d", UNIT_PERCENTAGE, "mdi:weather-pouring"],
+    "rainchance_5d": ["Rainchance 5d", UNIT_PERCENTAGE, "mdi:weather-pouring"],
+    "sunchance_1d": ["Sunchance 1d", UNIT_PERCENTAGE, "mdi:weather-partly-cloudy"],
+    "sunchance_2d": ["Sunchance 2d", UNIT_PERCENTAGE, "mdi:weather-partly-cloudy"],
+    "sunchance_3d": ["Sunchance 3d", UNIT_PERCENTAGE, "mdi:weather-partly-cloudy"],
+    "sunchance_4d": ["Sunchance 4d", UNIT_PERCENTAGE, "mdi:weather-partly-cloudy"],
+    "sunchance_5d": ["Sunchance 5d", UNIT_PERCENTAGE, "mdi:weather-partly-cloudy"],
     "windforce_1d": ["Wind force 1d", "Bft", "mdi:weather-windy"],
     "windforce_2d": ["Wind force 2d", "Bft", "mdi:weather-windy"],
     "windforce_3d": ["Wind force 3d", "Bft", "mdi:weather-windy"],
     "windforce_4d": ["Wind force 4d", "Bft", "mdi:weather-windy"],
     "windforce_5d": ["Wind force 5d", "Bft", "mdi:weather-windy"],
-    "windspeed_1d": ["Wind speed 1d", "km/h", "mdi:weather-windy"],
-    "windspeed_2d": ["Wind speed 2d", "km/h", "mdi:weather-windy"],
-    "windspeed_3d": ["Wind speed 3d", "km/h", "mdi:weather-windy"],
-    "windspeed_4d": ["Wind speed 4d", "km/h", "mdi:weather-windy"],
-    "windspeed_5d": ["Wind speed 5d", "km/h", "mdi:weather-windy"],
+    "windspeed_1d": ["Wind speed 1d", SPEED_KILOMETERS_PER_HOUR, "mdi:weather-windy"],
+    "windspeed_2d": ["Wind speed 2d", SPEED_KILOMETERS_PER_HOUR, "mdi:weather-windy"],
+    "windspeed_3d": ["Wind speed 3d", SPEED_KILOMETERS_PER_HOUR, "mdi:weather-windy"],
+    "windspeed_4d": ["Wind speed 4d", SPEED_KILOMETERS_PER_HOUR, "mdi:weather-windy"],
+    "windspeed_5d": ["Wind speed 5d", SPEED_KILOMETERS_PER_HOUR, "mdi:weather-windy"],
     "winddirection_1d": ["Wind direction 1d", None, "mdi:compass-outline"],
     "winddirection_2d": ["Wind direction 2d", None, "mdi:compass-outline"],
     "winddirection_3d": ["Wind direction 3d", None, "mdi:compass-outline"],
