@@ -6,7 +6,6 @@ import voluptuous as vol
 
 from homeassistant.components.media_player import PLATFORM_SCHEMA, MediaPlayerDevice
 from homeassistant.components.media_player.const import (
-    DOMAIN,
     MEDIA_TYPE_CHANNEL,
     MEDIA_TYPE_EPISODE,
     MEDIA_TYPE_MOVIE,
@@ -31,6 +30,8 @@ from homeassistant.const import (
 )
 import homeassistant.helpers.config_validation as cv
 
+from .const import DOMAIN, SERVICE_SEEK_BACKWARD, SERVICE_SEEK_BY, SERVICE_SEEK_FORWARD
+
 _LOGGER = logging.getLogger(__name__)
 
 DATA_CHANNELS = "channels"
@@ -56,9 +57,6 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
     }
 )
 
-SERVICE_SEEK_FORWARD = "channels_seek_forward"
-SERVICE_SEEK_BACKWARD = "channels_seek_backward"
-SERVICE_SEEK_BY = "channels_seek_by"
 
 # Service call validation schemas
 ATTR_SECONDS = "seconds"
