@@ -54,5 +54,5 @@ class CiscoWebexTeamsNotificationService(BaseNotificationService):
             self.client.messages.create(roomId=self.room, html=f"{title}{message}")
         except ApiError as api_error:
             _LOGGER.error(
-                "Could not send CiscoWebexTeams notification. " "Error: %s", api_error
+                "Could not send CiscoWebexTeams notification. Error: %s", api_error
             )
