@@ -10,7 +10,7 @@ from . import EditKeyBasedConfigView
 async def async_setup(hass):
     """Set up the Group config API."""
 
-    async def hook(hass):
+    async def hook(action, config_key):
         """post_write_hook for Config View that reloads groups."""
         await hass.services.async_call(DOMAIN, SERVICE_RELOAD)
 
