@@ -61,8 +61,8 @@ def setup(hass, config):
             title="Home Assistant",
             text=f"%%% \n **{name}** {message} \n %%%",
             tags=[
-                "entity:{}".format(event.data.get("entity_id")),
-                "domain:{}".format(event.data.get("domain")),
+                f"entity:{event.data.get('entity_id')}",
+                f"domain:{event.data.get('domain')}",
             ],
         )
 
@@ -84,7 +84,7 @@ def setup(hass, config):
 
         for key, value in states.items():
             if isinstance(value, (float, int)):
-                attribute = "{}.{}".format(metric, key.replace(" ", "_"))
+                attribute = f"{metric}.{key.replace(' ', '_')}"
                 statsd.gauge(attribute, value, sample_rate=sample_rate, tags=tags)
 
                 _LOGGER.debug("Sent metric %s: %s (tags: %s)", attribute, value, tags)
