@@ -63,17 +63,6 @@ class DeconzDevice(DeconzBase, Entity):
 
         Daylight is a virtual sensor from deCONZ that should never be enabled by default.
         """
-        if not self.gateway.option_allow_clip_sensor and self._device.type.startswith(
-            "CLIP"
-        ):
-            return False
-
-        if (
-            not self.gateway.option_allow_deconz_groups
-            and self._device.type == "LightGroup"
-        ):
-            return False
-
         if self._device.type == "Daylight":
             return False
 
@@ -81,13 +70,18 @@ class DeconzDevice(DeconzBase, Entity):
 
     async def async_added_to_hass(self):
         """Subscribe to device events."""
-        self._device.register_async_callback(self.async_update_callback)
+        self._device.register_callback(self.async_update_callback)
         self.gateway.deconz_ids[self.entity_id] = self._device.deconz_id
         self.listeners.append(
             async_dispatcher_connect(
                 self.hass, self.gateway.signal_reachable, self.async_update_callback
             )
         )
+        self.listeners.append(
+            async_dispatcher_connect(
+                self.hass, self.gateway.signal_remove_entity, self.async_remove_self
+            )
+        )
 
     async def async_will_remove_from_hass(self) -> None:
         """Disconnect device object when removed."""
@@ -96,6 +90,15 @@ class DeconzDevice(DeconzBase, Entity):
         for unsub_dispatcher in self.listeners:
             unsub_dispatcher()
 
+    async def async_remove_self(self, deconz_ids: list) -> None:
+        """Schedule removal of this entity.
+
+        Called by signal_remove_entity scheduled by async_added_to_hass.
+        """
+        if self._device.deconz_id not in deconz_ids:
+            return
+        await self.async_remove()
+
     @callback
     def async_update_callback(self, force_update=False, ignore_update=False):
         """Update the device's state."""
