@@ -9,24 +9,20 @@ from homeassistant.core import callback
 from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import aiohttp_client
 from homeassistant.helpers.device_registry import CONNECTION_NETWORK_MAC
-from homeassistant.helpers.dispatcher import (
-    async_dispatcher_connect,
-    async_dispatcher_send,
-)
-from homeassistant.helpers.entity_registry import (
-    DISABLED_CONFIG_ENTRY,
-    async_get_registry,
-)
+from homeassistant.helpers.dispatcher import async_dispatcher_send
 
 from .const import (
-    _LOGGER,
     CONF_ALLOW_CLIP_SENSOR,
     CONF_ALLOW_DECONZ_GROUPS,
     CONF_MASTER_GATEWAY,
     DEFAULT_ALLOW_CLIP_SENSOR,
     DEFAULT_ALLOW_DECONZ_GROUPS,
     DOMAIN,
-    NEW_DEVICE,
+    LOGGER,
+    NEW_GROUP,
+    NEW_LIGHT,
+    NEW_SCENE,
+    NEW_SENSOR,
     SUPPORTED_PLATFORMS,
 )
 from .errors import AuthenticationRequired, CannotConnect
@@ -52,6 +48,9 @@ class DeconzGateway:
         self.events = []
         self.listeners = []
 
+        self._current_option_allow_clip_sensor = self.option_allow_clip_sensor
+        self._current_option_allow_deconz_groups = self.option_allow_deconz_groups
+
     @property
     def bridgeid(self) -> str:
         """Return the unique identifier of the gateway."""
@@ -103,7 +102,7 @@ class DeconzGateway:
             raise ConfigEntryNotReady
 
         except Exception as err:  # pylint: disable=broad-except
-            _LOGGER.error("Error connecting with deCONZ gateway: %s", err)
+            LOGGER.error("Error connecting with deCONZ gateway: %s", err)
             return False
 
         for component in SUPPORTED_PLATFORMS:
@@ -115,23 +114,64 @@ class DeconzGateway:
 
         self.api.start()
 
-        self.config_entry.add_update_listener(self.async_new_address)
-        self.config_entry.add_update_listener(self.async_options_updated)
+        self.config_entry.add_update_listener(self.async_config_entry_updated)
 
         return True
 
     @staticmethod
-    async def async_new_address(hass, entry) -> None:
-        """Handle signals of gateway getting new address.
+    async def async_config_entry_updated(hass, entry) -> None:
+        """Handle signals of config entry being updated.
 
-        This is a static method because a class method (bound method),
-        can not be used with weak references.
+        This is a static method because a class method (bound method), can not be used with weak references.
+        Causes for this is either discovery updating host address or config entry options changing.
         """
         gateway = get_gateway_from_config_entry(hass, entry)
         if gateway.api.host != entry.data[CONF_HOST]:
             gateway.api.close()
             gateway.api.host = entry.data[CONF_HOST]
             gateway.api.start()
+            return
+
+        await gateway.options_updated()
+
+    async def options_updated(self):
+        """Manage entities affected by config entry options."""
+        deconz_ids = []
+
+        if self._current_option_allow_clip_sensor != self.option_allow_clip_sensor:
+            self._current_option_allow_clip_sensor = self.option_allow_clip_sensor
+
+            sensors = [
+                sensor
+                for sensor in self.api.sensors.values()
+                if sensor.type.startswith("CLIP")
+            ]
+
+            if self.option_allow_clip_sensor:
+                self.async_add_device_callback(NEW_SENSOR, sensors)
+            else:
+                deconz_ids += [sensor.deconz_id for sensor in sensors]
+
+        if self._current_option_allow_deconz_groups != self.option_allow_deconz_groups:
+            self._current_option_allow_deconz_groups = self.option_allow_deconz_groups
+
+            groups = list(self.api.groups.values())
+
+            if self.option_allow_deconz_groups:
+                self.async_add_device_callback(NEW_GROUP, groups)
+            else:
+                deconz_ids += [group.deconz_id for group in groups]
+
+        if deconz_ids:
+            async_dispatcher_send(self.hass, self.signal_remove_entity, deconz_ids)
+
+        entity_registry = await self.hass.helpers.entity_registry.async_get_registry()
+
+        for entity_id, deconz_id in self.deconz_ids.items():
+            if deconz_id in deconz_ids and entity_registry.async_is_registered(
+                entity_id
+            ):
+                entity_registry.async_remove(entity_id)
 
     @property
     def signal_reachable(self) -> str:
@@ -144,23 +184,21 @@ class DeconzGateway:
         self.available = available
         async_dispatcher_send(self.hass, self.signal_reachable, True)
 
-    @property
-    def signal_options_update(self) -> str:
-        """Event specific per deCONZ entry to signal new options."""
-        return f"deconz-options-{self.bridgeid}"
-
-    @staticmethod
-    async def async_options_updated(hass, entry) -> None:
-        """Triggered by config entry options updates."""
-        gateway = get_gateway_from_config_entry(hass, entry)
-
-        registry = await async_get_registry(hass)
-        async_dispatcher_send(hass, gateway.signal_options_update, registry)
-
     @callback
     def async_signal_new_device(self, device_type) -> str:
         """Gateway specific event to signal new device."""
-        return NEW_DEVICE[device_type].format(self.bridgeid)
+        new_device = {
+            NEW_GROUP: f"deconz_new_group_{self.bridgeid}",
+            NEW_LIGHT: f"deconz_new_light_{self.bridgeid}",
+            NEW_SCENE: f"deconz_new_scene_{self.bridgeid}",
+            NEW_SENSOR: f"deconz_new_sensor_{self.bridgeid}",
+        }
+        return new_device[device_type]
+
+    @property
+    def signal_remove_entity(self) -> str:
+        """Gateway specific event to signal removal of entity."""
+        return f"deconz-remove-{self.bridgeid}"
 
     @callback
     def async_add_device_callback(self, device_type, device) -> None:
@@ -221,44 +259,9 @@ async def get_gateway(
         return deconz
 
     except errors.Unauthorized:
-        _LOGGER.warning("Invalid key for deCONZ at %s", config[CONF_HOST])
+        LOGGER.warning("Invalid key for deCONZ at %s", config[CONF_HOST])
         raise AuthenticationRequired
 
     except (asyncio.TimeoutError, errors.RequestError):
-        _LOGGER.error("Error connecting to deCONZ gateway at %s", config[CONF_HOST])
+        LOGGER.error("Error connecting to deCONZ gateway at %s", config[CONF_HOST])
         raise CannotConnect
-
-
-class DeconzEntityHandler:
-    """Platform entity handler to help with updating disabled by."""
-
-    def __init__(self, gateway) -> None:
-        """Create an entity handler."""
-        self.gateway = gateway
-        self._entities = []
-
-        gateway.listeners.append(
-            async_dispatcher_connect(
-                gateway.hass, gateway.signal_options_update, self.update_entity_registry
-            )
-        )
-
-    @callback
-    def add_entity(self, entity) -> None:
-        """Add a new entity to handler."""
-        self._entities.append(entity)
-
-    @callback
-    def update_entity_registry(self, entity_registry) -> None:
-        """Update entity registry disabled by status."""
-        for entity in self._entities:
-
-            if entity.entity_registry_enabled_default != entity.enabled:
-                disabled_by = None
-
-                if entity.enabled:
-                    disabled_by = DISABLED_CONFIG_ENTRY
-
-                entity_registry.async_update_entity(
-                    entity.registry_entry.entity_id, disabled_by=disabled_by
-                )
