@@ -9,7 +9,12 @@ from pydeconz.sensor import (
     Thermostat,
 )
 
-from homeassistant.const import ATTR_TEMPERATURE, ATTR_VOLTAGE, DEVICE_CLASS_BATTERY
+from homeassistant.const import (
+    ATTR_TEMPERATURE,
+    ATTR_VOLTAGE,
+    DEVICE_CLASS_BATTERY,
+    UNIT_PERCENTAGE,
+)
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import (
     async_dispatcher_connect,
@@ -19,7 +24,7 @@ from homeassistant.helpers.dispatcher import (
 from .const import ATTR_DARK, ATTR_ON, NEW_SENSOR
 from .deconz_device import DeconzDevice
 from .deconz_event import DeconzEvent
-from .gateway import DeconzEntityHandler, get_gateway_from_config_entry
+from .gateway import get_gateway_from_config_entry
 
 ATTR_CURRENT = "current"
 ATTR_POWER = "power"
@@ -37,7 +42,6 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
 
     batteries = set()
     battery_handler = DeconzBatteryHandler(gateway)
-    entity_handler = DeconzEntityHandler(gateway)
 
     @callback
     def async_add_sensor(sensors, new=True):
@@ -65,11 +69,12 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
                 new
                 and sensor.BINARY is False
                 and sensor.type not in Battery.ZHATYPE + Thermostat.ZHATYPE
+                and (
+                    gateway.option_allow_clip_sensor
+                    or not sensor.type.startswith("CLIP")
+                )
             ):
-
-                new_sensor = DeconzSensor(sensor, gateway)
-                entity_handler.add_entity(new_sensor)
-                entities.append(new_sensor)
+                entities.append(DeconzSensor(sensor, gateway))
 
             if sensor.battery is not None:
                 new_battery = DeconzBattery(sensor, gateway)
@@ -194,7 +199,7 @@ class DeconzBattery(DeconzDevice):
     @property
     def unit_of_measurement(self):
         """Return the unit of measurement of this entity."""
-        return "%"
+        return UNIT_PERCENTAGE
 
     @property
     def device_state_attributes(self):
@@ -216,7 +221,7 @@ class DeconzSensorStateTracker:
         """Set up tracker."""
         self.sensor = sensor
         self.gateway = gateway
-        sensor.register_async_callback(self.async_update_callback)
+        sensor.register_callback(self.async_update_callback)
 
     @callback
     def close(self):
