@@ -6,7 +6,8 @@ from homeassistant.components.cover import (
     SUPPORT_OPEN,
     CoverDevice,
 )
-from homeassistant.helpers.event import track_utc_time_change
+from homeassistant.core import callback
+from homeassistant.helpers.event import async_track_utc_time_change
 
 from . import DOMAIN
 
@@ -131,21 +132,21 @@ class DemoCover(CoverDevice):
             return self._supported_features
         return super().supported_features
 
-    def close_cover(self, **kwargs):
+    async def async_close_cover(self, **kwargs):
         """Close the cover."""
         if self._position == 0:
             return
         if self._position is None:
             self._closed = True
-            self.schedule_update_ha_state()
+            self.async_write_ha_state()
             return
 
         self._is_closing = True
         self._listen_cover()
         self._requested_closing = True
-        self.schedule_update_ha_state()
+        self.async_write_ha_state()
 
-    def close_cover_tilt(self, **kwargs):
+    async def async_close_cover_tilt(self, **kwargs):
         """Close the cover tilt."""
         if self._tilt_position in (0, None):
             return
@@ -153,21 +154,21 @@ class DemoCover(CoverDevice):
         self._listen_cover_tilt()
         self._requested_closing_tilt = True
 
-    def open_cover(self, **kwargs):
+    async def async_open_cover(self, **kwargs):
         """Open the cover."""
         if self._position == 100:
             return
         if self._position is None:
             self._closed = False
-            self.schedule_update_ha_state()
+            self.async_write_ha_state()
             return
 
         self._is_opening = True
         self._listen_cover()
         self._requested_closing = False
-        self.schedule_update_ha_state()
+        self.async_write_ha_state()
 
-    def open_cover_tilt(self, **kwargs):
+    async def async_open_cover_tilt(self, **kwargs):
         """Open the cover tilt."""
         if self._tilt_position in (100, None):
             return
@@ -175,7 +176,7 @@ class DemoCover(CoverDevice):
         self._listen_cover_tilt()
         self._requested_closing_tilt = False
 
-    def set_cover_position(self, **kwargs):
+    async def async_set_cover_position(self, **kwargs):
         """Move the cover to a specific position."""
         position = kwargs.get(ATTR_POSITION)
         self._set_position = round(position, -1)
@@ -185,7 +186,7 @@ class DemoCover(CoverDevice):
         self._listen_cover()
         self._requested_closing = position < self._position
 
-    def set_cover_tilt_position(self, **kwargs):
+    async def async_set_cover_tilt_position(self, **kwargs):
         """Move the cover til to a specific position."""
         tilt_position = kwargs.get(ATTR_TILT_POSITION)
         self._set_tilt_position = round(tilt_position, -1)
@@ -195,7 +196,7 @@ class DemoCover(CoverDevice):
         self._listen_cover_tilt()
         self._requested_closing_tilt = tilt_position < self._tilt_position
 
-    def stop_cover(self, **kwargs):
+    async def async_stop_cover(self, **kwargs):
         """Stop the cover."""
         self._is_closing = False
         self._is_opening = False
@@ -206,7 +207,7 @@ class DemoCover(CoverDevice):
             self._unsub_listener_cover = None
             self._set_position = None
 
-    def stop_cover_tilt(self, **kwargs):
+    async def async_stop_cover_tilt(self, **kwargs):
         """Stop the cover tilt."""
         if self._tilt_position is None:
             return
@@ -216,14 +217,15 @@ class DemoCover(CoverDevice):
             self._unsub_listener_cover_tilt = None
             self._set_tilt_position = None
 
+    @callback
     def _listen_cover(self):
         """Listen for changes in cover."""
         if self._unsub_listener_cover is None:
-            self._unsub_listener_cover = track_utc_time_change(
+            self._unsub_listener_cover = async_track_utc_time_change(
                 self.hass, self._time_changed_cover
             )
 
-    def _time_changed_cover(self, now):
+    async def _time_changed_cover(self, now):
         """Track time changes."""
         if self._requested_closing:
             self._position -= 10
@@ -231,20 +233,20 @@ class DemoCover(CoverDevice):
             self._position += 10
 
         if self._position in (100, 0, self._set_position):
-            self.stop_cover()
+            await self.async_stop_cover()
 
         self._closed = self.current_cover_position <= 0
+        self.async_write_ha_state()
 
-        self.schedule_update_ha_state()
-
+    @callback
     def _listen_cover_tilt(self):
         """Listen for changes in cover tilt."""
         if self._unsub_listener_cover_tilt is None:
-            self._unsub_listener_cover_tilt = track_utc_time_change(
+            self._unsub_listener_cover_tilt = async_track_utc_time_change(
                 self.hass, self._time_changed_cover_tilt
             )
 
-    def _time_changed_cover_tilt(self, now):
+    async def _time_changed_cover_tilt(self, now):
         """Track time changes."""
         if self._requested_closing_tilt:
             self._tilt_position -= 10
@@ -252,6 +254,6 @@ class DemoCover(CoverDevice):
             self._tilt_position += 10
 
         if self._tilt_position in (100, 0, self._set_tilt_position):
-            self.stop_cover_tilt()
+            await self.async_stop_cover_tilt()
 
-        self.schedule_update_ha_state()
+        self.async_write_ha_state()
