@@ -78,12 +78,12 @@ DEMO_VACUUM_STATE = "5_Fifth_floor"
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up the Demo config entry."""
-    setup_platform(hass, {}, async_add_entities)
+    await async_setup_platform(hass, {}, async_add_entities)
 
 
-def setup_platform(hass, config, add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the Demo vacuums."""
-    add_entities(
+    async_add_entities(
         [
             DemoVacuum(DEMO_VACUUM_COMPLETE, SUPPORT_ALL_SERVICES),
             DemoVacuum(DEMO_VACUUM_MOST, SUPPORT_MOST_SERVICES),
