@@ -6,6 +6,7 @@ from doorbirdpy import DoorBird
 import voluptuous as vol
 
 from homeassistant.components.http import HomeAssistantView
+from homeassistant.components.logbook import log_entry
 from homeassistant.const import (
     CONF_DEVICES,
     CONF_HOST,
@@ -65,7 +66,7 @@ def setup(hass, config):
         custom_url = doorstation_config.get(CONF_CUSTOM_URL)
         events = doorstation_config.get(CONF_EVENTS)
         token = doorstation_config.get(CONF_TOKEN)
-        name = doorstation_config.get(CONF_NAME) or "DoorBird {}".format(index + 1)
+        name = doorstation_config.get(CONF_NAME) or f"DoorBird {index + 1}"
 
         try:
             device = DoorBird(device_ip, username, password)
@@ -296,4 +297,6 @@ class DoorBirdRequestView(HomeAssistantView):
 
         hass.bus.async_fire(f"{DOMAIN}_{event}", event_data)
 
+        log_entry(hass, f"Doorbird {event}", "event was fired.", DOMAIN)
+
         return web.Response(status=200, text="OK")
