@@ -4,13 +4,15 @@ from homeassistant.components.scene import Scene
 from . import DOMAIN as ELK_DOMAIN, ElkEntity, create_elk_entities
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Create the Elk-M1 scene platform."""
     if discovery_info is None:
         return
-    elk = hass.data[ELK_DOMAIN]['elk']
-    entities = create_elk_entities(hass, elk.tasks, 'task', ElkTask, [])
+    elk_datas = hass.data[ELK_DOMAIN]
+    entities = []
+    for elk_data in elk_datas.values():
+        elk = elk_data["elk"]
+        entities = create_elk_entities(elk_data, elk.tasks, "task", ElkTask, entities)
     async_add_entities(entities, True)
 
 
