@@ -81,12 +81,12 @@ class SmartPlugSwitch(SwitchDevice):
     def update(self):
         """Update the PCA switch's state."""
         try:
-            self._emeter_params[ATTR_CURRENT_POWER_W] = "{:.1f}".format(
-                self._pca.get_current_power(self._device_id)
-            )
-            self._emeter_params[ATTR_TOTAL_ENERGY_KWH] = "{:.2f}".format(
-                self._pca.get_total_consumption(self._device_id)
-            )
+            self._emeter_params[
+                ATTR_CURRENT_POWER_W
+            ] = f"{self._pca.get_current_power(self._device_id):.1f}"
+            self._emeter_params[
+                ATTR_TOTAL_ENERGY_KWH
+            ] = f"{self._pca.get_total_consumption(self._device_id):.2f}"
 
             self._available = True
             self._state = self._pca.get_state(self._device_id)
