@@ -37,7 +37,6 @@ CONF_SENSOR_NAMES = "sensor_names"
 
 DECIMALS = 2
 DEFAULT_UNIT = POWER_WATT
-
 MIN_TIME_BETWEEN_UPDATES = timedelta(seconds=5)
 
 ONLY_INCL_EXCL_NONE = "only_include_exclude_or_none"
@@ -64,9 +63,7 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 
 def get_id(sensorid, feedtag, feedname, feedid, feeduserid):
     """Return unique identifier for feed / sensor."""
-    return "emoncms{}_{}_{}_{}_{}".format(
-        sensorid, feedtag, feedname, feedid, feeduserid
-    )
+    return f"emoncms{sensorid}_{feedtag}_{feedname}_{feedid}_{feeduserid}"
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
@@ -75,7 +72,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     url = config.get(CONF_URL)
     sensorid = config.get(CONF_ID)
     value_template = config.get(CONF_VALUE_TEMPLATE)
-    unit_of_measurement = config.get(CONF_UNIT_OF_MEASUREMENT)
+    config_unit = config.get(CONF_UNIT_OF_MEASUREMENT)
     exclude_feeds = config.get(CONF_EXCLUDE_FEEDID)
     include_only_feeds = config.get(CONF_ONLY_INCLUDE_FEEDID)
     sensor_names = config.get(CONF_SENSOR_NAMES)
@@ -107,6 +104,12 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
         if sensor_names is not None:
             name = sensor_names.get(int(elem["id"]), None)
 
+        unit = elem.get("unit")
+        if unit:
+            unit_of_measurement = unit
+        else:
+            unit_of_measurement = config_unit
+
         sensors.append(
             EmonCmsSensor(
                 hass,
@@ -134,7 +137,7 @@ class EmonCmsSensor(Entity):
             # ID if there's only one.
             id_for_name = "" if str(sensorid) == "1" else sensorid
             # Use the feed name assigned in EmonCMS or fall back to the feed ID
-            feed_name = elem.get("name") or "Feed {}".format(elem["id"])
+            feed_name = elem.get("name") or f"Feed {elem['id']}"
             self._name = f"EmonCMS{id_for_name} {feed_name}"
         else:
             self._name = name
