@@ -1,11 +1,14 @@
 """Support for EnOcean devices."""
 import logging
 
+from enocean.communicators.serialcommunicator import SerialCommunicator
+from enocean.protocol.packet import Packet, RadioPacket
+from enocean.utils import combine_hex
 import voluptuous as vol
 
 from homeassistant.const import CONF_DEVICE
-from homeassistant.helpers.entity import Entity
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.entity import Entity
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -34,7 +37,6 @@ class EnOceanDongle:
 
     def __init__(self, hass, ser):
         """Initialize the EnOcean dongle."""
-        from enocean.communicators.serialcommunicator import SerialCommunicator
 
         self.__communicator = SerialCommunicator(port=ser, callback=self.callback)
         self.__communicator.start()
@@ -53,7 +55,6 @@ class EnOceanDongle:
         This is the callback function called by python-enocan whenever there
         is an incoming packet.
         """
-        from enocean.protocol.packet import RadioPacket
 
         if isinstance(packet, RadioPacket):
             _LOGGER.debug("Received radio packet: %s", packet)
@@ -76,7 +77,6 @@ class EnOceanDevice(Entity):
 
     def _message_received_callback(self, packet):
         """Handle incoming packets."""
-        from enocean.utils import combine_hex
 
         if packet.sender_int == combine_hex(self.dev_id):
             self.value_changed(packet)
@@ -84,10 +84,8 @@ class EnOceanDevice(Entity):
     def value_changed(self, packet):
         """Update the internal state of the device when a packet arrives."""
 
-    # pylint: disable=no-self-use
     def send_command(self, data, optional, packet_type):
         """Send a command via the EnOcean dongle."""
-        from enocean.protocol.packet import Packet
 
         packet = Packet(packet_type, data=data, optional=optional)
         self.hass.helpers.dispatcher.dispatcher_send(SIGNAL_SEND_MESSAGE, packet)
