@@ -47,9 +47,9 @@ class EsphomeCamera(Camera, EsphomeEntity):
     def _state(self) -> Optional[CameraState]:
         return super()._state
 
-    async def _on_update(self) -> None:
+    async def _on_state_update(self) -> None:
         """Notify listeners of new image when update arrives."""
-        await super()._on_update()
+        await super()._on_state_update()
         async with self._image_cond:
             self._image_cond.notify_all()
 
