@@ -1,7 +1,7 @@
 """Support for the Fitbit API."""
-import os
-import logging
 import datetime
+import logging
+import os
 import time
 
 from fitbit import Fitbit
@@ -9,17 +9,23 @@ from fitbit.api import FitbitOauth2Client
 from oauthlib.oauth2.rfc6749.errors import MismatchingStateError, MissingTokenError
 import voluptuous as vol
 
-from homeassistant.core import callback
 from homeassistant.components.http import HomeAssistantView
 from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import ATTR_ATTRIBUTION
-from homeassistant.const import CONF_UNIT_SYSTEM
+from homeassistant.const import (
+    ATTR_ATTRIBUTION,
+    CONF_UNIT_SYSTEM,
+    MASS_KILOGRAMS,
+    MASS_MILLIGRAMS,
+    TIME_MILLISECONDS,
+    TIME_MINUTES,
+    UNIT_PERCENTAGE,
+)
+from homeassistant.core import callback
+import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.icon import icon_for_battery_level
-import homeassistant.helpers.config_validation as cv
 from homeassistant.util.json import load_json, save_json
 
-
 _CONFIGURING = {}
 _LOGGER = logging.getLogger(__name__)
 
@@ -50,14 +56,14 @@ FITBIT_RESOURCES_LIST = {
     "activities/elevation": ["Elevation", "", "walk"],
     "activities/floors": ["Floors", "floors", "walk"],
     "activities/heart": ["Resting Heart Rate", "bpm", "heart-pulse"],
-    "activities/minutesFairlyActive": ["Minutes Fairly Active", "minutes", "walk"],
-    "activities/minutesLightlyActive": ["Minutes Lightly Active", "minutes", "walk"],
+    "activities/minutesFairlyActive": ["Minutes Fairly Active", TIME_MINUTES, "walk"],
+    "activities/minutesLightlyActive": ["Minutes Lightly Active", TIME_MINUTES, "walk"],
     "activities/minutesSedentary": [
         "Minutes Sedentary",
-        "minutes",
+        TIME_MINUTES,
         "seat-recline-normal",
     ],
-    "activities/minutesVeryActive": ["Minutes Very Active", "minutes", "run"],
+    "activities/minutesVeryActive": ["Minutes Very Active", TIME_MINUTES, "run"],
     "activities/steps": ["Steps", "steps", "walk"],
     "activities/tracker/activityCalories": ["Tracker Activity Calories", "cal", "fire"],
     "activities/tracker/calories": ["Tracker Calories", "cal", "fire"],
@@ -66,53 +72,57 @@ FITBIT_RESOURCES_LIST = {
     "activities/tracker/floors": ["Tracker Floors", "floors", "walk"],
     "activities/tracker/minutesFairlyActive": [
         "Tracker Minutes Fairly Active",
-        "minutes",
+        TIME_MINUTES,
         "walk",
     ],
     "activities/tracker/minutesLightlyActive": [
         "Tracker Minutes Lightly Active",
-        "minutes",
+        TIME_MINUTES,
         "walk",
     ],
     "activities/tracker/minutesSedentary": [
         "Tracker Minutes Sedentary",
-        "minutes",
+        TIME_MINUTES,
         "seat-recline-normal",
     ],
     "activities/tracker/minutesVeryActive": [
         "Tracker Minutes Very Active",
-        "minutes",
+        TIME_MINUTES,
         "run",
     ],
     "activities/tracker/steps": ["Tracker Steps", "steps", "walk"],
     "body/bmi": ["BMI", "BMI", "human"],
-    "body/fat": ["Body Fat", "%", "human"],
+    "body/fat": ["Body Fat", UNIT_PERCENTAGE, "human"],
     "body/weight": ["Weight", "", "human"],
     "devices/battery": ["Battery", None, None],
     "sleep/awakeningsCount": ["Awakenings Count", "times awaken", "sleep"],
-    "sleep/efficiency": ["Sleep Efficiency", "%", "sleep"],
-    "sleep/minutesAfterWakeup": ["Minutes After Wakeup", "minutes", "sleep"],
-    "sleep/minutesAsleep": ["Sleep Minutes Asleep", "minutes", "sleep"],
-    "sleep/minutesAwake": ["Sleep Minutes Awake", "minutes", "sleep"],
-    "sleep/minutesToFallAsleep": ["Sleep Minutes to Fall Asleep", "minutes", "sleep"],
+    "sleep/efficiency": ["Sleep Efficiency", UNIT_PERCENTAGE, "sleep"],
+    "sleep/minutesAfterWakeup": ["Minutes After Wakeup", TIME_MINUTES, "sleep"],
+    "sleep/minutesAsleep": ["Sleep Minutes Asleep", TIME_MINUTES, "sleep"],
+    "sleep/minutesAwake": ["Sleep Minutes Awake", TIME_MINUTES, "sleep"],
+    "sleep/minutesToFallAsleep": [
+        "Sleep Minutes to Fall Asleep",
+        TIME_MINUTES,
+        "sleep",
+    ],
     "sleep/startTime": ["Sleep Start Time", None, "clock"],
-    "sleep/timeInBed": ["Sleep Time in Bed", "minutes", "hotel"],
+    "sleep/timeInBed": ["Sleep Time in Bed", TIME_MINUTES, "hotel"],
 }
 
 FITBIT_MEASUREMENTS = {
     "en_US": {
-        "duration": "ms",
+        "duration": TIME_MILLISECONDS,
         "distance": "mi",
         "elevation": "ft",
         "height": "in",
         "weight": "lbs",
         "body": "in",
         "liquids": "fl. oz.",
-        "blood glucose": "mg/dL",
+        "blood glucose": f"{MASS_MILLIGRAMS}/dL",
         "battery": "",
     },
     "en_GB": {
-        "duration": "milliseconds",
+        "duration": TIME_MILLISECONDS,
         "distance": "kilometers",
         "elevation": "meters",
         "height": "centimeters",
@@ -123,11 +133,11 @@ FITBIT_MEASUREMENTS = {
         "battery": "",
     },
     "metric": {
-        "duration": "milliseconds",
+        "duration": TIME_MILLISECONDS,
         "distance": "kilometers",
         "elevation": "meters",
         "height": "centimeters",
-        "weight": "kilograms",
+        "weight": MASS_KILOGRAMS,
         "body": "centimeters",
         "liquids": "milliliters",
         "blood glucose": "mmol/L",
@@ -172,16 +182,14 @@ def request_app_setup(hass, config, add_entities, config_path, discovery_info=No
 
     start_url = f"{hass.config.api.base_url}{FITBIT_AUTH_CALLBACK_PATH}"
 
-    description = """Please create a Fitbit developer app at
+    description = f"""Please create a Fitbit developer app at
                        https://dev.fitbit.com/apps/new.
                        For the OAuth 2.0 Application Type choose Personal.
-                       Set the Callback URL to {}.
+                       Set the Callback URL to {start_url}.
                        They will provide you a Client ID and secret.
-                       These need to be saved into the file located at: {}.
+                       These need to be saved into the file located at: {config_path}.
                        Then come back here and hit the below button.
-                       """.format(
-        start_url, config_path
-    )
+                       """
 
     submit = "I have saved my Client ID and Client Secret into fitbit.conf."
 
@@ -299,9 +307,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
             config_file.get(ATTR_CLIENT_ID), config_file.get(ATTR_CLIENT_SECRET)
         )
 
-        redirect_uri = "{}{}".format(
-            hass.config.api.base_url, FITBIT_AUTH_CALLBACK_PATH
-        )
+        redirect_uri = f"{hass.config.api.base_url}{FITBIT_AUTH_CALLBACK_PATH}"
 
         fitbit_auth_start_url, _ = oauth.authorize_token_url(
             redirect_uri=redirect_uri,
@@ -346,26 +352,20 @@ class FitbitAuthCallbackView(HomeAssistantView):
 
         result = None
         if data.get("code") is not None:
-            redirect_uri = "{}{}".format(
-                hass.config.api.base_url, FITBIT_AUTH_CALLBACK_PATH
-            )
+            redirect_uri = f"{hass.config.api.base_url}{FITBIT_AUTH_CALLBACK_PATH}"
 
             try:
                 result = self.oauth.fetch_access_token(data.get("code"), redirect_uri)
             except MissingTokenError as error:
                 _LOGGER.error("Missing token: %s", error)
-                response_message = """Something went wrong when
+                response_message = f"""Something went wrong when
                 attempting authenticating with Fitbit. The error
-                encountered was {}. Please try again!""".format(
-                    error
-                )
+                encountered was {error}. Please try again!"""
             except MismatchingStateError as error:
                 _LOGGER.error("Mismatched state, CSRF error: %s", error)
-                response_message = """Something went wrong when
+                response_message = f"""Something went wrong when
                 attempting authenticating with Fitbit. The error
-                encountered was {}. Please try again!""".format(
-                    error
-                )
+                encountered was {error}. Please try again!"""
         else:
             _LOGGER.error("Unknown error when authing")
             response_message = """Something went wrong when
@@ -380,10 +380,8 @@ class FitbitAuthCallbackView(HomeAssistantView):
                 An unknown error occurred. Please try again!
                 """
 
-        html_response = """<html><head><title>Fitbit Auth</title></head>
-        <body><h1>{}</h1></body></html>""".format(
-            response_message
-        )
+        html_response = f"""<html><head><title>Fitbit Auth</title></head>
+        <body><h1>{response_message}</h1></body></html>"""
 
         if result:
             config_contents = {
@@ -415,7 +413,7 @@ class FitbitSensor(Entity):
         self.extra = extra
         self._name = FITBIT_RESOURCES_LIST[self.resource_type][0]
         if self.extra:
-            self._name = "{0} Battery".format(self.extra.get("deviceVersion"))
+            self._name = f"{self.extra.get('deviceVersion')} Battery"
         unit_type = FITBIT_RESOURCES_LIST[self.resource_type][1]
         if unit_type == "":
             split_resource = self.resource_type.split("/")
@@ -451,7 +449,7 @@ class FitbitSensor(Entity):
         if self.resource_type == "devices/battery" and self.extra:
             battery_level = BATTERY_LEVELS[self.extra.get("battery")]
             return icon_for_battery_level(battery_level=battery_level, charging=None)
-        return "mdi:{}".format(FITBIT_RESOURCES_LIST[self.resource_type][2])
+        return f"mdi:{FITBIT_RESOURCES_LIST[self.resource_type][2]}"
 
     @property
     def device_state_attributes(self):
@@ -504,7 +502,7 @@ class FitbitSensor(Entity):
                     self._state = raw_state
                 else:
                     try:
-                        self._state = "{0:,}".format(int(raw_state))
+                        self._state = f"{int(raw_state):,}"
                     except TypeError:
                         self._state = raw_state
 
