@@ -1,5 +1,5 @@
 """Constants for the Garmin Connect integration."""
-from homeassistant.const import DEVICE_CLASS_TIMESTAMP
+from homeassistant.const import DEVICE_CLASS_TIMESTAMP, TIME_MINUTES, UNIT_PERCENTAGE
 
 DOMAIN = "garmin_connect"
 ATTRIBUTION = "Data provided by garmin.com"
@@ -52,20 +52,32 @@ GARMIN_ENTITY_LIST = {
         False,
     ],
     "wellnessKilocalories": ["Wellness KiloCalories", "kcal", "mdi:food", None, False],
-    "highlyActiveSeconds": ["Highly Active Time", "min", "mdi:fire", None, False],
-    "activeSeconds": ["Active Time", "min", "mdi:fire", None, True],
-    "sedentarySeconds": ["Sedentary Time", "min", "mdi:seat", None, True],
-    "sleepingSeconds": ["Sleeping Time", "min", "mdi:sleep", None, True],
-    "measurableAwakeDuration": ["Awake Duration", "min", "mdi:sleep", None, True],
-    "measurableAsleepDuration": ["Sleep Duration", "min", "mdi:sleep", None, True],
-    "floorsAscendedInMeters": ["Floors Ascended Mtr", "m", "mdi:stairs", None, False],
-    "floorsDescendedInMeters": [
-        "Floors Descended Mtr",
-        "m",
-        "mdi:stairs",
+    "highlyActiveSeconds": [
+        "Highly Active Time",
+        TIME_MINUTES,
+        "mdi:fire",
         None,
         False,
     ],
+    "activeSeconds": ["Active Time", TIME_MINUTES, "mdi:fire", None, True],
+    "sedentarySeconds": ["Sedentary Time", TIME_MINUTES, "mdi:seat", None, True],
+    "sleepingSeconds": ["Sleeping Time", TIME_MINUTES, "mdi:sleep", None, True],
+    "measurableAwakeDuration": [
+        "Awake Duration",
+        TIME_MINUTES,
+        "mdi:sleep",
+        None,
+        True,
+    ],
+    "measurableAsleepDuration": [
+        "Sleep Duration",
+        TIME_MINUTES,
+        "mdi:sleep",
+        None,
+        True,
+    ],
+    "floorsAscendedInMeters": ["Floors Ascended Mtr", "m", "mdi:stairs", None, False],
+    "floorsDescendedInMeters": ["Floors Descended Mtr", "m", "mdi:stairs", None, False],
     "floorsAscended": ["Floors Ascended", "floors", "mdi:stairs", None, True],
     "floorsDescended": ["Floors Descended", "floors", "mdi:stairs", None, True],
     "userFloorsAscendedGoal": [
@@ -97,146 +109,164 @@ GARMIN_ENTITY_LIST = {
     "averageStressLevel": ["Avg Stress Level", "", "mdi:flash-alert", None, True],
     "maxStressLevel": ["Max Stress Level", "", "mdi:flash-alert", None, True],
     "stressQualifier": ["Stress Qualifier", "", "mdi:flash-alert", None, False],
-    "stressDuration": ["Stress Duration", "min", "mdi:flash-alert", None, False],
+    "stressDuration": ["Stress Duration", TIME_MINUTES, "mdi:flash-alert", None, False],
     "restStressDuration": [
         "Rest Stress Duration",
-        "min",
+        TIME_MINUTES,
         "mdi:flash-alert",
         None,
         True,
     ],
     "activityStressDuration": [
         "Activity Stress Duration",
-        "min",
+        TIME_MINUTES,
         "mdi:flash-alert",
         None,
         True,
     ],
     "uncategorizedStressDuration": [
         "Uncat. Stress Duration",
-        "min",
+        TIME_MINUTES,
         "mdi:flash-alert",
         None,
         True,
     ],
     "totalStressDuration": [
         "Total Stress Duration",
-        "min",
+        TIME_MINUTES,
+        "mdi:flash-alert",
+        None,
+        True,
+    ],
+    "lowStressDuration": [
+        "Low Stress Duration",
+        TIME_MINUTES,
         "mdi:flash-alert",
         None,
         True,
     ],
-    "lowStressDuration": ["Low Stress Duration", "min", "mdi:flash-alert", None, True],
     "mediumStressDuration": [
         "Medium Stress Duration",
-        "min",
+        TIME_MINUTES,
         "mdi:flash-alert",
         None,
         True,
     ],
     "highStressDuration": [
         "High Stress Duration",
-        "min",
+        TIME_MINUTES,
         "mdi:flash-alert",
         None,
         True,
     ],
-    "stressPercentage": ["Stress Percentage", "%", "mdi:flash-alert", None, False],
+    "stressPercentage": [
+        "Stress Percentage",
+        UNIT_PERCENTAGE,
+        "mdi:flash-alert",
+        None,
+        False,
+    ],
     "restStressPercentage": [
         "Rest Stress Percentage",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:flash-alert",
         None,
         False,
     ],
     "activityStressPercentage": [
         "Activity Stress Percentage",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:flash-alert",
         None,
         False,
     ],
     "uncategorizedStressPercentage": [
         "Uncat. Stress Percentage",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:flash-alert",
         None,
         False,
     ],
     "lowStressPercentage": [
         "Low Stress Percentage",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:flash-alert",
         None,
         False,
     ],
     "mediumStressPercentage": [
         "Medium Stress Percentage",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:flash-alert",
         None,
         False,
     ],
     "highStressPercentage": [
         "High Stress Percentage",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:flash-alert",
         None,
         False,
     ],
     "moderateIntensityMinutes": [
         "Moderate Intensity",
-        "min",
+        TIME_MINUTES,
         "mdi:flash-alert",
         None,
         False,
     ],
     "vigorousIntensityMinutes": [
         "Vigorous Intensity",
-        "min",
+        TIME_MINUTES,
+        "mdi:run-fast",
+        None,
+        False,
+    ],
+    "intensityMinutesGoal": [
+        "Intensity Goal",
+        TIME_MINUTES,
         "mdi:run-fast",
         None,
         False,
     ],
-    "intensityMinutesGoal": ["Intensity Goal", "min", "mdi:run-fast", None, False],
     "bodyBatteryChargedValue": [
         "Body Battery Charged",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:battery-charging-100",
         None,
         True,
     ],
     "bodyBatteryDrainedValue": [
         "Body Battery Drained",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:battery-alert-variant-outline",
         None,
         True,
     ],
     "bodyBatteryHighestValue": [
         "Body Battery Highest",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:battery-heart",
         None,
         True,
     ],
     "bodyBatteryLowestValue": [
         "Body Battery Lowest",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:battery-heart-outline",
         None,
         True,
     ],
     "bodyBatteryMostRecentValue": [
         "Body Battery Most Recent",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:battery-positive",
         None,
         True,
     ],
-    "averageSpo2": ["Average SPO2", "%", "mdi:diabetes", None, True],
-    "lowestSpo2": ["Lowest SPO2", "%", "mdi:diabetes", None, True],
-    "latestSpo2": ["Latest SPO2", "%", "mdi:diabetes", None, True],
+    "averageSpo2": ["Average SPO2", UNIT_PERCENTAGE, "mdi:diabetes", None, True],
+    "lowestSpo2": ["Lowest SPO2", UNIT_PERCENTAGE, "mdi:diabetes", None, True],
+    "latestSpo2": ["Latest SPO2", UNIT_PERCENTAGE, "mdi:diabetes", None, True],
     "latestSpo2ReadingTimeLocal": [
         "Latest SPO2 Time",
         "",
@@ -246,7 +276,7 @@ GARMIN_ENTITY_LIST = {
     ],
     "averageMonitoringEnvironmentAltitude": [
         "Average Altitude",
-        "%",
+        UNIT_PERCENTAGE,
         "mdi:image-filter-hdr",
         None,
         False,
