@@ -84,11 +84,6 @@ class GeofencyEntity(TrackerEntity, RestoreEntity):
         """Return the name of the device."""
         return self._name
 
-    @property
-    def should_poll(self):
-        """No polling needed."""
-        return False
-
     @property
     def unique_id(self):
         """Return the unique ID."""
