@@ -1,9 +1,10 @@
 """Play media via gstreamer."""
 import logging
 
+from gsp import GstreamerPlayer
 import voluptuous as vol
 
-from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
+from homeassistant.components.media_player import PLATFORM_SCHEMA, MediaPlayerDevice
 from homeassistant.components.media_player.const import (
     MEDIA_TYPE_MUSIC,
     SUPPORT_NEXT_TRACK,
@@ -36,7 +37,6 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Gstreamer platform."""
-    from gsp import GstreamerPlayer
 
     name = config.get(CONF_NAME)
     pipeline = config.get(CONF_PIPELINE)
