@@ -6,23 +6,23 @@ from typing import Awaitable
 
 import voluptuous as vol
 
-import homeassistant.core as ha
+from homeassistant.auth.permissions.const import CAT_ENTITIES, POLICY_CONTROL
 import homeassistant.config as conf_util
-from homeassistant.exceptions import HomeAssistantError
-from homeassistant.helpers.service import async_extract_entity_ids
-from homeassistant.helpers import intent
 from homeassistant.const import (
     ATTR_ENTITY_ID,
-    SERVICE_TURN_ON,
-    SERVICE_TURN_OFF,
-    SERVICE_TOGGLE,
-    SERVICE_HOMEASSISTANT_STOP,
-    SERVICE_HOMEASSISTANT_RESTART,
-    RESTART_EXIT_CODE,
     ATTR_LATITUDE,
     ATTR_LONGITUDE,
+    RESTART_EXIT_CODE,
+    SERVICE_HOMEASSISTANT_RESTART,
+    SERVICE_HOMEASSISTANT_STOP,
+    SERVICE_TOGGLE,
+    SERVICE_TURN_OFF,
+    SERVICE_TURN_ON,
 )
+import homeassistant.core as ha
+from homeassistant.exceptions import HomeAssistantError, Unauthorized, UnknownUser
 from homeassistant.helpers import config_validation as cv
+from homeassistant.helpers.service import async_extract_entity_ids
 
 _LOGGER = logging.getLogger(__name__)
 DOMAIN = ha.DOMAIN
@@ -55,6 +55,15 @@ async def async_setup(hass: ha.HomeAssistant, config: dict) -> Awaitable[bool]:
         tasks = []
 
         for domain, ent_ids in by_domain:
+            # This leads to endless loop.
+            if domain == DOMAIN:
+                _LOGGER.warning(
+                    "Called service homeassistant.%s with invalid entity IDs %s",
+                    service.service,
+                    ", ".join(ent_ids),
+                )
+                continue
+
             # We want to block for all calls and only return when all calls
             # have been processed. If a service does not exist it causes a 10
             # second delay while we're blocking waiting for a response.
@@ -73,25 +82,19 @@ async def async_setup(hass: ha.HomeAssistant, config: dict) -> Awaitable[bool]:
                 hass.services.async_call(domain, service.service, data, blocking)
             )
 
-        await asyncio.wait(tasks)
+        if tasks:
+            await asyncio.gather(*tasks)
 
-    hass.services.async_register(ha.DOMAIN, SERVICE_TURN_OFF, async_handle_turn_service)
-    hass.services.async_register(ha.DOMAIN, SERVICE_TURN_ON, async_handle_turn_service)
-    hass.services.async_register(ha.DOMAIN, SERVICE_TOGGLE, async_handle_turn_service)
-    hass.helpers.intent.async_register(
-        intent.ServiceIntentHandler(
-            intent.INTENT_TURN_ON, ha.DOMAIN, SERVICE_TURN_ON, "Turned {} on"
-        )
+    service_schema = vol.Schema({ATTR_ENTITY_ID: cv.entity_ids}, extra=vol.ALLOW_EXTRA)
+
+    hass.services.async_register(
+        ha.DOMAIN, SERVICE_TURN_OFF, async_handle_turn_service, schema=service_schema
     )
-    hass.helpers.intent.async_register(
-        intent.ServiceIntentHandler(
-            intent.INTENT_TURN_OFF, ha.DOMAIN, SERVICE_TURN_OFF, "Turned {} off"
-        )
+    hass.services.async_register(
+        ha.DOMAIN, SERVICE_TURN_ON, async_handle_turn_service, schema=service_schema
     )
-    hass.helpers.intent.async_register(
-        intent.ServiceIntentHandler(
-            intent.INTENT_TOGGLE, ha.DOMAIN, SERVICE_TOGGLE, "Toggled {}"
-        )
+    hass.services.async_register(
+        ha.DOMAIN, SERVICE_TOGGLE, async_handle_turn_service, schema=service_schema
     )
 
     async def async_handle_core_service(call):
@@ -119,6 +122,25 @@ async def async_setup(hass: ha.HomeAssistant, config: dict) -> Awaitable[bool]:
 
     async def async_handle_update_service(call):
         """Service handler for updating an entity."""
+        if call.context.user_id:
+            user = await hass.auth.async_get_user(call.context.user_id)
+
+            if user is None:
+                raise UnknownUser(
+                    context=call.context,
+                    permission=POLICY_CONTROL,
+                    user_id=call.context.user_id,
+                )
+
+            for entity in call.data[ATTR_ENTITY_ID]:
+                if not user.permissions.check_entity(entity, POLICY_CONTROL):
+                    raise Unauthorized(
+                        context=call.context,
+                        permission=POLICY_CONTROL,
+                        user_id=call.context.user_id,
+                        perm_category=CAT_ENTITIES,
+                    )
+
         tasks = [
             hass.helpers.entity_component.async_update_entity(entity)
             for entity in call.data[ATTR_ENTITY_ID]
@@ -127,13 +149,13 @@ async def async_setup(hass: ha.HomeAssistant, config: dict) -> Awaitable[bool]:
         if tasks:
             await asyncio.wait(tasks)
 
-    hass.services.async_register(
+    hass.helpers.service.async_register_admin_service(
         ha.DOMAIN, SERVICE_HOMEASSISTANT_STOP, async_handle_core_service
     )
-    hass.services.async_register(
+    hass.helpers.service.async_register_admin_service(
         ha.DOMAIN, SERVICE_HOMEASSISTANT_RESTART, async_handle_core_service
     )
-    hass.services.async_register(
+    hass.helpers.service.async_register_admin_service(
         ha.DOMAIN, SERVICE_CHECK_CONFIG, async_handle_core_service
     )
     hass.services.async_register(
