@@ -1,16 +1,23 @@
 """Support for Homekit device discovery."""
 import logging
+import os
+from typing import Any, Dict
 
-import homekit
-from homekit.model.characteristics import CharacteristicsTypes
+import aiohomekit
+from aiohomekit.model import Accessory
+from aiohomekit.model.characteristics import (
+    Characteristic,
+    CharacteristicPermissions,
+    CharacteristicsTypes,
+)
+from aiohomekit.model.services import Service, ServicesTypes
 
-from homeassistant.core import callback
 from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import device_registry as dr
 from homeassistant.helpers.entity import Entity
 
 from .config_flow import normalize_hkid
-from .connection import HKDevice, get_accessory_information
+from .connection import HKDevice
 from .const import CONTROLLER, DOMAIN, ENTITY_MAP, KNOWN_DEVICES
 from .storage import EntityMapStorage
 
@@ -31,29 +38,65 @@ class HomeKitEntity(Entity):
         self._aid = devinfo["aid"]
         self._iid = devinfo["iid"]
         self._features = 0
-        self._chars = {}
         self.setup()
 
         self._signals = []
 
+    @property
+    def accessory(self) -> Accessory:
+        """Return an Accessory model that this entity is attached to."""
+        return self._accessory.entity_map.aid(self._aid)
+
+    @property
+    def accessory_info(self) -> Service:
+        """Information about the make and model of an accessory."""
+        return self.accessory.services.first(
+            service_type=ServicesTypes.ACCESSORY_INFORMATION
+        )
+
+    @property
+    def service(self) -> Service:
+        """Return a Service model that this entity is attached to."""
+        return self.accessory.services.iid(self._iid)
+
     async def async_added_to_hass(self):
         """Entity added to hass."""
         self._signals.append(
             self.hass.helpers.dispatcher.async_dispatcher_connect(
-                self._accessory.signal_state_updated, self.async_state_changed
+                self._accessory.signal_state_updated, self.async_write_ha_state
             )
         )
 
         self._accessory.add_pollable_characteristics(self.pollable_characteristics)
+        self._accessory.add_watchable_characteristics(self.watchable_characteristics)
 
     async def async_will_remove_from_hass(self):
         """Prepare to be removed from hass."""
         self._accessory.remove_pollable_characteristics(self._aid)
+        self._accessory.remove_watchable_characteristics(self._aid)
 
         for signal_remove in self._signals:
             signal_remove()
         self._signals.clear()
 
+    async def async_put_characteristics(self, characteristics: Dict[str, Any]):
+        """
+        Write characteristics to the device.
+
+        A characteristic type is unique within a service, but in order to write
+        to a named characteristic on a bridge we need to turn its type into
+        an aid and iid, and send it as a list of tuples, which is what this
+        helper does.
+
+        E.g. you can do:
+
+            await entity.async_put_characteristics({
+                CharacteristicsTypes.ON: True
+            })
+        """
+        payload = self.service.build_update(characteristics)
+        return await self._accessory.put_characteristics(payload)
+
     @property
     def should_poll(self) -> bool:
         """Return False.
@@ -63,96 +106,50 @@ class HomeKitEntity(Entity):
         return False
 
     def setup(self):
-        """Configure an entity baed on its HomeKit characterstics metadata."""
-        accessories = self._accessory.accessories
-
-        get_uuid = CharacteristicsTypes.get_uuid
-        characteristic_types = [get_uuid(c) for c in self.get_characteristic_types()]
-
+        """Configure an entity baed on its HomeKit characteristics metadata."""
         self.pollable_characteristics = []
-        self._chars = {}
-        self._char_names = {}
+        self.watchable_characteristics = []
 
-        for accessory in accessories:
-            if accessory["aid"] != self._aid:
-                continue
-            self._accessory_info = get_accessory_information(accessory)
-            for service in accessory["services"]:
-                if service["iid"] != self._iid:
-                    continue
-                for char in service["characteristics"]:
-                    try:
-                        uuid = CharacteristicsTypes.get_uuid(char["type"])
-                    except KeyError:
-                        # If a KeyError is raised its a non-standard
-                        # characteristic. We must ignore it in this case.
-                        continue
-                    if uuid not in characteristic_types:
-                        continue
-                    self._setup_characteristic(char)
+        char_types = self.get_characteristic_types()
 
-    def _setup_characteristic(self, char):
+        # Setup events and/or polling for characteristics directly attached to this entity
+        for char in self.service.characteristics.filter(char_types=char_types):
+            self._setup_characteristic(char)
+
+        # Setup events and/or polling for characteristics attached to sub-services of this
+        # entity (like an INPUT_SOURCE).
+        for service in self.accessory.services.filter(parent_service=self.service):
+            for char in service.characteristics.filter(char_types=char_types):
+                self._setup_characteristic(char)
+
+    def _setup_characteristic(self, char: Characteristic):
         """Configure an entity based on a HomeKit characteristics metadata."""
         # Build up a list of (aid, iid) tuples to poll on update()
-        self.pollable_characteristics.append((self._aid, char["iid"]))
+        if CharacteristicPermissions.paired_read in char.perms:
+            self.pollable_characteristics.append((self._aid, char.iid))
 
-        # Build a map of ctype -> iid
-        short_name = CharacteristicsTypes.get_short(char["type"])
-        self._chars[short_name] = char["iid"]
-        self._char_names[char["iid"]] = short_name
+        # Build up a list of (aid, iid) tuples to subscribe to
+        if CharacteristicPermissions.events in char.perms:
+            self.watchable_characteristics.append((self._aid, char.iid))
 
         # Callback to allow entity to configure itself based on this
         # characteristics metadata (valid values, value ranges, features, etc)
-        setup_fn_name = escape_characteristic_name(short_name)
+        setup_fn_name = escape_characteristic_name(char.type_name)
         setup_fn = getattr(self, f"_setup_{setup_fn_name}", None)
         if not setup_fn:
             return
-        setup_fn(char)
-
-    def get_hk_char_value(self, characteristic_type):
-        """Return the value for a given characteristic type enum."""
-        state = self._accessory.current_state.get(self._aid)
-        if not state:
-            return None
-        char = self._chars.get(CharacteristicsTypes.get_short(characteristic_type))
-        if not char:
-            return None
-        return state.get(char, {}).get("value")
-
-    @callback
-    def async_state_changed(self):
-        """Collect new data from bridge and update the entity state in hass."""
-        accessory_state = self._accessory.current_state.get(self._aid, {})
-        for iid, result in accessory_state.items():
-            # No value so dont process this result
-            if "value" not in result:
-                continue
-
-            # Unknown iid - this is probably for a sibling service that is part
-            # of the same physical accessory. Ignore it.
-            if iid not in self._char_names:
-                continue
-
-            # Callback to update the entity with this characteristic value
-            char_name = escape_characteristic_name(self._char_names[iid])
-            update_fn = getattr(self, f"_update_{char_name}", None)
-            if not update_fn:
-                continue
-
-            update_fn(result["value"])
-
-        self.async_write_ha_state()
+        setup_fn(char.to_accessory_and_service_list())
 
     @property
-    def unique_id(self):
+    def unique_id(self) -> str:
         """Return the ID of this device."""
-        serial = self._accessory_info["serial-number"]
+        serial = self.accessory_info.value(CharacteristicsTypes.SERIAL_NUMBER)
         return f"homekit-{serial}-{self._iid}"
 
     @property
-    def name(self):
+    def name(self) -> str:
         """Return the name of the device if any."""
-        return self._accessory_info.get("name")
+        return self.accessory_info.value(CharacteristicsTypes.NAME)
 
     @property
     def available(self) -> bool:
@@ -162,14 +159,15 @@ class HomeKitEntity(Entity):
     @property
     def device_info(self):
         """Return the device info."""
-        accessory_serial = self._accessory_info["serial-number"]
+        info = self.accessory_info
+        accessory_serial = info.value(CharacteristicsTypes.SERIAL_NUMBER)
 
         device_info = {
             "identifiers": {(DOMAIN, "serial-number", accessory_serial)},
-            "name": self._accessory_info["name"],
-            "manufacturer": self._accessory_info.get("manufacturer", ""),
-            "model": self._accessory_info.get("model", ""),
-            "sw_version": self._accessory_info.get("firmware.revision", ""),
+            "name": info.value(CharacteristicsTypes.NAME),
+            "manufacturer": info.value(CharacteristicsTypes.MANUFACTURER, ""),
+            "model": info.value(CharacteristicsTypes.MODEL, ""),
+            "sw_version": info.value(CharacteristicsTypes.FIRMWARE_REVISION, ""),
         }
 
         # Some devices only have a single accessory - we don't add a
@@ -223,9 +221,19 @@ async def async_setup(hass, config):
     map_storage = hass.data[ENTITY_MAP] = EntityMapStorage(hass)
     await map_storage.async_initialize()
 
-    hass.data[CONTROLLER] = homekit.Controller()
+    hass.data[CONTROLLER] = aiohomekit.Controller()
     hass.data[KNOWN_DEVICES] = {}
 
+    dothomekit_dir = hass.config.path(".homekit")
+    if os.path.exists(dothomekit_dir):
+        _LOGGER.warning(
+            (
+                "Legacy homekit_controller state found in %s. Support for reading "
+                "the folder is deprecated and will be removed in 0.109.0."
+            ),
+            dothomekit_dir,
+        )
+
     return True
 
 
