@@ -30,4 +30,6 @@ HOMEKIT_ACCESSORY_DISPATCH = {
     "fan": "fan",
     "fanv2": "fan",
     "air-quality": "air_quality",
+    "occupancy": "binary_sensor",
+    "television": "media_player",
 }
