@@ -1,7 +1,7 @@
 """Support for Homekit lights."""
 import logging
 
-from homekit.model.characteristics import CharacteristicsTypes
+from aiohomekit.model.characteristics import CharacteristicsTypes
 
 from homeassistant.components.light import (
     ATTR_BRIGHTNESS,
@@ -38,15 +38,6 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
 class HomeKitLight(HomeKitEntity, Light):
     """Representation of a Homekit light."""
 
-    def __init__(self, *args):
-        """Initialise the light."""
-        super().__init__(*args)
-        self._on = False
-        self._brightness = 0
-        self._color_temperature = 0
-        self._hue = 0
-        self._saturation = 0
-
     def get_characteristic_types(self):
         """Define the homekit characteristics the entity cares about."""
         return [
@@ -69,40 +60,28 @@ class HomeKitLight(HomeKitEntity, Light):
     def _setup_saturation(self, char):
         self._features |= SUPPORT_COLOR
 
-    def _update_on(self, value):
-        self._on = value
-
-    def _update_brightness(self, value):
-        self._brightness = value
-
-    def _update_color_temperature(self, value):
-        self._color_temperature = value
-
-    def _update_hue(self, value):
-        self._hue = value
-
-    def _update_saturation(self, value):
-        self._saturation = value
-
     @property
     def is_on(self):
         """Return true if device is on."""
-        return self._on
+        return self.service.value(CharacteristicsTypes.ON)
 
     @property
     def brightness(self):
         """Return the brightness of this light between 0..255."""
-        return self._brightness * 255 / 100
+        return self.service.value(CharacteristicsTypes.BRIGHTNESS) * 255 / 100
 
     @property
     def hs_color(self):
         """Return the color property."""
-        return (self._hue, self._saturation)
+        return (
+            self.service.value(CharacteristicsTypes.HUE),
+            self.service.value(CharacteristicsTypes.SATURATION),
+        )
 
     @property
     def color_temp(self):
         """Return the color temperature."""
-        return self._color_temperature
+        return self.service.value(CharacteristicsTypes.COLOR_TEMPERATURE)
 
     @property
     def supported_features(self):
@@ -115,41 +94,28 @@ class HomeKitLight(HomeKitEntity, Light):
         temperature = kwargs.get(ATTR_COLOR_TEMP)
         brightness = kwargs.get(ATTR_BRIGHTNESS)
 
-        characteristics = []
+        characteristics = {}
+
         if hs_color is not None:
-            characteristics.append(
-                {"aid": self._aid, "iid": self._chars["hue"], "value": hs_color[0]}
-            )
-            characteristics.append(
+            characteristics.update(
                 {
-                    "aid": self._aid,
-                    "iid": self._chars["saturation"],
-                    "value": hs_color[1],
+                    CharacteristicsTypes.HUE: hs_color[0],
+                    CharacteristicsTypes.SATURATION: hs_color[1],
                 }
             )
+
         if brightness is not None:
-            characteristics.append(
-                {
-                    "aid": self._aid,
-                    "iid": self._chars["brightness"],
-                    "value": int(brightness * 100 / 255),
-                }
+            characteristics[CharacteristicsTypes.BRIGHTNESS] = int(
+                brightness * 100 / 255
             )
 
         if temperature is not None:
-            characteristics.append(
-                {
-                    "aid": self._aid,
-                    "iid": self._chars["color-temperature"],
-                    "value": int(temperature),
-                }
-            )
-        characteristics.append(
-            {"aid": self._aid, "iid": self._chars["on"], "value": True}
-        )
-        await self._accessory.put_characteristics(characteristics)
+            characteristics[CharacteristicsTypes.COLOR_TEMPERATURE] = int(temperature)
+
+        characteristics[CharacteristicsTypes.ON] = True
+
+        await self.async_put_characteristics(characteristics)
 
     async def async_turn_off(self, **kwargs):
         """Turn the specified light off."""
-        characteristics = [{"aid": self._aid, "iid": self._chars["on"], "value": False}]
-        await self._accessory.put_characteristics(characteristics)
+        await self.async_put_characteristics({CharacteristicsTypes.ON: False})
