@@ -8,6 +8,9 @@ from homeassistant.const import (
     DEVICE_CLASS_TEMPERATURE,
     ENERGY_WATT_HOUR,
     POWER_WATT,
+    SPEED_KILOMETERS_PER_HOUR,
+    UNIT_PERCENTAGE,
+    VOLUME_CUBIC_METERS,
 )
 
 from .const import ATTR_DISCOVER_DEVICES
@@ -30,7 +33,7 @@ HM_STATE_HA_CAST = {
 }
 
 HM_UNIT_HA_CAST = {
-    "HUMIDITY": "%",
+    "HUMIDITY": UNIT_PERCENTAGE,
     "TEMPERATURE": "°C",
     "ACTUAL_TEMPERATURE": "°C",
     "BRIGHTNESS": "#",
@@ -38,8 +41,8 @@ HM_UNIT_HA_CAST = {
     "CURRENT": "mA",
     "VOLTAGE": "V",
     "ENERGY_COUNTER": ENERGY_WATT_HOUR,
-    "GAS_POWER": "m3",
-    "GAS_ENERGY_COUNTER": "m3",
+    "GAS_POWER": VOLUME_CUBIC_METERS,
+    "GAS_ENERGY_COUNTER": VOLUME_CUBIC_METERS,
     "LUX": "lx",
     "ILLUMINATION": "lx",
     "CURRENT_ILLUMINATION": "lx",
@@ -47,7 +50,7 @@ HM_UNIT_HA_CAST = {
     "LOWEST_ILLUMINATION": "lx",
     "HIGHEST_ILLUMINATION": "lx",
     "RAIN_COUNTER": "mm",
-    "WIND_SPEED": "km/h",
+    "WIND_SPEED": SPEED_KILOMETERS_PER_HOUR,
     "WIND_DIRECTION": "°",
     "WIND_DIRECTION_RANGE": "°",
     "SUNSHINEDURATION": "#",
