@@ -63,8 +63,11 @@ from .const import (
     KEY_DEVICE_INFORMATION,
     KEY_DEVICE_SIGNAL,
     KEY_DIALUP_MOBILE_DATASWITCH,
+    KEY_MONITORING_MONTH_STATISTICS,
     KEY_MONITORING_STATUS,
     KEY_MONITORING_TRAFFIC_STATISTICS,
+    KEY_NET_CURRENT_PLMN,
+    KEY_NET_NET_MODE,
     KEY_WLAN_HOST_LIST,
     NOTIFY_SUPPRESS_TIMEOUT,
     SERVICE_CLEAR_TRAFFIC_STATISTICS,
@@ -81,8 +84,6 @@ _LOGGER = logging.getLogger(__name__)
 # https://github.com/quandyfactory/dicttoxml/issues/60
 logging.getLogger("dicttoxml").setLevel(logging.WARNING)
 
-DEFAULT_NAME_TEMPLATE = "Huawei {} {}"
-
 SCAN_INTERVAL = timedelta(seconds=10)
 
 NOTIFY_SCHEMA = vol.Any(
@@ -232,10 +233,15 @@ class Router:
         self._get_data(
             KEY_DIALUP_MOBILE_DATASWITCH, self.client.dial_up.mobile_dataswitch
         )
+        self._get_data(
+            KEY_MONITORING_MONTH_STATISTICS, self.client.monitoring.month_statistics
+        )
         self._get_data(KEY_MONITORING_STATUS, self.client.monitoring.status)
         self._get_data(
             KEY_MONITORING_TRAFFIC_STATISTICS, self.client.monitoring.traffic_statistics
         )
+        self._get_data(KEY_NET_CURRENT_PLMN, self.client.net.current_plmn)
+        self._get_data(KEY_NET_NET_MODE, self.client.net.net_mode)
         self._get_data(KEY_WLAN_HOST_LIST, self.client.wlan.host_list)
 
         self.signal_update()
@@ -567,7 +573,7 @@ class HuaweiLteBaseEntity(Entity):
     @property
     def name(self) -> str:
         """Return entity name."""
-        return DEFAULT_NAME_TEMPLATE.format(self.router.device_name, self._entity_name)
+        return f"Huawei {self.router.device_name} {self._entity_name}"
 
     @property
     def available(self) -> bool:
