@@ -6,7 +6,12 @@ from hydrawiser.core import Hydrawiser
 from requests.exceptions import ConnectTimeout, HTTPError
 import voluptuous as vol
 
-from homeassistant.const import ATTR_ATTRIBUTION, CONF_ACCESS_TOKEN, CONF_SCAN_INTERVAL
+from homeassistant.const import (
+    ATTR_ATTRIBUTION,
+    CONF_ACCESS_TOKEN,
+    CONF_SCAN_INTERVAL,
+    TIME_MINUTES,
+)
 from homeassistant.core import callback
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.dispatcher import async_dispatcher_connect, dispatcher_send
@@ -40,7 +45,7 @@ DEVICE_MAP = {
     "manual_watering": ["Manual Watering", "mdi:water-pump", "", ""],
     "next_cycle": ["Next Cycle", "mdi:calendar-clock", "", ""],
     "status": ["Status", "", "connectivity", ""],
-    "watering_time": ["Watering Time", "mdi:water-pump", "", "min"],
+    "watering_time": ["Watering Time", "mdi:water-pump", "", TIME_MINUTES],
     "rain_sensor": ["Rain Sensor", "", "moisture", ""],
 }
 
@@ -79,9 +84,7 @@ def setup(hass, config):
     except (ConnectTimeout, HTTPError) as ex:
         _LOGGER.error("Unable to connect to Hydrawise cloud service: %s", str(ex))
         hass.components.persistent_notification.create(
-            "Error: {}<br />"
-            "You will need to restart hass after fixing."
-            "".format(ex),
+            f"Error: {ex}<br />You will need to restart hass after fixing.",
             title=NOTIFICATION_TITLE,
             notification_id=NOTIFICATION_ID,
         )
@@ -114,10 +117,7 @@ class HydrawiseEntity(Entity):
         """Initialize the Hydrawise entity."""
         self.data = data
         self._sensor_type = sensor_type
-        self._name = "{0} {1}".format(
-            self.data["name"],
-            DEVICE_MAP[self._sensor_type][DEVICE_MAP_INDEX.index("KEY_INDEX")],
-        )
+        self._name = f"{self.data['name']} {DEVICE_MAP[self._sensor_type][DEVICE_MAP_INDEX.index('KEY_INDEX')]}"
         self._state = None
 
     @property
