@@ -126,11 +126,6 @@ class IcloudTrackerEntity(TrackerEntity):
             "model": self._device.device_model,
         }
 
-    @property
-    def should_poll(self) -> bool:
-        """No polling needed."""
-        return False
-
     async def async_added_to_hass(self):
         """Register state update callback."""
         self._unsub_dispatcher = async_dispatcher_connect(
