@@ -1,7 +1,7 @@
 """Support for IHC switches."""
 from homeassistant.components.switch import SwitchDevice
 
-from . import IHC_CONTROLLER, IHC_DATA, IHC_INFO
+from . import IHC_CONTROLLER, IHC_INFO
 from .const import CONF_OFF_ID, CONF_ON_ID
 from .ihcdevice import IHCDevice
 from .util import async_pulse, async_set_bool
@@ -18,7 +18,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
         product = device["product"]
         # Find controller that corresponds with device id
         ctrl_id = device["ctrl_id"]
-        ihc_key = IHC_DATA.format(ctrl_id)
+        ihc_key = f"ihc{ctrl_id}"
         info = hass.data[ihc_key][IHC_INFO]
         ihc_controller = hass.data[ihc_key][IHC_CONTROLLER]
         ihc_off_id = product_cfg.get(CONF_OFF_ID)
