@@ -2,6 +2,7 @@
 from datetime import timedelta
 import logging
 
+from influxdb import InfluxDBClient, exceptions
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
@@ -94,7 +95,6 @@ class InfluxSensor(Entity):
 
     def __init__(self, hass, influx_conf, query):
         """Initialize the sensor."""
-        from influxdb import InfluxDBClient, exceptions
 
         self._name = query.get(CONF_NAME)
         self._unit_of_measurement = query.get(CONF_UNIT_OF_MEASUREMENT)
@@ -196,23 +196,20 @@ class InfluxSensorData:
             _LOGGER.error("Could not render where clause template: %s", ex)
             return
 
-        self.query = "select {}({}) as value from {} where {}".format(
-            self.group, self.field, self.measurement, where_clause
-        )
+        self.query = f"select {self.group}({self.field}) as value from {self.measurement} where {where_clause}"
 
         _LOGGER.info("Running query: %s", self.query)
 
         points = list(self.influx.query(self.query).get_points())
         if not points:
             _LOGGER.warning(
-                "Query returned no points, sensor state set " "to UNKNOWN: %s",
-                self.query,
+                "Query returned no points, sensor state set to UNKNOWN: %s", self.query,
             )
             self.value = None
         else:
             if len(points) > 1:
                 _LOGGER.warning(
-                    "Query returned multiple points, only first " "one shown: %s",
+                    "Query returned multiple points, only first one shown: %s",
                     self.query,
                 )
             self.value = points[0].get("value")
