@@ -1,5 +1,6 @@
 """Support for KNX scenes."""
 import voluptuous as vol
+from xknx.devices import Scene as XknxScene
 
 from homeassistant.components.scene import CONF_PLATFORM, Scene
 from homeassistant.const import CONF_ADDRESS, CONF_NAME
@@ -42,9 +43,7 @@ def async_add_entities_discovery(hass, discovery_info, async_add_entities):
 @callback
 def async_add_entities_config(hass, config, async_add_entities):
     """Set up scene for KNX platform configured within platform."""
-    import xknx
-
-    scene = xknx.devices.Scene(
+    scene = XknxScene(
         hass.data[DATA_KNX].xknx,
         name=config[CONF_NAME],
         group_address=config[CONF_ADDRESS],
