@@ -19,12 +19,12 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 
 
 def to_lutron_level(level):
-    """Convert the given HASS light level (0-255) to Lutron (0.0-100.0)."""
+    """Convert the given Home Assistant light level (0-255) to Lutron (0.0-100.0)."""
     return float((level * 100) / 255)
 
 
 def to_hass_level(level):
-    """Convert the given Lutron (0.0-100.0) light level to HASS (0-255)."""
+    """Convert the given Lutron (0.0-100.0) light level to Home Assistant (0-255)."""
     return int((level * 255) / 100)
 
 
