@@ -29,7 +29,6 @@ from homeassistant.const import (
     STATE_ALARM_PENDING,
     STATE_ALARM_TRIGGERED,
 )
-from homeassistant.core import callback
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.event import async_track_state_change, track_point_in_time
 import homeassistant.util.dt as dt_util
@@ -427,17 +426,16 @@ class ManualMQTTAlarm(alarm.AlarmControlPanel):
             self.hass, self.entity_id, self._async_state_changed_listener
         )
 
-        @callback
-        def message_received(msg):
+        async def message_received(msg):
             """Run when new MQTT message has been received."""
             if msg.payload == self._payload_disarm:
-                self.async_alarm_disarm(self._code)
+                await self.async_alarm_disarm(self._code)
             elif msg.payload == self._payload_arm_home:
-                self.async_alarm_arm_home(self._code)
+                await self.async_alarm_arm_home(self._code)
             elif msg.payload == self._payload_arm_away:
-                self.async_alarm_arm_away(self._code)
+                await self.async_alarm_arm_away(self._code)
             elif msg.payload == self._payload_arm_night:
-                self.async_alarm_arm_night(self._code)
+                await self.async_alarm_arm_night(self._code)
             else:
                 _LOGGER.warning("Received unexpected payload: %s", msg.payload)
                 return
