@@ -1,7 +1,7 @@
 """Support for binary sensor using I2C MCP23017 chip."""
 import logging
 
-import adafruit_mcp230xx  # pylint: disable=import-error
+from adafruit_mcp230xx.mcp23017 import MCP23017  # pylint: disable=import-error
 import board  # pylint: disable=import-error
 import busio  # pylint: disable=import-error
 import digitalio  # pylint: disable=import-error
@@ -46,7 +46,7 @@ def setup_platform(hass, config, add_devices, discovery_info=None):
     i2c_address = config[CONF_I2C_ADDRESS]
 
     i2c = busio.I2C(board.SCL, board.SDA)
-    mcp = adafruit_mcp230xx.MCP23017(i2c, address=i2c_address)
+    mcp = MCP23017(i2c, address=i2c_address)
 
     binary_sensors = []
     pins = config[CONF_PINS]
