@@ -1,7 +1,10 @@
 """Support for Generic Modbus Thermostats."""
 import logging
 import struct
+from typing import Optional
 
+from pymodbus.exceptions import ConnectionException, ModbusException
+from pymodbus.pdu import ExceptionResponse
 import voluptuous as vol
 
 from homeassistant.components.climate import PLATFORM_SCHEMA, ClimateDevice
@@ -24,6 +27,7 @@ _LOGGER = logging.getLogger(__name__)
 
 CONF_TARGET_TEMP = "target_temp_register"
 CONF_CURRENT_TEMP = "current_temp_register"
+CONF_CURRENT_TEMP_REGISTER_TYPE = "current_temp_register_type"
 CONF_DATA_TYPE = "data_type"
 CONF_COUNT = "data_count"
 CONF_PRECISION = "precision"
@@ -39,6 +43,9 @@ CONF_STEP = "temp_step"
 SUPPORT_FLAGS = SUPPORT_TARGET_TEMPERATURE
 HVAC_MODES = [HVAC_MODE_AUTO]
 
+DEFAULT_REGISTER_TYPE_HOLDING = "holding"
+DEFAULT_REGISTER_TYPE_INPUT = "input"
+
 PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
     {
         vol.Required(CONF_CURRENT_TEMP): cv.positive_int,
@@ -46,6 +53,9 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
         vol.Required(CONF_SLAVE): cv.positive_int,
         vol.Required(CONF_TARGET_TEMP): cv.positive_int,
         vol.Optional(CONF_COUNT, default=2): cv.positive_int,
+        vol.Optional(
+            CONF_CURRENT_TEMP_REGISTER_TYPE, default=DEFAULT_REGISTER_TYPE_HOLDING
+        ): vol.In([DEFAULT_REGISTER_TYPE_HOLDING, DEFAULT_REGISTER_TYPE_INPUT]),
         vol.Optional(CONF_DATA_TYPE, default=DATA_TYPE_FLOAT): vol.In(
             [DATA_TYPE_INT, DATA_TYPE_UINT, DATA_TYPE_FLOAT]
         ),
@@ -53,8 +63,8 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
         vol.Optional(CONF_PRECISION, default=1): cv.positive_int,
         vol.Optional(CONF_SCALE, default=1): vol.Coerce(float),
         vol.Optional(CONF_OFFSET, default=0): vol.Coerce(float),
-        vol.Optional(CONF_MAX_TEMP, default=5): cv.positive_int,
-        vol.Optional(CONF_MIN_TEMP, default=35): cv.positive_int,
+        vol.Optional(CONF_MAX_TEMP, default=35): cv.positive_int,
+        vol.Optional(CONF_MIN_TEMP, default=5): cv.positive_int,
         vol.Optional(CONF_STEP, default=0.5): vol.Coerce(float),
         vol.Optional(CONF_UNIT, default="C"): cv.string,
     }
@@ -63,20 +73,21 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Modbus Thermostat Platform."""
-    name = config.get(CONF_NAME)
-    modbus_slave = config.get(CONF_SLAVE)
-    target_temp_register = config.get(CONF_TARGET_TEMP)
-    current_temp_register = config.get(CONF_CURRENT_TEMP)
-    data_type = config.get(CONF_DATA_TYPE)
-    count = config.get(CONF_COUNT)
-    precision = config.get(CONF_PRECISION)
-    scale = config.get(CONF_SCALE)
-    offset = config.get(CONF_OFFSET)
-    unit = config.get(CONF_UNIT)
-    max_temp = config.get(CONF_MAX_TEMP)
-    min_temp = config.get(CONF_MIN_TEMP)
-    temp_step = config.get(CONF_STEP)
-    hub_name = config.get(CONF_HUB)
+    name = config[CONF_NAME]
+    modbus_slave = config[CONF_SLAVE]
+    target_temp_register = config[CONF_TARGET_TEMP]
+    current_temp_register = config[CONF_CURRENT_TEMP]
+    current_temp_register_type = config[CONF_CURRENT_TEMP_REGISTER_TYPE]
+    data_type = config[CONF_DATA_TYPE]
+    count = config[CONF_COUNT]
+    precision = config[CONF_PRECISION]
+    scale = config[CONF_SCALE]
+    offset = config[CONF_OFFSET]
+    unit = config[CONF_UNIT]
+    max_temp = config[CONF_MAX_TEMP]
+    min_temp = config[CONF_MIN_TEMP]
+    temp_step = config[CONF_STEP]
+    hub_name = config[CONF_HUB]
     hub = hass.data[MODBUS_DOMAIN][hub_name]
 
     add_entities(
@@ -87,6 +98,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
                 modbus_slave,
                 target_temp_register,
                 current_temp_register,
+                current_temp_register_type,
                 data_type,
                 count,
                 precision,
@@ -112,6 +124,7 @@ class ModbusThermostat(ClimateDevice):
         modbus_slave,
         target_temp_register,
         current_temp_register,
+        current_temp_register_type,
         data_type,
         count,
         precision,
@@ -128,6 +141,7 @@ class ModbusThermostat(ClimateDevice):
         self._slave = modbus_slave
         self._target_temperature_register = target_temp_register
         self._current_temperature_register = current_temp_register
+        self._current_temperature_register_type = current_temp_register_type
         self._target_temperature = None
         self._current_temperature = None
         self._data_type = data_type
@@ -140,6 +154,7 @@ class ModbusThermostat(ClimateDevice):
         self._min_temp = min_temp
         self._temp_step = temp_step
         self._structure = ">f"
+        self._available = True
 
         data_types = {
             DATA_TYPE_INT: {1: "h", 2: "i", 4: "q"},
@@ -147,7 +162,7 @@ class ModbusThermostat(ClimateDevice):
             DATA_TYPE_FLOAT: {1: "e", 2: "f", 4: "d"},
         }
 
-        self._structure = ">{}".format(data_types[self._data_type][self._count])
+        self._structure = f">{data_types[self._data_type][self._count]}"
 
     @property
     def supported_features(self):
@@ -156,9 +171,11 @@ class ModbusThermostat(ClimateDevice):
 
     def update(self):
         """Update Target & Current Temperature."""
-        self._target_temperature = self.read_register(self._target_temperature_register)
-        self._current_temperature = self.read_register(
-            self._current_temperature_register
+        self._target_temperature = self._read_register(
+            DEFAULT_REGISTER_TYPE_HOLDING, self._target_temperature_register
+        )
+        self._current_temperature = self._read_register(
+            self._current_temperature_register_type, self._current_temperature_register
         )
 
     @property
@@ -215,20 +232,32 @@ class ModbusThermostat(ClimateDevice):
             return
         byte_string = struct.pack(self._structure, target_temperature)
         register_value = struct.unpack(">h", byte_string[0:2])[0]
+        self._write_register(self._target_temperature_register, register_value)
 
-        try:
-            self.write_register(self._target_temperature_register, register_value)
-        except AttributeError as ex:
-            _LOGGER.error(ex)
+    @property
+    def available(self) -> bool:
+        """Return True if entity is available."""
+        return self._available
 
-    def read_register(self, register):
-        """Read holding register using the Modbus hub slave."""
+    def _read_register(self, register_type, register) -> Optional[float]:
+        """Read register using the Modbus hub slave."""
         try:
-            result = self._hub.read_holding_registers(
-                self._slave, register, self._count
-            )
-        except AttributeError as ex:
-            _LOGGER.error(ex)
+            if register_type == DEFAULT_REGISTER_TYPE_INPUT:
+                result = self._hub.read_input_registers(
+                    self._slave, register, self._count
+                )
+            else:
+                result = self._hub.read_holding_registers(
+                    self._slave, register, self._count
+                )
+        except ConnectionException:
+            self._set_unavailable(register)
+            return
+
+        if isinstance(result, (ModbusException, ExceptionResponse)):
+            self._set_unavailable(register)
+            return
+
         byte_string = b"".join(
             [x.to_bytes(2, byteorder="big") for x in result.registers]
         )
@@ -237,8 +266,29 @@ class ModbusThermostat(ClimateDevice):
             (self._scale * val) + self._offset, f".{self._precision}f"
         )
         register_value = float(register_value)
+        self._available = True
+
         return register_value
 
-    def write_register(self, register, value):
-        """Write register using the Modbus hub slave."""
-        self._hub.write_registers(self._slave, register, [value, 0])
+    def _write_register(self, register, value):
+        """Write holding register using the Modbus hub slave."""
+        try:
+            self._hub.write_registers(self._slave, register, [value, 0])
+        except ConnectionException:
+            self._set_unavailable(register)
+            return
+
+        self._available = True
+
+    def _set_unavailable(self, register):
+        """Set unavailable state and log it as an error."""
+        if not self._available:
+            return
+
+        _LOGGER.error(
+            "No response from hub %s, slave %s, register %s",
+            self._hub.name,
+            self._slave,
+            register,
+        )
+        self._available = False
