@@ -1,9 +1,11 @@
 """Support for interfacing with Monoprice 6 zone home audio controller."""
 import logging
 
+from pymonoprice import get_monoprice
+from serial import SerialException
 import voluptuous as vol
 
-from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
+from homeassistant.components.media_player import PLATFORM_SCHEMA, MediaPlayerDevice
 from homeassistant.components.media_player.const import (
     SUPPORT_SELECT_SOURCE,
     SUPPORT_TURN_OFF,
@@ -20,6 +22,7 @@ from homeassistant.const import (
     STATE_ON,
 )
 import homeassistant.helpers.config_validation as cv
+
 from .const import DOMAIN, SERVICE_RESTORE, SERVICE_SNAPSHOT
 
 _LOGGER = logging.getLogger(__name__)
@@ -68,9 +71,6 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Monoprice 6-zone amplifier platform."""
     port = config.get(CONF_PORT)
 
-    from serial import SerialException
-    from pymonoprice import get_monoprice
-
     try:
         monoprice = get_monoprice(port)
     except SerialException:
