@@ -22,7 +22,7 @@ class MoparLock(LockDevice):
     def __init__(self, data, index):
         """Initialize the Mopar lock."""
         self._index = index
-        self._name = "{} Lock".format(data.get_vehicle_name(self._index))
+        self._name = f"{data.get_vehicle_name(self._index)} Lock"
         self._actuate = data.actuate
         self._state = None
 
