@@ -1,5 +1,4 @@
 """Support for a local MQTT broker."""
-import asyncio
 import logging
 import tempfile
 
@@ -29,8 +28,7 @@ HBMQTT_CONFIG_SCHEMA = vol.Any(
 )
 
 
-@asyncio.coroutine
-def async_start(hass, password, server_config):
+async def async_start(hass, password, server_config):
     """Initialize MQTT Server.
 
     This method is a coroutine.
@@ -47,17 +45,16 @@ def async_start(hass, password, server_config):
             server_config = gen_server_config
 
         broker = Broker(server_config, hass.loop)
-        yield from broker.start()
+        await broker.start()
     except BrokerException:
         _LOGGER.exception("Error initializing MQTT server")
         return False, None
     finally:
         passwd.close()
 
-    @asyncio.coroutine
-    def async_shutdown_mqtt_server(event):
+    async def async_shutdown_mqtt_server(event):
         """Shut down the MQTT server."""
-        yield from broker.shutdown()
+        await broker.shutdown()
 
     hass.bus.async_listen_once(EVENT_HOMEASSISTANT_STOP, async_shutdown_mqtt_server)
 
@@ -88,9 +85,7 @@ def generate_config(hass, passwd, password):
 
         # Encrypt with what hbmqtt uses to verify
         passwd.write(
-            "homeassistant:{}\n".format(custom_app_context.encrypt(password)).encode(
-                "utf-8"
-            )
+            f"homeassistant:{custom_app_context.encrypt(password)}\n".encode("utf-8")
         )
         passwd.flush()
 
