@@ -1,14 +1,15 @@
 """Support for departure information for public transport in Munich."""
-import logging
-from datetime import timedelta
-
 from copy import deepcopy
+from datetime import timedelta
+import logging
+
+import MVGLive
 import voluptuous as vol
 
+from homeassistant.components.sensor import PLATFORM_SCHEMA
+from homeassistant.const import ATTR_ATTRIBUTION, CONF_NAME, TIME_MINUTES
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
-from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import CONF_NAME, ATTR_ATTRIBUTION
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -130,7 +131,7 @@ class MVGLiveSensor(Entity):
     @property
     def unit_of_measurement(self):
         """Return the unit this state is expressed in."""
-        return "min"
+        return TIME_MINUTES
 
     def update(self):
         """Get the latest data and update the state."""
@@ -150,8 +151,6 @@ class MVGLiveData:
         self, station, destinations, directions, lines, products, timeoffset, number
     ):
         """Initialize the sensor."""
-        import MVGLive
-
         self._station = station
         self._destinations = destinations
         self._directions = directions
