@@ -4,6 +4,7 @@ import logging
 from homeassistant.components.binary_sensor import DOMAIN, BinarySensorDevice
 from homeassistant.components.http import HomeAssistantView
 from homeassistant.const import HTTP_UNPROCESSABLE_ENTITY
+from homeassistant.core import callback
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -81,6 +82,7 @@ class MyStromBinarySensor(BinarySensorDevice):
         """Return true if the binary sensor is on."""
         return self._state
 
+    @callback
     def async_on_update(self, value):
         """Receive an update."""
         self._state = value
