@@ -20,6 +20,7 @@ CONF_ROUTES = "routes"
 CONF_FROM = "from"
 CONF_TO = "to"
 CONF_VIA = "via"
+CONF_TIME = "time"
 
 ICON = "mdi:train"
 
@@ -31,6 +32,7 @@ ROUTE_SCHEMA = vol.Schema(
         vol.Required(CONF_FROM): cv.string,
         vol.Required(CONF_TO): cv.string,
         vol.Optional(CONF_VIA): cv.string,
+        vol.Optional(CONF_TIME): cv.time,
     }
 )
 
@@ -68,6 +70,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
                 departure.get(CONF_FROM),
                 departure.get(CONF_TO),
                 departure.get(CONF_VIA),
+                departure.get(CONF_TIME),
             )
         )
     if sensors:
@@ -88,13 +91,14 @@ def valid_stations(stations, given_stations):
 class NSDepartureSensor(Entity):
     """Implementation of a NS Departure Sensor."""
 
-    def __init__(self, nsapi, name, departure, heading, via):
+    def __init__(self, nsapi, name, departure, heading, via, time):
         """Initialize the sensor."""
         self._nsapi = nsapi
         self._name = name
         self._departure = departure
         self._via = via
         self._heading = heading
+        self._time = time
         self._state = None
         self._trips = None
 
@@ -138,6 +142,7 @@ class NSDepartureSensor(Entity):
             "arrival_platform_planned": self._trips[0].arrival_platform_planned,
             "arrival_platform_actual": self._trips[0].arrival_platform_actual,
             "next": None,
+            "punctuality": None,
             "status": self._trips[0].status.lower(),
             "transfers": self._trips[0].nr_transfers,
             "route": route,
@@ -186,26 +191,49 @@ class NSDepartureSensor(Entity):
         ):
             attributes["arrival_delay"] = True
 
+        # Punctuality attributes
+        if self._trips[0].punctuality is not None:
+            attributes["punctuality"] = self._trips[0].punctuality
+
         # Next attributes
-        if self._trips[1].departure_time_actual is not None:
-            attributes["next"] = self._trips[1].departure_time_actual.strftime("%H:%M")
-        elif self._trips[1].departure_time_planned is not None:
-            attributes["next"] = self._trips[1].departure_time_planned.strftime("%H:%M")
+        if len(self._trips) > 1:
+            if self._trips[1].departure_time_actual is not None:
+                attributes["next"] = self._trips[1].departure_time_actual.strftime(
+                    "%H:%M"
+                )
+            elif self._trips[1].departure_time_planned is not None:
+                attributes["next"] = self._trips[1].departure_time_planned.strftime(
+                    "%H:%M"
+                )
 
         return attributes
 
     @Throttle(MIN_TIME_BETWEEN_UPDATES)
     def update(self):
         """Get the trip information."""
+
+        # If looking for a specific trip time, update around that trip time only.
+        if self._time and (
+            (datetime.now() + timedelta(minutes=30)).time() < self._time
+            or (datetime.now() - timedelta(minutes=30)).time() > self._time
+        ):
+            self._state = None
+            self._trips = None
+            return
+
+        # Set the search parameter to search from a specific trip time or to just search for next trip.
+        if self._time:
+            trip_time = (
+                datetime.today()
+                .replace(hour=self._time.hour, minute=self._time.minute)
+                .strftime("%d-%m-%Y %H:%M")
+            )
+        else:
+            trip_time = datetime.now().strftime("%d-%m-%Y %H:%M")
+
         try:
             self._trips = self._nsapi.get_trips(
-                datetime.now().strftime("%d-%m-%Y %H:%M"),
-                self._departure,
-                self._via,
-                self._heading,
-                True,
-                0,
-                2,
+                trip_time, self._departure, self._via, self._heading, True, 0, 2
             )
             if self._trips:
                 if self._trips[0].departure_time_actual is None:
