@@ -22,6 +22,7 @@ from .const import (
     MANUFACTURER,
     MIN_TIME_BETWEEN_EVENT_UPDATES,
     MIN_TIME_BETWEEN_UPDATES,
+    MODELS,
 )
 
 _LOGGER = logging.getLogger(__name__)
@@ -83,21 +84,11 @@ class NetatmoCamera(Camera):
         self._unique_id = f"{self._camera_id}-{self._camera_type}"
         self._verify_ssl = verify_ssl
         self._quality = quality
-
-        # URLs
         self._vpnurl = None
         self._localurl = None
-
-        # Monitoring status
         self._status = None
-
-        # SD Card status
         self._sd_status = None
-
-        # Power status
         self._alim_status = None
-
-        # Is local
         self._is_local = None
 
     def camera_image(self):
@@ -149,7 +140,7 @@ class NetatmoCamera(Camera):
             "identifiers": {(DOMAIN, self._camera_id)},
             "name": self._camera_name,
             "manufacturer": MANUFACTURER,
-            "model": self._camera_type,
+            "model": MODELS[self._camera_type],
         }
 
     @property
@@ -218,29 +209,17 @@ class NetatmoCamera(Camera):
 
     def update(self):
         """Update entity status."""
-
-        # Refresh camera data
         self._data.update()
 
         camera = self._data.camera_data.get_camera(cid=self._camera_id)
 
-        # URLs
         self._vpnurl, self._localurl = self._data.camera_data.camera_urls(
             cid=self._camera_id
         )
-
-        # Monitoring status
         self._status = camera.get("status")
-
-        # SD Card status
         self._sd_status = camera.get("sd_status")
-
-        # Power status
         self._alim_status = camera.get("alim_status")
-
-        # Is local
         self._is_local = camera.get("is_local")
-
         self.is_streaming = self._alim_status == "on"
 
 
