@@ -4,7 +4,7 @@ import logging
 from homeassistant.components.device_tracker.config_entry import TrackerEntity
 from homeassistant.components.device_tracker.const import (
     ATTR_SOURCE_TYPE,
-    ENTITY_ID_FORMAT,
+    DOMAIN,
     SOURCE_TYPE_GPS,
 )
 from homeassistant.const import (
@@ -68,7 +68,7 @@ class OwnTracksEntity(TrackerEntity, RestoreEntity):
         """Set up OwnTracks entity."""
         self._dev_id = dev_id
         self._data = data or {}
-        self.entity_id = ENTITY_ID_FORMAT.format(dev_id)
+        self.entity_id = f"{DOMAIN}.{dev_id}"
 
     @property
     def unique_id(self):
@@ -118,11 +118,6 @@ class OwnTracksEntity(TrackerEntity, RestoreEntity):
         """Return the name of the device."""
         return self._data.get("host_name")
 
-    @property
-    def should_poll(self):
-        """No polling needed."""
-        return False
-
     @property
     def source_type(self):
         """Return the source type, eg gps or router, of the device."""
