@@ -2,9 +2,10 @@
 from datetime import timedelta
 import logging
 
+from panacotta import PanasonicBD
 import voluptuous as vol
 
-from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
+from homeassistant.components.media_player import PLATFORM_SCHEMA, MediaPlayerDevice
 from homeassistant.components.media_player.const import (
     SUPPORT_PAUSE,
     SUPPORT_PLAY,
@@ -53,9 +54,7 @@ class PanasonicBluRay(MediaPlayerDevice):
 
     def __init__(self, ip, name):
         """Initialize the Panasonic Blue-ray device."""
-        import panacotta
-
-        self._device = panacotta.PanasonicBD(ip)
+        self._device = PanasonicBD(ip)
         self._name = name
         self._state = STATE_OFF
         self._position = 0
