@@ -120,7 +120,7 @@ class PandoraMediaPlayer(MediaPlayerDevice):
             _LOGGER.warning(
                 "The pianobar client is not configured to log in. "
                 "Please create a configuration file for it as described at "
-                "https://home-assistant.io/integrations/pandora/"
+                "https://www.home-assistant.io/integrations/pandora/"
             )
             # pass through the email/password prompts to quit cleanly
             self._pianobar.sendcontrol("m")
@@ -384,6 +384,6 @@ def _pianobar_exists():
     _LOGGER.warning(
         "The Pandora integration depends on the Pianobar client, which "
         "cannot be found. Please install using instructions at "
-        "https://home-assistant.io/components/media_player.pandora/"
+        "https://www.home-assistant.io/integrations/media_player.pandora/"
     )
     return False
