@@ -48,12 +48,15 @@ from .const import (
 )
 from .server import PlexServer
 
-MEDIA_PLAYER_SCHEMA = vol.Schema(
-    {
-        vol.Optional(CONF_USE_EPISODE_ART, default=False): cv.boolean,
-        vol.Optional(CONF_SHOW_ALL_CONTROLS, default=False): cv.boolean,
-        vol.Optional(CONF_IGNORE_NEW_SHARED_USERS, default=False): cv.boolean,
-    }
+MEDIA_PLAYER_SCHEMA = vol.All(
+    cv.deprecated(CONF_SHOW_ALL_CONTROLS, invalidation_version="0.110"),
+    vol.Schema(
+        {
+            vol.Optional(CONF_USE_EPISODE_ART, default=False): cv.boolean,
+            vol.Optional(CONF_SHOW_ALL_CONTROLS): cv.boolean,
+            vol.Optional(CONF_IGNORE_NEW_SHARED_USERS, default=False): cv.boolean,
+        }
+    ),
 )
 
 SERVER_CONFIG_SCHEMA = vol.Schema(
@@ -113,6 +116,11 @@ async def async_setup_entry(hass, entry):
     """Set up Plex from a config entry."""
     server_config = entry.data[PLEX_SERVER_CONFIG]
 
+    if entry.unique_id is None:
+        hass.config_entries.async_update_entry(
+            entry, unique_id=entry.data[CONF_SERVER_IDENTIFIER]
+        )
+
     if MP_DOMAIN not in entry.options:
         options = dict(entry.options)
         options.setdefault(
