@@ -101,23 +101,24 @@ class PlexSensor(Entity):
         _LOGGER.debug("Refreshing sensor [%s]", self.unique_id)
         now_playing = []
         for sess in self.sessions:
+            if sess.TYPE == "photo":
+                _LOGGER.debug("Photo session detected, skipping: %s", sess)
+                continue
             user = sess.usernames[0]
             device = sess.players[0].title
             now_playing_user = f"{user} - {device}"
             now_playing_title = ""
 
-            if sess.TYPE == "episode":
+            if sess.TYPE in ["clip", "episode"]:
                 # example:
-                # "Supernatural (2005) - S01 · E13 - Route 666"
+                # "Supernatural (2005) - s01e13 - Route 666"
                 season_title = sess.grandparentTitle
                 if sess.show().year is not None:
-                    season_title += " ({0})".format(sess.show().year)
-                season_episode = "S{0}".format(sess.parentIndex)
-                if sess.index is not None:
-                    season_episode += f" · E{sess.index}"
+                    season_title += f" ({sess.show().year!s})"
+                season_episode = sess.seasonEpisode
                 episode_title = sess.title
-                now_playing_title = "{0} - {1} - {2}".format(
-                    season_title, season_episode, episode_title
+                now_playing_title = (
+                    f"{season_title} - {season_episode} - {episode_title}"
                 )
             elif sess.TYPE == "track":
                 # example:
@@ -125,9 +126,7 @@ class PlexSensor(Entity):
                 track_artist = sess.grandparentTitle
                 track_album = sess.parentTitle
                 track_title = sess.title
-                now_playing_title = "{0} - {1} - {2}".format(
-                    track_artist, track_album, track_title
-                )
+                now_playing_title = f"{track_artist} - {track_album} - {track_title}"
             else:
                 # example:
                 # "picture_of_last_summer_camp (2015)"
@@ -139,3 +138,17 @@ class PlexSensor(Entity):
             now_playing.append((now_playing_user, now_playing_title))
         self._state = len(self.sessions)
         self._now_playing = now_playing
+
+    @property
+    def device_info(self):
+        """Return a device description for device registry."""
+        if self.unique_id is None:
+            return None
+
+        return {
+            "identifiers": {(PLEX_DOMAIN, self._server.machine_identifier)},
+            "manufacturer": "Plex",
+            "model": "Plex Media Server",
+            "name": "Activity Sensor",
+            "sw_version": self._server.version,
+        }
