@@ -10,7 +10,6 @@ from homeassistant.helpers.event import track_state_change
 from homeassistant.util.distance import convert
 from homeassistant.util.location import distance
 
-
 # mypy: allow-untyped-defs, no-check-untyped-defs
 
 _LOGGER = logging.getLogger(__name__)
@@ -269,7 +268,7 @@ class Proximity(Entity):
         self.nearest = entity_name
         self.schedule_update_ha_state()
         _LOGGER.debug(
-            "proximity.%s update entity: distance=%s: direction=%s: " "device=%s",
+            "proximity.%s update entity: distance=%s: direction=%s: device=%s",
             self.friendly_name,
             round(dist_to_zone),
             direction_of_travel,
