@@ -8,7 +8,7 @@ DOMAIN = "ps4"
 GAMES_FILE = ".ps4-games.json"
 PS4_DATA = "ps4_data"
 
-COMMANDS = ("up", "down", "right", "left", "enter", "back", "option", "ps")
+COMMANDS = ("up", "down", "right", "left", "enter", "back", "option", "ps", "ps_hold")
 
 # Deprecated used for logger/backwards compatibility from 0.89
 REGIONS = ["R1", "R2", "R3", "R4", "R5"]
