@@ -11,6 +11,9 @@ from homeassistant.const import (
     CONF_PASSWORD,
     CONF_SCAN_INTERVAL,
     CONF_USERNAME,
+    TIME_DAYS,
+    TIME_MINUTES,
+    UNIT_PERCENTAGE,
 )
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.dispatcher import async_dispatcher_connect, dispatcher_send
@@ -56,13 +59,13 @@ ICON_MAP = {
 
 UNIT_OF_MEASUREMENT_MAP = {
     "auto_watering": "",
-    "battery": "%",
+    "battery": UNIT_PERCENTAGE,
     "is_watering": "",
     "manual_watering": "",
     "next_cycle": "",
-    "rain_delay": "days",
+    "rain_delay": TIME_DAYS,
     "status": "",
-    "watering_time": "min",
+    "watering_time": TIME_MINUTES,
 }
 
 BINARY_SENSORS = ["is_watering", "status"]
