@@ -9,7 +9,6 @@ from homeassistant.components.media_player.const import (
     MEDIA_TYPE_MOVIE,
     SUPPORT_NEXT_TRACK,
     SUPPORT_PLAY,
-    SUPPORT_PLAY_MEDIA,
     SUPPORT_PREVIOUS_TRACK,
     SUPPORT_SELECT_SOURCE,
     SUPPORT_TURN_OFF,
@@ -25,14 +24,13 @@ from homeassistant.const import (
     STATE_STANDBY,
 )
 
-DEFAULT_PORT = 8060
+from .const import DEFAULT_PORT
 
 _LOGGER = logging.getLogger(__name__)
 
 SUPPORT_ROKU = (
     SUPPORT_PREVIOUS_TRACK
     | SUPPORT_NEXT_TRACK
-    | SUPPORT_PLAY_MEDIA
     | SUPPORT_VOLUME_SET
     | SUPPORT_VOLUME_MUTE
     | SUPPORT_SELECT_SOURCE
@@ -61,6 +59,7 @@ class RokuDevice(MediaPlayerDevice):
         self.ip_address = host
         self.channels = []
         self.current_app = None
+        self._available = False
         self._device_info = {}
         self._power_state = "Unknown"
 
@@ -76,7 +75,10 @@ class RokuDevice(MediaPlayerDevice):
                 self.current_app = self.roku.current_app
             else:
                 self.current_app = None
+
+            self._available = True
         except (requests.exceptions.ConnectionError, requests.exceptions.ReadTimeout):
+            self._available = False
             pass
 
     def get_source_list(self):
@@ -118,9 +120,14 @@ class RokuDevice(MediaPlayerDevice):
         """Flag media player features that are supported."""
         return SUPPORT_ROKU
 
+    @property
+    def available(self):
+        """Return if able to retrieve information from device or not."""
+        return self._available
+
     @property
     def unique_id(self):
-        """Return a unique, HASS-friendly identifier for this entity."""
+        """Return a unique, Home Assistant friendly identifier for this entity."""
         return self._device_info.serial_num
 
     @property
