@@ -61,10 +61,7 @@ async def async_setup(hass, config):
 
     await component.async_setup(config)
     # Ensure Home Assistant platform always loaded.
-    await component.async_setup_platform(
-        HA_DOMAIN, {"platform": "homeasistant", STATES: []}
-    )
-
+    await component.async_setup_platform(HA_DOMAIN, {"platform": HA_DOMAIN, STATES: []})
     component.async_register_entity_service(SERVICE_TURN_ON, {}, "async_activate")
 
     return True
@@ -97,9 +94,6 @@ class Scene(Entity):
         """Activate scene. Try to get entities into requested state."""
         raise NotImplementedError()
 
-    def async_activate(self):
-        """Activate scene. Try to get entities into requested state.
-
-        This method must be run in the event loop and returns a coroutine.
-        """
-        return self.hass.async_add_job(self.activate)
+    async def async_activate(self):
+        """Activate scene. Try to get entities into requested state."""
+        await self.hass.async_add_job(self.activate)
