@@ -242,7 +242,9 @@ class ScriptEntity(ToggleEntity):
         self.object_id = object_id
         self.icon = icon
         self.entity_id = ENTITY_ID_FORMAT.format(object_id)
-        self.script = Script(hass, sequence, name, self.async_update_ha_state)
+        self.script = Script(
+            hass, sequence, name, self.async_update_ha_state, logger=_LOGGER
+        )
 
     @property
     def should_poll(self):
@@ -279,22 +281,15 @@ class ScriptEntity(ToggleEntity):
             {ATTR_NAME: self.script.name, ATTR_ENTITY_ID: self.entity_id},
             context=context,
         )
-        try:
-            await self.script.async_run(kwargs.get(ATTR_VARIABLES), context)
-        except Exception as err:
-            self.script.async_log_exception(
-                _LOGGER, f"Error executing script {self.entity_id}", err
-            )
-            raise err
+        await self.script.async_run(kwargs.get(ATTR_VARIABLES), context)
 
     async def async_turn_off(self, **kwargs):
         """Turn script off."""
-        self.script.async_stop()
+        await self.script.async_stop()
 
     async def async_will_remove_from_hass(self):
         """Stop script and remove service when it will be removed from Home Assistant."""
-        if self.script.is_running:
-            self.script.async_stop()
+        await self.script.async_stop()
 
         # remove service
         self.hass.services.async_remove(DOMAIN, self.object_id)
