@@ -1,10 +1,11 @@
 """Support for the Skybell HD Doorbell."""
 import logging
 
-from requests.exceptions import HTTPError, ConnectTimeout
+from requests.exceptions import ConnectTimeout, HTTPError
+from skybellpy import Skybell
 import voluptuous as vol
 
-from homeassistant.const import ATTR_ATTRIBUTION, CONF_USERNAME, CONF_PASSWORD
+from homeassistant.const import ATTR_ATTRIBUTION, CONF_PASSWORD, CONF_USERNAME
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
 
@@ -39,8 +40,6 @@ def setup(hass, config):
     password = conf.get(CONF_PASSWORD)
 
     try:
-        from skybellpy import Skybell
-
         cache = hass.config.path(DEFAULT_CACHEDB)
         skybell = Skybell(
             username=username, password=password, get_devices=True, cache_path=cache
