@@ -5,6 +5,7 @@ from typing import Optional, Sequence
 from pysmartthings import Attribute, Capability
 
 from homeassistant.const import (
+    CONCENTRATION_PARTS_PER_MILLION,
     DEVICE_CLASS_BATTERY,
     DEVICE_CLASS_HUMIDITY,
     DEVICE_CLASS_ILLUMINANCE,
@@ -15,6 +16,7 @@ from homeassistant.const import (
     POWER_WATT,
     TEMP_CELSIUS,
     TEMP_FAHRENHEIT,
+    UNIT_PERCENTAGE,
 )
 
 from . import SmartThingsEntity
@@ -33,8 +35,10 @@ CAPABILITY_TO_SENSORS = {
         Map(Attribute.air_quality, "Air Quality", "CAQI", None)
     ],
     Capability.alarm: [Map(Attribute.alarm, "Alarm", None, None)],
-    Capability.audio_volume: [Map(Attribute.volume, "Volume", "%", None)],
-    Capability.battery: [Map(Attribute.battery, "Battery", "%", DEVICE_CLASS_BATTERY)],
+    Capability.audio_volume: [Map(Attribute.volume, "Volume", UNIT_PERCENTAGE, None)],
+    Capability.battery: [
+        Map(Attribute.battery, "Battery", UNIT_PERCENTAGE, DEVICE_CLASS_BATTERY)
+    ],
     Capability.body_mass_index_measurement: [
         Map(Attribute.bmi_measurement, "Body Mass Index", "kg/m^2", None)
     ],
@@ -42,13 +46,23 @@ CAPABILITY_TO_SENSORS = {
         Map(Attribute.body_weight_measurement, "Body Weight", MASS_KILOGRAMS, None)
     ],
     Capability.carbon_dioxide_measurement: [
-        Map(Attribute.carbon_dioxide, "Carbon Dioxide Measurement", "ppm", None)
+        Map(
+            Attribute.carbon_dioxide,
+            "Carbon Dioxide Measurement",
+            CONCENTRATION_PARTS_PER_MILLION,
+            None,
+        )
     ],
     Capability.carbon_monoxide_detector: [
         Map(Attribute.carbon_monoxide, "Carbon Monoxide Detector", None, None)
     ],
     Capability.carbon_monoxide_measurement: [
-        Map(Attribute.carbon_monoxide_level, "Carbon Monoxide Measurement", "ppm", None)
+        Map(
+            Attribute.carbon_monoxide_level,
+            "Carbon Monoxide Measurement",
+            CONCENTRATION_PARTS_PER_MILLION,
+            None,
+        )
     ],
     Capability.dishwasher_operating_state: [
         Map(Attribute.machine_state, "Dishwasher Machine State", None, None),
@@ -82,18 +96,23 @@ CAPABILITY_TO_SENSORS = {
         Map(
             Attribute.equivalent_carbon_dioxide_measurement,
             "Equivalent Carbon Dioxide Measurement",
-            "ppm",
+            CONCENTRATION_PARTS_PER_MILLION,
             None,
         )
     ],
     Capability.formaldehyde_measurement: [
-        Map(Attribute.formaldehyde_level, "Formaldehyde Measurement", "ppm", None)
+        Map(
+            Attribute.formaldehyde_level,
+            "Formaldehyde Measurement",
+            CONCENTRATION_PARTS_PER_MILLION,
+            None,
+        )
     ],
     Capability.illuminance_measurement: [
         Map(Attribute.illuminance, "Illuminance", "lux", DEVICE_CLASS_ILLUMINANCE)
     ],
     Capability.infrared_level: [
-        Map(Attribute.infrared_level, "Infrared Level", "%", None)
+        Map(Attribute.infrared_level, "Infrared Level", UNIT_PERCENTAGE, None)
     ],
     Capability.media_input_source: [
         Map(Attribute.input_source, "Media Input Source", None, None)
@@ -131,7 +150,7 @@ CAPABILITY_TO_SENSORS = {
         Map(
             Attribute.humidity,
             "Relative Humidity Measurement",
-            "%",
+            UNIT_PERCENTAGE,
             DEVICE_CLASS_HUMIDITY,
         )
     ],
@@ -203,7 +222,12 @@ CAPABILITY_TO_SENSORS = {
     Capability.three_axis: [],
     Capability.tv_channel: [Map(Attribute.tv_channel, "Tv Channel", None, None)],
     Capability.tvoc_measurement: [
-        Map(Attribute.tvoc_level, "Tvoc Measurement", "ppm", None)
+        Map(
+            Attribute.tvoc_level,
+            "Tvoc Measurement",
+            CONCENTRATION_PARTS_PER_MILLION,
+            None,
+        )
     ],
     Capability.ultraviolet_index: [
         Map(Attribute.ultraviolet_index, "Ultraviolet Index", None, None)
