@@ -21,11 +21,6 @@ from .const import (
 _LOGGER = logging.getLogger(__name__)
 
 
-async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
-    """Old configuration."""
-    pass
-
-
 async def async_setup_entry(hass, entry, async_add_entities):
     """Add an solarEdge entry."""
     # Add the needed sensors to hass
