@@ -2,6 +2,7 @@
 import logging
 from typing import Optional
 
+from pysupla import SuplaAPI
 import voluptuous as vol
 
 from homeassistant.const import CONF_ACCESS_TOKEN
@@ -17,8 +18,10 @@ CONF_SERVERS = "servers"
 
 SUPLA_FUNCTION_HA_CMP_MAP = {
     "CONTROLLINGTHEROLLERSHUTTER": "cover",
+    "CONTROLLINGTHEGATE": "cover",
     "LIGHTSWITCH": "switch",
 }
+SUPLA_FUNCTION_NONE = "NONE"
 SUPLA_CHANNELS = "supla_channels"
 SUPLA_SERVERS = "supla_servers"
 
@@ -38,7 +41,6 @@ CONFIG_SCHEMA = vol.Schema(
 
 def setup(hass, base_config):
     """Set up the Supla component."""
-    from pysupla import SuplaAPI
 
     server_confs = base_config[DOMAIN][CONF_SERVERS]
 
@@ -86,6 +88,14 @@ def discover_devices(hass, hass_config):
 
         for channel in server.get_channels(include=["iodevice"]):
             channel_function = channel["function"]["name"]
+            if channel_function == SUPLA_FUNCTION_NONE:
+                _LOGGER.debug(
+                    "Ignored function: %s, channel id: %s",
+                    channel_function,
+                    channel["id"],
+                )
+                continue
+
             component_name = SUPLA_FUNCTION_HA_CMP_MAP.get(channel_function)
 
             if component_name is None:
@@ -130,6 +140,16 @@ class SuplaChannel(Entity):
         """Return the name of the device."""
         return self.channel_data["caption"]
 
+    @property
+    def available(self) -> bool:
+        """Return True if entity is available."""
+        if self.channel_data is None:
+            return False
+        state = self.channel_data.get("state")
+        if state is None:
+            return False
+        return state.get("connected")
+
     def action(self, action, **add_pars):
         """
         Run server action.
