@@ -1,17 +1,17 @@
 """Support for Sure Petcare cat/pet flaps."""
 import logging
+from typing import Any, Dict, List
 
 from surepy import (
     SurePetcare,
     SurePetcareAuthenticationError,
     SurePetcareError,
-    SureThingID,
+    SureProductID,
 )
 import voluptuous as vol
 
 from homeassistant.const import (
     CONF_ID,
-    CONF_NAME,
     CONF_PASSWORD,
     CONF_SCAN_INTERVAL,
     CONF_TYPE,
@@ -23,9 +23,11 @@ from homeassistant.helpers.dispatcher import async_dispatcher_send
 from homeassistant.helpers.event import async_track_time_interval
 
 from .const import (
+    CONF_FEEDERS,
     CONF_FLAPS,
-    CONF_HOUSEHOLD_ID,
+    CONF_PARENT,
     CONF_PETS,
+    CONF_PRODUCT_ID,
     DATA_SURE_PETCARE,
     DEFAULT_SCAN_INTERVAL,
     DOMAIN,
@@ -36,23 +38,19 @@ from .const import (
 _LOGGER = logging.getLogger(__name__)
 
 
-FLAP_SCHEMA = vol.Schema(
-    {vol.Required(CONF_ID): cv.positive_int, vol.Required(CONF_NAME): cv.string}
-)
-
-PET_SCHEMA = vol.Schema(
-    {vol.Required(CONF_ID): cv.positive_int, vol.Required(CONF_NAME): cv.string}
-)
-
 CONFIG_SCHEMA = vol.Schema(
     {
         DOMAIN: vol.Schema(
             {
                 vol.Required(CONF_USERNAME): cv.string,
                 vol.Required(CONF_PASSWORD): cv.string,
-                vol.Required(CONF_HOUSEHOLD_ID): cv.positive_int,
-                vol.Required(CONF_FLAPS): vol.All(cv.ensure_list, [FLAP_SCHEMA]),
-                vol.Required(CONF_PETS): vol.All(cv.ensure_list, [PET_SCHEMA]),
+                vol.Optional(CONF_FEEDERS, default=[]): vol.All(
+                    cv.ensure_list, [cv.positive_int]
+                ),
+                vol.Optional(CONF_FLAPS, default=[]): vol.All(
+                    cv.ensure_list, [cv.positive_int]
+                ),
+                vol.Optional(CONF_PETS): vol.All(cv.ensure_list, [cv.positive_int]),
                 vol.Optional(
                     CONF_SCAN_INTERVAL, default=DEFAULT_SCAN_INTERVAL
                 ): cv.time_period,
@@ -63,7 +61,7 @@ CONFIG_SCHEMA = vol.Schema(
 )
 
 
-async def async_setup(hass, config):
+async def async_setup(hass, config) -> bool:
     """Initialize the Sure Petcare component."""
     conf = config[DOMAIN]
 
@@ -78,11 +76,10 @@ async def async_setup(hass, config):
         surepy = SurePetcare(
             conf[CONF_USERNAME],
             conf[CONF_PASSWORD],
-            conf[CONF_HOUSEHOLD_ID],
             hass.loop,
             async_get_clientsession(hass),
         )
-        await surepy.refresh_token()
+        await surepy.get_data()
     except SurePetcareAuthenticationError:
         _LOGGER.error("Unable to connect to surepetcare.io: Wrong credentials!")
         return False
@@ -90,32 +87,44 @@ async def async_setup(hass, config):
         _LOGGER.error("Unable to connect to surepetcare.io: Wrong %s!", error)
         return False
 
-    # add flaps
+    # add feeders
     things = [
-        {
-            CONF_NAME: flap[CONF_NAME],
-            CONF_ID: flap[CONF_ID],
-            CONF_TYPE: SureThingID.FLAP.name,
-        }
-        for flap in conf[CONF_FLAPS]
+        {CONF_ID: feeder, CONF_TYPE: SureProductID.FEEDER}
+        for feeder in conf[CONF_FEEDERS]
     ]
 
-    # add pets
+    # add flaps (don't differentiate between CAT and PET for now)
     things.extend(
         [
-            {
-                CONF_NAME: pet[CONF_NAME],
-                CONF_ID: pet[CONF_ID],
-                CONF_TYPE: SureThingID.PET.name,
-            }
-            for pet in conf[CONF_PETS]
+            {CONF_ID: flap, CONF_TYPE: SureProductID.PET_FLAP}
+            for flap in conf[CONF_FLAPS]
         ]
     )
 
-    spc = hass.data[DATA_SURE_PETCARE][SPC] = SurePetcareAPI(
-        hass, surepy, things, conf[CONF_HOUSEHOLD_ID]
+    # discover hubs the flaps/feeders are connected to
+    for device in things.copy():
+        device_data = await surepy.device(device[CONF_ID])
+        if (
+            CONF_PARENT in device_data
+            and device_data[CONF_PARENT][CONF_PRODUCT_ID] == SureProductID.HUB
+            and device_data[CONF_PARENT][CONF_ID] not in things
+        ):
+            things.append(
+                {
+                    CONF_ID: device_data[CONF_PARENT][CONF_ID],
+                    CONF_TYPE: SureProductID.HUB,
+                }
+            )
+
+    # add pets
+    things.extend(
+        [{CONF_ID: pet, CONF_TYPE: SureProductID.PET} for pet in conf[CONF_PETS]]
     )
 
+    _LOGGER.debug("Devices and Pets to setup: %s", things)
+
+    spc = hass.data[DATA_SURE_PETCARE][SPC] = SurePetcareAPI(hass, surepy, things)
+
     # initial update
     await spc.async_update()
 
@@ -135,16 +144,18 @@ async def async_setup(hass, config):
 class SurePetcareAPI:
     """Define a generic Sure Petcare object."""
 
-    def __init__(self, hass, surepy, ids, household_id):
+    def __init__(self, hass, surepy: SurePetcare, ids: List[Dict[str, Any]]) -> None:
         """Initialize the Sure Petcare object."""
         self.hass = hass
         self.surepy = surepy
-        self.household_id = household_id
         self.ids = ids
-        self.states = {}
+        self.states: Dict[str, Any] = {}
 
-    async def async_update(self, args=None):
+    async def async_update(self, arg: Any = None) -> None:
         """Refresh Sure Petcare data."""
+
+        await self.surepy.get_data()
+
         for thing in self.ids:
             sure_id = thing[CONF_ID]
             sure_type = thing[CONF_TYPE]
@@ -152,10 +163,15 @@ class SurePetcareAPI:
             try:
                 type_state = self.states.setdefault(sure_type, {})
 
-                if sure_type == SureThingID.FLAP.name:
-                    type_state[sure_id] = await self.surepy.get_flap_data(sure_id)
-                elif sure_type == SureThingID.PET.name:
-                    type_state[sure_id] = await self.surepy.get_pet_data(sure_id)
+                if sure_type in [
+                    SureProductID.CAT_FLAP,
+                    SureProductID.PET_FLAP,
+                    SureProductID.FEEDER,
+                    SureProductID.HUB,
+                ]:
+                    type_state[sure_id] = await self.surepy.device(sure_id)
+                elif sure_type == SureProductID.PET:
+                    type_state[sure_id] = await self.surepy.pet(sure_id)
 
             except SurePetcareError as error:
                 _LOGGER.error("Unable to retrieve data from surepetcare.io: %s", error)
