@@ -11,8 +11,11 @@ SPC = "spc"
 SUREPY = "surepy"
 
 CONF_HOUSEHOLD_ID = "household_id"
+CONF_FEEDERS = "feeders"
 CONF_FLAPS = "flaps"
+CONF_PARENT = "parent"
 CONF_PETS = "pets"
+CONF_PRODUCT_ID = "product_id"
 CONF_DATA = "data"
 
 SURE_IDS = "sure_ids"
