@@ -4,7 +4,13 @@ from typing import Any, Dict, Optional
 
 from surepy import SureLockStateID, SureProductID
 
-from homeassistant.const import ATTR_VOLTAGE, CONF_ID, CONF_TYPE, DEVICE_CLASS_BATTERY
+from homeassistant.const import (
+    ATTR_VOLTAGE,
+    CONF_ID,
+    CONF_TYPE,
+    DEVICE_CLASS_BATTERY,
+    UNIT_PERCENTAGE,
+)
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity import Entity
@@ -40,10 +46,7 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
         ]:
             entities.append(SureBattery(entity[CONF_ID], sure_type, spc))
 
-        if sure_type in [
-            SureProductID.CAT_FLAP,
-            SureProductID.PET_FLAP,
-        ]:
+        if sure_type in [SureProductID.CAT_FLAP, SureProductID.PET_FLAP]:
             entities.append(Flap(entity[CONF_ID], sure_type, spc))
 
     async_add_entities(entities, True)
@@ -52,9 +55,7 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
 class SurePetcareSensor(Entity):
     """A binary sensor implementation for Sure Petcare Entities."""
 
-    def __init__(
-        self, _id: int, sure_type: SureProductID, spc: SurePetcareAPI,
-    ):
+    def __init__(self, _id: int, sure_type: SureProductID, spc: SurePetcareAPI):
         """Initialize a Sure Petcare sensor."""
 
         self._id = _id
@@ -128,9 +129,7 @@ class Flap(SurePetcareSensor):
         """Return the state attributes of the device."""
         attributes = None
         if self._state:
-            attributes = {
-                "learn_mode": bool(self._state["learn_mode"]),
-            }
+            attributes = {"learn_mode": bool(self._state["learn_mode"])}
 
         return attributes
 
@@ -182,4 +181,4 @@ class SureBattery(SurePetcareSensor):
     @property
     def unit_of_measurement(self) -> str:
         """Return the unit of measurement."""
-        return "%"
+        return UNIT_PERCENTAGE
