@@ -103,7 +103,7 @@ class SwitchDevice(ToggleEntity):
 
         for prop, attr in PROP_TO_ATTR.items():
             value = getattr(self, prop)
-            if value:
+            if value is not None:
                 data[attr] = value
 
         return data
