@@ -2,7 +2,7 @@
 from datetime import timedelta
 import logging
 
-from homeassistant.const import ATTR_BATTERY_LEVEL, TEMP_CELSIUS
+from homeassistant.const import ATTR_BATTERY_LEVEL, TEMP_CELSIUS, UNIT_PERCENTAGE
 from homeassistant.helpers.entity import Entity
 
 from . import DOMAIN as TAHOMA_DOMAIN, TahomaDevice
@@ -51,7 +51,7 @@ class TahomaSensor(TahomaDevice, Entity):
         if self.tahoma_device.type == "io:LightIOSystemSensor":
             return "lx"
         if self.tahoma_device.type == "Humidity Sensor":
-            return "%"
+            return UNIT_PERCENTAGE
         if self.tahoma_device.type == "rtds:RTDSContactSensor":
             return None
         if self.tahoma_device.type == "rtds:RTDSMotionSensor":
