@@ -7,7 +7,10 @@ from homeassistant.const import (
     DEVICE_CLASS_ILLUMINANCE,
     DEVICE_CLASS_TEMPERATURE,
     POWER_WATT,
+    SPEED_METERS_PER_SECOND,
     TEMP_CELSIUS,
+    TIME_HOURS,
+    UNIT_PERCENTAGE,
 )
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 
@@ -35,12 +38,12 @@ SENSOR_TYPES = {
         None,
         DEVICE_CLASS_TEMPERATURE,
     ],
-    SENSOR_TYPE_HUMIDITY: ["Humidity", "%", None, DEVICE_CLASS_HUMIDITY],
-    SENSOR_TYPE_RAINRATE: ["Rain rate", "mm/h", "mdi:water", None],
+    SENSOR_TYPE_HUMIDITY: ["Humidity", UNIT_PERCENTAGE, None, DEVICE_CLASS_HUMIDITY],
+    SENSOR_TYPE_RAINRATE: ["Rain rate", f"mm/{TIME_HOURS}", "mdi:water", None],
     SENSOR_TYPE_RAINTOTAL: ["Rain total", "mm", "mdi:water", None],
     SENSOR_TYPE_WINDDIRECTION: ["Wind direction", "", "", None],
-    SENSOR_TYPE_WINDAVERAGE: ["Wind average", "m/s", "", None],
-    SENSOR_TYPE_WINDGUST: ["Wind gust", "m/s", "", None],
+    SENSOR_TYPE_WINDAVERAGE: ["Wind average", SPEED_METERS_PER_SECOND, "", None],
+    SENSOR_TYPE_WINDGUST: ["Wind gust", SPEED_METERS_PER_SECOND, "", None],
     SENSOR_TYPE_UV: ["UV", "UV", "", None],
     SENSOR_TYPE_WATT: ["Power", POWER_WATT, "", None],
     SENSOR_TYPE_LUMINANCE: ["Luminance", "lx", None, DEVICE_CLASS_ILLUMINANCE],
