@@ -6,7 +6,6 @@ import re
 import requests
 import voluptuous as vol
 
-import homeassistant.helpers.config_validation as cv
 from homeassistant.components.device_tracker import (
     DOMAIN,
     PLATFORM_SCHEMA,
@@ -14,12 +13,13 @@ from homeassistant.components.device_tracker import (
 )
 from homeassistant.const import (
     CONF_HOST,
+    CONF_PASSWORD,
     CONF_PORT,
     CONF_SSL,
-    CONF_VERIFY_SSL,
-    CONF_PASSWORD,
     CONF_USERNAME,
+    CONF_VERIFY_SSL,
 )
+import homeassistant.helpers.config_validation as cv
 
 CONF_HTTP_ID = "http_id"
 
@@ -124,7 +124,7 @@ class TomatoDeviceScanner(DeviceScanner):
             # We get this if we could not connect to the router or
             # an invalid http_id was supplied.
             _LOGGER.exception(
-                "Failed to connect to the router or " "invalid http_id supplied"
+                "Failed to connect to the router or invalid http_id supplied"
             )
             return False
 
