@@ -1,8 +1,4 @@
-"""Support for UK public transport data provided by transportapi.com.
-
-For more details about this platform, please refer to the documentation at
-https://home-assistant.io/components/sensor.uk_transport/
-"""
+"""Support for UK public transport data provided by transportapi.com."""
 from datetime import datetime, timedelta
 import logging
 import re
@@ -11,7 +7,7 @@ import requests
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import CONF_MODE
+from homeassistant.const import CONF_MODE, TIME_MINUTES
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
 from homeassistant.util import Throttle
@@ -123,7 +119,7 @@ class UkTransportSensor(Entity):
     @property
     def unit_of_measurement(self):
         """Return the unit this state is expressed in."""
-        return "min"
+        return TIME_MINUTES
 
     @property
     def icon(self):
