@@ -25,11 +25,9 @@ CONF_DONT_TRACK_DEVICES = "dont_track_devices"
 CONF_DONT_TRACK_WIRED_CLIENTS = "dont_track_wired_clients"
 
 DEFAULT_ALLOW_BANDWIDTH_SENSORS = False
-DEFAULT_BLOCK_CLIENTS = []
 DEFAULT_TRACK_CLIENTS = True
 DEFAULT_TRACK_DEVICES = True
 DEFAULT_TRACK_WIRED_CLIENTS = True
 DEFAULT_DETECTION_TIME = 300
-DEFAULT_SSID_FILTER = []
 
 ATTR_MANUFACTURER = "Ubiquiti Networks"
