@@ -1,19 +1,18 @@
 """Track devices using UniFi controllers."""
 import logging
-from pprint import pformat
 
 from homeassistant.components.device_tracker import DOMAIN as DEVICE_TRACKER_DOMAIN
 from homeassistant.components.device_tracker.config_entry import ScannerEntity
 from homeassistant.components.device_tracker.const import SOURCE_TYPE_ROUTER
 from homeassistant.components.unifi.config_flow import get_controller_from_config_entry
 from homeassistant.core import callback
-from homeassistant.helpers import entity_registry
 from homeassistant.helpers.device_registry import CONNECTION_NETWORK_MAC
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
-from homeassistant.helpers.entity_registry import DISABLED_CONFIG_ENTRY
+from homeassistant.helpers.event import async_track_point_in_utc_time
 import homeassistant.util.dt as dt_util
 
 from .const import ATTR_MANUFACTURER
+from .unifi_client import UniFiClient
 
 LOGGER = logging.getLogger(__name__)
 
@@ -43,7 +42,11 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     controller = get_controller_from_config_entry(hass, config_entry)
     tracked = {}
 
-    registry = await entity_registry.async_get_registry(hass)
+    option_track_clients = controller.option_track_clients
+    option_track_devices = controller.option_track_devices
+    option_track_wired_clients = controller.option_track_wired_clients
+
+    registry = await hass.helpers.entity_registry.async_get_registry()
 
     # Restore clients that is not a part of active clients list.
     for entity in registry.entities.values():
@@ -65,31 +68,72 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     @callback
     def update_controller():
         """Update the values of the controller."""
-        update_items(controller, async_add_entities, tracked)
+        nonlocal option_track_clients
+        nonlocal option_track_devices
+
+        if not option_track_clients and not option_track_devices:
+            return
+
+        add_entities(controller, async_add_entities, tracked)
 
     controller.listeners.append(
         async_dispatcher_connect(hass, controller.signal_update, update_controller)
     )
 
     @callback
-    def update_disable_on_entities():
-        """Update the values of the controller."""
-        for entity in tracked.values():
+    def options_updated():
+        """Manage entities affected by config entry options."""
+        nonlocal option_track_clients
+        nonlocal option_track_devices
+        nonlocal option_track_wired_clients
 
-            if entity.entity_registry_enabled_default == entity.enabled:
+        update = False
+        remove = set()
+
+        for current_option, config_entry_option, tracker_class in (
+            (option_track_clients, controller.option_track_clients, UniFiClientTracker),
+            (option_track_devices, controller.option_track_devices, UniFiDeviceTracker),
+        ):
+            if current_option == config_entry_option:
                 continue
 
-            disabled_by = None
-            if not entity.entity_registry_enabled_default and entity.enabled:
-                disabled_by = DISABLED_CONFIG_ENTRY
+            if config_entry_option:
+                update = True
+            else:
+                for mac, entity in tracked.items():
+                    if isinstance(entity, tracker_class):
+                        remove.add(mac)
 
-            registry.async_update_entity(
-                entity.registry_entry.entity_id, disabled_by=disabled_by
-            )
+        if (
+            controller.option_track_clients
+            and option_track_wired_clients != controller.option_track_wired_clients
+        ):
+
+            if controller.option_track_wired_clients:
+                update = True
+            else:
+                for mac, entity in tracked.items():
+                    if isinstance(entity, UniFiClientTracker) and entity.is_wired:
+                        remove.add(mac)
+
+        option_track_clients = controller.option_track_clients
+        option_track_devices = controller.option_track_devices
+        option_track_wired_clients = controller.option_track_wired_clients
+
+        for mac in remove:
+            entity = tracked.pop(mac)
+
+            if registry.async_is_registered(entity.entity_id):
+                registry.async_remove(entity.entity_id)
+
+            hass.async_create_task(entity.async_remove())
+
+        if update:
+            update_controller()
 
     controller.listeners.append(
         async_dispatcher_connect(
-            hass, controller.signal_options_update, update_disable_on_entities
+            hass, controller.signal_options_update, options_updated
         )
     )
 
@@ -97,20 +141,25 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
 
 
 @callback
-def update_items(controller, async_add_entities, tracked):
-    """Update tracked device state from the controller."""
+def add_entities(controller, async_add_entities, tracked):
+    """Add new tracker entities from the controller."""
     new_tracked = []
 
-    for items, tracker_class in (
-        (controller.api.clients, UniFiClientTracker),
-        (controller.api.devices, UniFiDeviceTracker),
+    for items, tracker_class, track in (
+        (controller.api.clients, UniFiClientTracker, controller.option_track_clients),
+        (controller.api.devices, UniFiDeviceTracker, controller.option_track_devices),
     ):
+        if not track:
+            continue
 
         for item_id in items:
 
             if item_id in tracked:
-                if tracked[item_id].enabled:
-                    tracked[item_id].async_schedule_update_ha_state()
+                continue
+
+            if tracker_class is UniFiClientTracker and (
+                not controller.option_track_wired_clients and items[item_id].is_wired
+            ):
                 continue
 
             tracked[item_id] = tracker_class(items[item_id], controller)
@@ -120,24 +169,33 @@ def update_items(controller, async_add_entities, tracked):
         async_add_entities(new_tracked)
 
 
-class UniFiClientTracker(ScannerEntity):
+class UniFiClientTracker(UniFiClient, ScannerEntity):
     """Representation of a network client."""
 
     def __init__(self, client, controller):
         """Set up tracked client."""
-        self.client = client
-        self.controller = controller
-        self.is_wired = self.client.mac not in controller.wireless_clients
-        self.wired_bug = None
+        super().__init__(client, controller)
 
+        self.cancel_scheduled_update = None
+        self.is_disconnected = None
+        self.wired_bug = None
         if self.is_wired != self.client.is_wired:
             self.wired_bug = dt_util.utcnow() - self.controller.option_detection_time
 
     @property
-    def entity_registry_enabled_default(self):
-        """Return if the entity should be enabled when first added to the entity registry."""
-        if not self.controller.option_track_clients:
-            return False
+    def is_connected(self):
+        """Return true if the client is connected to the network.
+
+        If connected to unwanted ssid return False.
+        If is_wired and client.is_wired differ it means that the device is offline and UniFi bug shows device as wired.
+        """
+
+        @callback
+        def _scheduled_update(now):
+            """Scheduled callback for update."""
+            self.is_disconnected = True
+            self.cancel_scheduled_update = None
+            self.async_schedule_update_ha_state()
 
         if (
             not self.is_wired
@@ -146,37 +204,28 @@ class UniFiClientTracker(ScannerEntity):
         ):
             return False
 
-        if not self.controller.option_track_wired_clients and self.is_wired:
-            return False
+        if (self.is_wired and self.wired_connection) or (
+            not self.is_wired and self.wireless_connection
+        ):
+            if self.cancel_scheduled_update:
+                self.cancel_scheduled_update()
+                self.cancel_scheduled_update = None
 
-        return True
+            self.is_disconnected = False
 
-    async def async_added_to_hass(self):
-        """Client entity created."""
-        LOGGER.debug("New UniFi client tracker %s (%s)", self.name, self.client.mac)
+        if (self.is_wired and self.wired_connection is False) or (
+            not self.is_wired and self.wireless_connection is False
+        ):
+            if not self.is_disconnected and not self.cancel_scheduled_update:
+                self.cancel_scheduled_update = async_track_point_in_utc_time(
+                    self.hass,
+                    _scheduled_update,
+                    dt_util.utcnow() + self.controller.option_detection_time,
+                )
 
-    async def async_update(self):
-        """Synchronize state with controller.
+        if self.is_disconnected is not None:
+            return not self.is_disconnected
 
-        Make sure to update self.is_wired if client is wireless, there is an issue when clients go offline that they get marked as wired.
-        """
-        await self.controller.request_update()
-
-        if self.is_wired and self.client.mac in self.controller.wireless_clients:
-            self.is_wired = False
-
-        LOGGER.debug(
-            "Updating UniFi tracked client %s\n%s",
-            self.entity_id,
-            pformat(self.client.raw),
-        )
-
-    @property
-    def is_connected(self):
-        """Return true if the client is connected to the network.
-
-        If is_wired and client.is_wired differ it means that the device is offline and UniFi bug shows device as wired.
-        """
         if self.is_wired != self.client.is_wired:
             if not self.wired_bug:
                 self.wired_bug = dt_util.utcnow()
@@ -184,6 +233,11 @@ class UniFiClientTracker(ScannerEntity):
 
         else:
             self.wired_bug = None
+
+            # A client that has never been seen cannot be connected.
+            if self.client.last_seen is None:
+                return False
+
             since_last_seen = dt_util.utcnow() - dt_util.utc_from_timestamp(
                 float(self.client.last_seen)
             )
@@ -198,26 +252,11 @@ class UniFiClientTracker(ScannerEntity):
         """Return the source type of the client."""
         return SOURCE_TYPE_ROUTER
 
-    @property
-    def name(self) -> str:
-        """Return the name of the client."""
-        return self.client.name or self.client.hostname
-
     @property
     def unique_id(self) -> str:
         """Return a unique identifier for this client."""
         return f"{self.client.mac}-{self.controller.site}"
 
-    @property
-    def available(self) -> bool:
-        """Return if controller is available."""
-        return self.controller.available
-
-    @property
-    def device_info(self):
-        """Return a client description for device registry."""
-        return {"connections": {(CONNECTION_NETWORK_MAC, self.client.mac)}}
-
     @property
     def device_state_attributes(self):
         """Return the client state attributes."""
@@ -239,28 +278,31 @@ class UniFiDeviceTracker(ScannerEntity):
         """Set up tracked device."""
         self.device = device
         self.controller = controller
-
-    @property
-    def entity_registry_enabled_default(self):
-        """Return if the entity should be enabled when first added to the entity registry."""
-        if self.controller.option_track_devices:
-            return True
-        return False
+        self.listeners = []
 
     async def async_added_to_hass(self):
         """Subscribe to device events."""
         LOGGER.debug("New UniFi device tracker %s (%s)", self.name, self.device.mac)
-
-    async def async_update(self):
-        """Synchronize state with controller."""
-        await self.controller.request_update()
-
-        LOGGER.debug(
-            "Updating UniFi tracked device %s\n%s",
-            self.entity_id,
-            pformat(self.device.raw),
+        self.device.register_callback(self.async_update_callback)
+        self.listeners.append(
+            async_dispatcher_connect(
+                self.hass, self.controller.signal_reachable, self.async_update_callback
+            )
         )
 
+    async def async_will_remove_from_hass(self) -> None:
+        """Disconnect device object when removed."""
+        self.device.remove_callback(self.async_update_callback)
+        for unsub_dispatcher in self.listeners:
+            unsub_dispatcher()
+
+    @callback
+    def async_update_callback(self):
+        """Update the sensor's state."""
+        LOGGER.debug("Updating UniFi tracked device %s", self.entity_id)
+
+        self.async_schedule_update_ha_state()
+
     @property
     def is_connected(self):
         """Return true if the device is connected to the network."""
@@ -325,3 +367,8 @@ class UniFiDeviceTracker(ScannerEntity):
             attributes["upgradable"] = self.device.upgradable
 
         return attributes
+
+    @property
+    def should_poll(self):
+        """No polling needed."""
+        return True
