@@ -4,7 +4,6 @@ import logging
 from homeassistant.components.switch import SwitchDevice
 from homeassistant.components.unifi.config_flow import get_controller_from_config_entry
 from homeassistant.core import callback
-from homeassistant.helpers import entity_registry
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.restore_state import RestoreEntity
 
@@ -30,10 +29,12 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     switches = {}
     switches_off = []
 
-    registry = await entity_registry.async_get_registry(hass)
+    option_block_clients = controller.option_block_clients
+
+    entity_registry = await hass.helpers.entity_registry.async_get_registry()
 
     # Restore clients that is not a part of active clients list.
-    for entity in registry.entities.values():
+    for entity in entity_registry.entities.values():
 
         if (
             entity.config_entry_id == config_entry.entry_id
@@ -61,6 +62,43 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
         async_dispatcher_connect(hass, controller.signal_update, update_controller)
     )
 
+    @callback
+    def options_updated():
+        """Manage entities affected by config entry options."""
+        nonlocal option_block_clients
+
+        update = set()
+        remove = set()
+
+        if option_block_clients != controller.option_block_clients:
+            option_block_clients = controller.option_block_clients
+
+            for block_client_id, entity in switches.items():
+                if not isinstance(entity, UniFiBlockClientSwitch):
+                    continue
+
+                if entity.client.mac in option_block_clients:
+                    update.add(block_client_id)
+                else:
+                    remove.add(block_client_id)
+
+            for block_client_id in remove:
+                entity = switches.pop(block_client_id)
+
+                if entity_registry.async_is_registered(entity.entity_id):
+                    entity_registry.async_remove(entity.entity_id)
+
+                hass.async_create_task(entity.async_remove())
+
+            if len(update) != len(option_block_clients):
+                update_controller()
+
+    controller.listeners.append(
+        async_dispatcher_connect(
+            hass, controller.signal_options_update, options_updated
+        )
+    )
+
     update_controller()
     switches_off.clear()
 
@@ -74,15 +112,21 @@ def add_entities(controller, async_add_entities, switches, switches_off):
     # block client
     for client_id in controller.option_block_clients:
 
+        client = None
         block_client_id = f"block-{client_id}"
 
         if block_client_id in switches:
             continue
 
-        if client_id not in controller.api.clients_all:
+        if client_id in controller.api.clients:
+            client = controller.api.clients[client_id]
+
+        elif client_id in controller.api.clients_all:
+            client = controller.api.clients_all[client_id]
+
+        if not client:
             continue
 
-        client = controller.api.clients_all[client_id]
         switches[block_client_id] = UniFiBlockClientSwitch(client, controller)
         new_switches.append(switches[block_client_id])
 
@@ -218,7 +262,7 @@ class UniFiPOEClientSwitch(UniFiClient, SwitchDevice, RestoreEntity):
         """Shortcut to the switch port that client is connected to."""
         try:
             return self.device.ports[self.client.sw_port]
-        except TypeError:
+        except (AttributeError, KeyError, TypeError):
             LOGGER.warning(
                 "Entity %s reports faulty device %s or port %s",
                 self.entity_id,
@@ -238,7 +282,7 @@ class UniFiBlockClientSwitch(UniFiClient, SwitchDevice):
     @property
     def is_on(self):
         """Return true if client is allowed to connect."""
-        return not self.client.blocked
+        return not self.is_blocked
 
     async def async_turn_on(self, **kwargs):
         """Turn on connectivity for client."""
@@ -247,3 +291,10 @@ class UniFiBlockClientSwitch(UniFiClient, SwitchDevice):
     async def async_turn_off(self, **kwargs):
         """Turn off connectivity for client."""
         await self.controller.api.clients.async_block(self.client.mac)
+
+    @property
+    def icon(self):
+        """Return the icon to use in the frontend."""
+        if self.is_blocked:
+            return "mdi:network-off"
+        return "mdi:network"
