@@ -7,11 +7,12 @@ import voluptuous as vol
 from homeassistant import config_entries
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import EVENT_HOMEASSISTANT_STOP
-from homeassistant.helpers import config_validation as cv
-from homeassistant.helpers import device_registry as dr
-from homeassistant.helpers import dispatcher
-from homeassistant.helpers.typing import ConfigType
-from homeassistant.helpers.typing import HomeAssistantType
+from homeassistant.helpers import (
+    config_validation as cv,
+    device_registry as dr,
+    dispatcher,
+)
+from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 from homeassistant.util import get_local_ip
 
 from .const import (
@@ -20,10 +21,10 @@ from .const import (
     CONF_HASS,
     CONF_LOCAL_IP,
     CONF_PORTS,
+    DOMAIN,
+    LOGGER as _LOGGER,
     SIGNAL_REMOVE_SENSOR,
 )
-from .const import DOMAIN
-from .const import LOGGER as _LOGGER
 from .device import Device
 
 NOTIFICATION_ID = "upnp_notification"
@@ -150,9 +151,10 @@ async def async_setup_entry(hass: HomeAssistantType, config_entry: ConfigEntry):
         return False
 
     # 'register'/save UDN
-    config_entry.data["udn"] = device.udn
     hass.data[DOMAIN]["devices"][device.udn] = device
-    hass.config_entries.async_update_entry(entry=config_entry, data=config_entry.data)
+    hass.config_entries.async_update_entry(
+        entry=config_entry, data={**config_entry.data, "udn": device.udn}
+    )
 
     # create device registry entry
     device_registry = await dr.async_get_registry(hass)
