@@ -1,16 +1,15 @@
 """Support for USCIS Case Status."""
-import logging
 from datetime import timedelta
+import logging
 
 import uscisstatus
 import voluptuous as vol
 
+from homeassistant.components.sensor import PLATFORM_SCHEMA
+from homeassistant.const import CONF_FRIENDLY_NAME
+from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.entity import Entity
 from homeassistant.util import Throttle
-from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.helpers import config_validation as cv
-from homeassistant.const import CONF_FRIENDLY_NAME
-
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -25,13 +24,13 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
-    """Set up the platform in HASS and Case Information."""
+    """Set up the platform in Home Assistant and Case Information."""
     uscis = UscisSensor(config["case_id"], config[CONF_FRIENDLY_NAME])
     uscis.update()
     if uscis.valid_case_id:
         add_entities([uscis])
     else:
-        _LOGGER.error("Setup USCIS Sensor Fail" " check if your Case ID is Valid")
+        _LOGGER.error("Setup USCIS Sensor Fail check if your Case ID is Valid")
 
 
 class UscisSensor(Entity):
