@@ -23,6 +23,7 @@ CONF_TARIFF = "tariff"
 CONF_TARIFF_ENTITY = "tariff_entity"
 
 ATTR_TARIFF = "tariff"
+ATTR_VALUE = "value"
 
 SIGNAL_START_PAUSE_METER = "utility_meter_start_pause"
 SIGNAL_RESET_METER = "utility_meter_reset"
@@ -30,3 +31,4 @@ SIGNAL_RESET_METER = "utility_meter_reset"
 SERVICE_RESET = "reset"
 SERVICE_SELECT_TARIFF = "select_tariff"
 SERVICE_SELECT_NEXT_TARIFF = "next_tariff"
+SERVICE_CALIBRATE_METER = "calibrate"
