@@ -1,8 +1,7 @@
 """Support for Vera binary sensors."""
 import logging
 
-from homeassistant.components.binary_sensor import (
-    ENTITY_ID_FORMAT, BinarySensorDevice)
+from homeassistant.components.binary_sensor import ENTITY_ID_FORMAT, BinarySensorDevice
 
 from . import VERA_CONTROLLER, VERA_DEVICES, VeraDevice
 
@@ -12,8 +11,12 @@ _LOGGER = logging.getLogger(__name__)
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Perform the setup for Vera controller devices."""
     add_entities(
-        [VeraBinarySensor(device, hass.data[VERA_CONTROLLER])
-         for device in hass.data[VERA_DEVICES]['binary_sensor']], True)
+        [
+            VeraBinarySensor(device, hass.data[VERA_CONTROLLER])
+            for device in hass.data[VERA_DEVICES]["binary_sensor"]
+        ],
+        True,
+    )
 
 
 class VeraBinarySensor(VeraDevice, BinarySensorDevice):
