@@ -1,4 +1,5 @@
 """Viessmann ViCare water_heater device."""
+from datetime import timedelta
 import logging
 
 import requests
@@ -42,6 +43,9 @@ HA_TO_VICARE_HVAC_DHW = {
 
 PYVICARE_ERROR = "error"
 
+# Scan interval of 15 minutes seems to be safe to not hit the ViCare server rate limit
+SCAN_INTERVAL = timedelta(seconds=900)
+
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Create the ViCare water_heater devices."""
@@ -122,7 +126,8 @@ class ViCareWater(WaterHeaterDevice):
         """Set new target temperatures."""
         temp = kwargs.get(ATTR_TEMPERATURE)
         if temp is not None:
-            self._api.setDomesticHotWaterTemperature(self._target_temperature)
+            self._api.setDomesticHotWaterTemperature(temp)
+            self._target_temperature = temp
 
     @property
     def min_temp(self):
