@@ -4,20 +4,13 @@ import logging
 from typing import Callable, List, Optional, Union
 
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import DEVICE_CLASS_TIMESTAMP
+from homeassistant.const import DATA_BYTES, DEVICE_CLASS_TIMESTAMP
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.typing import HomeAssistantType
 from homeassistant.util.dt import utcnow
 
 from . import WLED, WLEDDeviceEntity
-from .const import (
-    ATTR_LED_COUNT,
-    ATTR_MAX_POWER,
-    CURRENT_MA,
-    DATA_BYTES,
-    DATA_WLED_CLIENT,
-    DOMAIN,
-)
+from .const import ATTR_LED_COUNT, ATTR_MAX_POWER, CURRENT_MA, DATA_WLED_CLIENT, DOMAIN
 
 _LOGGER = logging.getLogger(__name__)
 
