@@ -9,27 +9,31 @@ import aiohttp
 import async_timeout
 import voluptuous as vol
 
-from homeassistant.helpers.typing import HomeAssistantType, ConfigType
 from homeassistant.components import sensor
 from homeassistant.components.sensor import PLATFORM_SCHEMA
 from homeassistant.const import (
-    CONF_MONITORED_CONDITIONS,
+    ATTR_ATTRIBUTION,
     CONF_API_KEY,
     CONF_LATITUDE,
     CONF_LONGITUDE,
-    TEMP_FAHRENHEIT,
-    TEMP_CELSIUS,
+    CONF_MONITORED_CONDITIONS,
+    IRRADIATION_WATTS_PER_SQUARE_METER,
+    LENGTH_FEET,
     LENGTH_INCHES,
     LENGTH_KILOMETERS,
     LENGTH_MILES,
-    LENGTH_FEET,
-    ATTR_ATTRIBUTION,
+    SPEED_KILOMETERS_PER_HOUR,
+    SPEED_MILES_PER_HOUR,
+    TEMP_CELSIUS,
+    TEMP_FAHRENHEIT,
+    UNIT_PERCENTAGE,
 )
 from homeassistant.exceptions import PlatformNotReady
-from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
-from homeassistant.util import Throttle
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.entity import Entity
+from homeassistant.helpers.typing import ConfigType, HomeAssistantType
+from homeassistant.util import Throttle
 
 _RESOURCE = "http://api.wunderground.com/api/{}/{}/{}/q/"
 _LOGGER = logging.getLogger(__name__)
@@ -66,7 +70,7 @@ class WUSensorConfig:
         device_state_attributes=None,
         device_class=None,
     ):
-        """Constructor.
+        """Initialize sensor configuration.
 
         :param friendly_name: Friendly name
         :param feature: WU feature. See:
@@ -98,7 +102,7 @@ class WUCurrentConditionsSensorConfig(WUSensorConfig):
         unit_of_measurement: Optional[str] = None,
         device_class=None,
     ):
-        """Constructor.
+        """Initialize current conditions sensor configuration.
 
         :param friendly_name: Friendly name of sensor
         :field: Field name in the "current_observation" dictionary.
@@ -127,7 +131,7 @@ class WUDailyTextForecastSensorConfig(WUSensorConfig):
     def __init__(
         self, period: int, field: str, unit_of_measurement: Optional[str] = None
     ):
-        """Constructor.
+        """Initialize daily text forecast sensor configuration.
 
         :param period: forecast period number
         :param field: field name to use as value
@@ -164,14 +168,14 @@ class WUDailySimpleForecastSensorConfig(WUSensorConfig):
         icon=None,
         device_class=None,
     ):
-        """Constructor.
+        """Initialize daily simple forecast sensor configuration.
 
         :param friendly_name: friendly_name of the sensor
         :param period: forecast period number
         :param field: field name to use as value
         :param wu_unit: "fahrenheit", "celsius", "degrees" etc. see the example json at:
                 https://www.wunderground.com/weather/api/d/docs?d=data/forecast&MR=1
-        :param ha_unit: corresponding unit in home assistant
+        :param ha_unit: corresponding unit in Home Assistant
         """
         super().__init__(
             friendly_name=friendly_name,
@@ -207,7 +211,7 @@ class WUHourlyForecastSensorConfig(WUSensorConfig):
     """Helper for defining sensor configurations for hourly text forecasts."""
 
     def __init__(self, period: int, field: int):
-        """Constructor.
+        """Initialize hourly forecast sensor configuration.
 
         :param period: forecast period number
         :param field: field name to use as value
@@ -274,7 +278,7 @@ class WUAlmanacSensorConfig(WUSensorConfig):
         icon: str,
         device_class=None,
     ):
-        """Constructor.
+        """Initialize almanac sensor configuration.
 
         :param friendly_name: Friendly name
         :param field: value name returned in 'almanac' dict as returned by the WU API
@@ -297,7 +301,7 @@ class WUAlertsSensorConfig(WUSensorConfig):
     """Helper for defining field configuration for alerts."""
 
     def __init__(self, friendly_name: Union[str, Callable]):
-        """Constructor.
+        """Initialiize alerts sensor configuration.
 
         :param friendly_name: Friendly name
         """
@@ -413,7 +417,7 @@ SENSOR_TYPES = {
         "Relative Humidity",
         "conditions",
         value=lambda wu: int(wu.data["current_observation"]["relative_humidity"][:-1]),
-        unit_of_measurement="%",
+        unit_of_measurement=UNIT_PERCENTAGE,
         icon="mdi:water-percent",
         device_class="humidity",
     ),
@@ -421,7 +425,10 @@ SENSOR_TYPES = {
         "Station ID", "station_id", "mdi:home"
     ),
     "solarradiation": WUCurrentConditionsSensorConfig(
-        "Solar Radiation", "solarradiation", "mdi:weather-sunny", "w/m2"
+        "Solar Radiation",
+        "solarradiation",
+        "mdi:weather-sunny",
+        IRRADIATION_WATTS_PER_SQUARE_METER,
     ),
     "temperature_string": WUCurrentConditionsSensorConfig(
         "Temperature Summary", "temperature_string", "mdi:thermometer"
@@ -455,16 +462,16 @@ SENSOR_TYPES = {
         "Wind Direction", "wind_dir", "mdi:weather-windy"
     ),
     "wind_gust_kph": WUCurrentConditionsSensorConfig(
-        "Wind Gust", "wind_gust_kph", "mdi:weather-windy", "kph"
+        "Wind Gust", "wind_gust_kph", "mdi:weather-windy", SPEED_KILOMETERS_PER_HOUR
     ),
     "wind_gust_mph": WUCurrentConditionsSensorConfig(
-        "Wind Gust", "wind_gust_mph", "mdi:weather-windy", "mph"
+        "Wind Gust", "wind_gust_mph", "mdi:weather-windy", SPEED_MILES_PER_HOUR
     ),
     "wind_kph": WUCurrentConditionsSensorConfig(
-        "Wind Speed", "wind_kph", "mdi:weather-windy", "kph"
+        "Wind Speed", "wind_kph", "mdi:weather-windy", SPEED_KILOMETERS_PER_HOUR
     ),
     "wind_mph": WUCurrentConditionsSensorConfig(
-        "Wind Speed", "wind_mph", "mdi:weather-windy", "mph"
+        "Wind Speed", "wind_mph", "mdi:weather-windy", SPEED_MILES_PER_HOUR
     ),
     "wind_string": WUCurrentConditionsSensorConfig(
         "Wind Summary", "wind_string", "mdi:weather-windy"
@@ -738,52 +745,132 @@ SENSOR_TYPES = {
         device_class="temperature",
     ),
     "wind_gust_1d_kph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind Today", 0, "maxwind", "kph", "kph", "mdi:weather-windy"
+        "Max. Wind Today",
+        0,
+        "maxwind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_gust_2d_kph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind Tomorrow", 1, "maxwind", "kph", "kph", "mdi:weather-windy"
+        "Max. Wind Tomorrow",
+        1,
+        "maxwind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_gust_3d_kph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind in 3 Days", 2, "maxwind", "kph", "kph", "mdi:weather-windy"
+        "Max. Wind in 3 Days",
+        2,
+        "maxwind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_gust_4d_kph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind in 4 Days", 3, "maxwind", "kph", "kph", "mdi:weather-windy"
+        "Max. Wind in 4 Days",
+        3,
+        "maxwind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_gust_1d_mph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind Today", 0, "maxwind", "mph", "mph", "mdi:weather-windy"
+        "Max. Wind Today",
+        0,
+        "maxwind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_gust_2d_mph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind Tomorrow", 1, "maxwind", "mph", "mph", "mdi:weather-windy"
+        "Max. Wind Tomorrow",
+        1,
+        "maxwind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_gust_3d_mph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind in 3 Days", 2, "maxwind", "mph", "mph", "mdi:weather-windy"
+        "Max. Wind in 3 Days",
+        2,
+        "maxwind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_gust_4d_mph": WUDailySimpleForecastSensorConfig(
-        "Max. Wind in 4 Days", 3, "maxwind", "mph", "mph", "mdi:weather-windy"
+        "Max. Wind in 4 Days",
+        3,
+        "maxwind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_1d_kph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind Today", 0, "avewind", "kph", "kph", "mdi:weather-windy"
+        "Avg. Wind Today",
+        0,
+        "avewind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_2d_kph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind Tomorrow", 1, "avewind", "kph", "kph", "mdi:weather-windy"
+        "Avg. Wind Tomorrow",
+        1,
+        "avewind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_3d_kph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind in 3 Days", 2, "avewind", "kph", "kph", "mdi:weather-windy"
+        "Avg. Wind in 3 Days",
+        2,
+        "avewind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_4d_kph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind in 4 Days", 3, "avewind", "kph", "kph", "mdi:weather-windy"
+        "Avg. Wind in 4 Days",
+        3,
+        "avewind",
+        SPEED_KILOMETERS_PER_HOUR,
+        SPEED_KILOMETERS_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_1d_mph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind Today", 0, "avewind", "mph", "mph", "mdi:weather-windy"
+        "Avg. Wind Today",
+        0,
+        "avewind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_2d_mph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind Tomorrow", 1, "avewind", "mph", "mph", "mdi:weather-windy"
+        "Avg. Wind Tomorrow",
+        1,
+        "avewind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_3d_mph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind in 3 Days", 2, "avewind", "mph", "mph", "mdi:weather-windy"
+        "Avg. Wind in 3 Days",
+        2,
+        "avewind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "wind_4d_mph": WUDailySimpleForecastSensorConfig(
-        "Avg. Wind in 4 Days", 3, "avewind", "mph", "mph", "mdi:weather-windy"
+        "Avg. Wind in 4 Days",
+        3,
+        "avewind",
+        SPEED_MILES_PER_HOUR,
+        SPEED_MILES_PER_HOUR,
+        "mdi:weather-windy",
     ),
     "precip_1d_mm": WUDailySimpleForecastSensorConfig(
         "Precipitation Intensity Today", 0, "qpf_allday", "mm", "mm", "mdi:umbrella"
@@ -830,16 +917,36 @@ SENSOR_TYPES = {
         "mdi:umbrella",
     ),
     "precip_1d": WUDailySimpleForecastSensorConfig(
-        "Precipitation Probability Today", 0, "pop", None, "%", "mdi:umbrella"
+        "Precipitation Probability Today",
+        0,
+        "pop",
+        None,
+        UNIT_PERCENTAGE,
+        "mdi:umbrella",
     ),
     "precip_2d": WUDailySimpleForecastSensorConfig(
-        "Precipitation Probability Tomorrow", 1, "pop", None, "%", "mdi:umbrella"
+        "Precipitation Probability Tomorrow",
+        1,
+        "pop",
+        None,
+        UNIT_PERCENTAGE,
+        "mdi:umbrella",
     ),
     "precip_3d": WUDailySimpleForecastSensorConfig(
-        "Precipitation Probability in 3 Days", 2, "pop", None, "%", "mdi:umbrella"
+        "Precipitation Probability in 3 Days",
+        2,
+        "pop",
+        None,
+        UNIT_PERCENTAGE,
+        "mdi:umbrella",
     ),
     "precip_4d": WUDailySimpleForecastSensorConfig(
-        "Precipitation Probability in 4 Days", 3, "pop", None, "%", "mdi:umbrella"
+        "Precipitation Probability in 4 Days",
+        3,
+        "pop",
+        None,
+        UNIT_PERCENTAGE,
+        "mdi:umbrella",
     ),
 }
 
@@ -998,7 +1105,7 @@ class WUndergroundSensor(Entity):
         self.rest.request_feature(SENSOR_TYPES[condition].feature)
         # This is only the suggested entity id, it might get changed by
         # the entity registry later.
-        self.entity_id = sensor.ENTITY_ID_FORMAT.format("pws_" + condition)
+        self.entity_id = sensor.ENTITY_ID_FORMAT.format(f"pws_{condition}")
         self._unique_id = f"{unique_id_base},{condition}"
         self._device_class = self._cfg_expand("device_class")
 
@@ -1012,7 +1119,7 @@ class WUndergroundSensor(Entity):
             val = val(self.rest)
         except (KeyError, IndexError, TypeError, ValueError) as err:
             _LOGGER.warning(
-                "Failed to expand cfg from WU API." " Condition: %s Attr: %s Error: %s",
+                "Failed to expand cfg from WU API. Condition: %s Attr: %s Error: %s",
                 self._condition,
                 what,
                 repr(err),
@@ -1122,11 +1229,11 @@ class WUndergroundData:
             self._api_key, "/".join(sorted(self._features)), self._lang
         )
         if self._pws_id:
-            url = url + f"pws:{self._pws_id}"
+            url = f"{url}pws:{self._pws_id}"
         else:
-            url = url + f"{self._latitude},{self._longitude}"
+            url = f"{url}{self._latitude},{self._longitude}"
 
-        return url + ".json"
+        return f"{url}.json"
 
     @Throttle(MIN_TIME_BETWEEN_UPDATES)
     async def async_update(self):
