@@ -5,17 +5,9 @@ from aiowwlln import Client
 import voluptuous as vol
 
 from homeassistant.config_entries import SOURCE_IMPORT
-from homeassistant.const import (
-    CONF_LATITUDE,
-    CONF_LONGITUDE,
-    CONF_RADIUS,
-    CONF_UNIT_SYSTEM,
-    CONF_UNIT_SYSTEM_IMPERIAL,
-    CONF_UNIT_SYSTEM_METRIC,
-)
+from homeassistant.const import CONF_LATITUDE, CONF_LONGITUDE, CONF_RADIUS
 from homeassistant.helpers import aiohttp_client, config_validation as cv
 
-from .config_flow import configured_instances
 from .const import CONF_WINDOW, DATA_CLIENT, DEFAULT_RADIUS, DEFAULT_WINDOW, DOMAIN
 
 _LOGGER = logging.getLogger(__name__)
@@ -28,7 +20,10 @@ CONFIG_SCHEMA = vol.Schema(
                 vol.Optional(CONF_LONGITUDE): cv.longitude,
                 vol.Optional(CONF_RADIUS, default=DEFAULT_RADIUS): cv.positive_int,
                 vol.Optional(CONF_WINDOW, default=DEFAULT_WINDOW): vol.All(
-                    cv.time_period, cv.positive_timedelta
+                    cv.time_period,
+                    cv.positive_timedelta,
+                    lambda value: value.total_seconds(),
+                    vol.Range(min=DEFAULT_WINDOW.total_seconds()),
                 ),
             }
         )
@@ -44,36 +39,9 @@ async def async_setup(hass, config):
 
     conf = config[DOMAIN]
 
-    latitude = conf.get(CONF_LATITUDE, hass.config.latitude)
-    longitude = conf.get(CONF_LONGITUDE, hass.config.longitude)
-
-    identifier = f"{latitude}, {longitude}"
-    if identifier in configured_instances(hass):
-        return True
-
-    if conf[CONF_WINDOW] < DEFAULT_WINDOW:
-        _LOGGER.warning(
-            "Setting a window smaller than %s seconds may cause Home Assistant \
-            to miss events",
-            DEFAULT_WINDOW.total_seconds(),
-        )
-
-    if hass.config.units.name == CONF_UNIT_SYSTEM_IMPERIAL:
-        unit_system = CONF_UNIT_SYSTEM_IMPERIAL
-    else:
-        unit_system = CONF_UNIT_SYSTEM_METRIC
-
     hass.async_create_task(
         hass.config_entries.flow.async_init(
-            DOMAIN,
-            context={"source": SOURCE_IMPORT},
-            data={
-                CONF_LATITUDE: latitude,
-                CONF_LONGITUDE: longitude,
-                CONF_RADIUS: conf[CONF_RADIUS],
-                CONF_WINDOW: conf[CONF_WINDOW],
-                CONF_UNIT_SYSTEM: unit_system,
-            },
+            DOMAIN, context={"source": SOURCE_IMPORT}, data=conf
         )
     )
 
@@ -82,6 +50,15 @@ async def async_setup(hass, config):
 
 async def async_setup_entry(hass, config_entry):
     """Set up the WWLLN as config entry."""
+    if not config_entry.unique_id:
+        hass.config_entries.async_update_entry(
+            config_entry,
+            unique_id=(
+                f"{config_entry.data[CONF_LATITUDE]}, "
+                f"{config_entry.data[CONF_LONGITUDE]}"
+            ),
+        )
+
     hass.data[DOMAIN] = {}
     hass.data[DOMAIN][DATA_CLIENT] = {}
 
