@@ -4,7 +4,8 @@ import logging
 from homeassistant.components.binary_sensor import BinarySensorDevice
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
-from . import DATA_YEELIGHT, DATA_UPDATED
+
+from . import DATA_UPDATED, DATA_YEELIGHT
 
 _LOGGER = logging.getLogger(__name__)
 
