@@ -18,6 +18,7 @@ from homeassistant.const import STATE_ON
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 
+from .core import discovery
 from .core.const import (
     CHANNEL_ACCELEROMETER,
     CHANNEL_OCCUPANCY,
@@ -25,8 +26,8 @@ from .core.const import (
     CHANNEL_ZONE,
     DATA_ZHA,
     DATA_ZHA_DISPATCHERS,
+    SIGNAL_ADD_ENTITIES,
     SIGNAL_ATTR_UPDATED,
-    ZHA_DISCOVERY_NEW,
 )
 from .core.registries import ZHA_ENTITIES
 from .entity import ZhaEntity
@@ -48,45 +49,22 @@ STRICT_MATCH = functools.partial(ZHA_ENTITIES.strict_match, DOMAIN)
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up the Zigbee Home Automation binary sensor from config entry."""
-
-    async def async_discover(discovery_info):
-        await _async_setup_entities(
-            hass, config_entry, async_add_entities, [discovery_info]
-        )
+    entities_to_create = hass.data[DATA_ZHA][DOMAIN]
 
     unsub = async_dispatcher_connect(
-        hass, ZHA_DISCOVERY_NEW.format(DOMAIN), async_discover
+        hass,
+        SIGNAL_ADD_ENTITIES,
+        functools.partial(
+            discovery.async_add_entities, async_add_entities, entities_to_create
+        ),
     )
     hass.data[DATA_ZHA][DATA_ZHA_DISPATCHERS].append(unsub)
 
-    binary_sensors = hass.data.get(DATA_ZHA, {}).get(DOMAIN)
-    if binary_sensors is not None:
-        await _async_setup_entities(
-            hass, config_entry, async_add_entities, binary_sensors.values()
-        )
-        del hass.data[DATA_ZHA][DOMAIN]
-
-
-async def _async_setup_entities(
-    hass, config_entry, async_add_entities, discovery_infos
-):
-    """Set up the ZHA binary sensors."""
-    entities = []
-    for discovery_info in discovery_infos:
-        zha_dev = discovery_info["zha_device"]
-        channels = discovery_info["channels"]
-
-        entity = ZHA_ENTITIES.get_entity(DOMAIN, zha_dev, channels, BinarySensor)
-        if entity:
-            entities.append(entity(**discovery_info))
-
-    if entities:
-        async_add_entities(entities, update_before_add=True)
-
 
 class BinarySensor(ZhaEntity, BinarySensorDevice):
     """ZHA BinarySensor."""
 
+    SENSOR_ATTR = None
     DEVICE_CLASS = None
 
     def __init__(self, unique_id, zha_device, channels, **kwargs):
@@ -126,22 +104,27 @@ class BinarySensor(ZhaEntity, BinarySensorDevice):
         return self._device_class
 
     @callback
-    def async_set_state(self, state):
+    def async_set_state(self, attr_id, attr_name, value):
         """Set the state."""
-        self._state = bool(state)
-        self.async_schedule_update_ha_state()
+        if self.SENSOR_ATTR is None or self.SENSOR_ATTR != attr_name:
+            return
+        self._state = bool(value)
+        self.async_write_ha_state()
 
     async def async_update(self):
         """Attempt to retrieve on off state from the binary sensor."""
         await super().async_update()
         attribute = getattr(self._channel, "value_attribute", "on_off")
-        self._state = await self._channel.get_attribute_value(attribute)
+        attr_value = await self._channel.get_attribute_value(attribute)
+        if attr_value is not None:
+            self._state = attr_value
 
 
 @STRICT_MATCH(channel_names=CHANNEL_ACCELEROMETER)
 class Accelerometer(BinarySensor):
     """ZHA BinarySensor."""
 
+    SENSOR_ATTR = "acceleration"
     DEVICE_CLASS = DEVICE_CLASS_MOVING
 
 
@@ -149,6 +132,7 @@ class Accelerometer(BinarySensor):
 class Occupancy(BinarySensor):
     """ZHA BinarySensor."""
 
+    SENSOR_ATTR = "occupancy"
     DEVICE_CLASS = DEVICE_CLASS_OCCUPANCY
 
 
@@ -156,6 +140,7 @@ class Occupancy(BinarySensor):
 class Opening(BinarySensor):
     """ZHA BinarySensor."""
 
+    SENSOR_ATTR = "on_off"
     DEVICE_CLASS = DEVICE_CLASS_OPENING
 
 
@@ -163,6 +148,8 @@ class Opening(BinarySensor):
 class IASZone(BinarySensor):
     """ZHA IAS BinarySensor."""
 
+    SENSOR_ATTR = "zone_status"
+
     async def get_device_class(self) -> None:
         """Get the HA device class from the channel."""
         zone_type = await self._channel.get_attribute_value("zone_type")
