@@ -1,16 +1,11 @@
-"""
-Lighting channels module for Zigbee Home Automation.
-
-For more details about this component, please refer to the documentation at
-https://home-assistant.io/integrations/zha/
-"""
+"""Lighting channels module for Zigbee Home Automation."""
 import logging
 
 import zigpy.zcl.clusters.lighting as lighting
 
-from . import ZigbeeChannel
-from .. import registries
+from .. import registries, typing as zha_typing
 from ..const import REPORT_CONFIG_DEFAULT
+from .base import ZigbeeChannel
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -38,9 +33,11 @@ class ColorChannel(ZigbeeChannel):
         {"attr": "color_temperature", "config": REPORT_CONFIG_DEFAULT},
     )
 
-    def __init__(self, cluster, device):
+    def __init__(
+        self, cluster: zha_typing.ZigpyClusterType, ch_pool: zha_typing.ChannelPoolType
+    ) -> None:
         """Initialize ColorChannel."""
-        super().__init__(cluster, device)
+        super().__init__(cluster, ch_pool)
         self._color_capabilities = None
 
     def get_color_capabilities(self):
@@ -55,9 +52,8 @@ class ColorChannel(ZigbeeChannel):
     async def async_initialize(self, from_cache):
         """Initialize channel."""
         await self.fetch_color_capabilities(True)
-        await self.get_attribute_value("color_temperature", from_cache=from_cache)
-        await self.get_attribute_value("current_x", from_cache=from_cache)
-        await self.get_attribute_value("current_y", from_cache=from_cache)
+        attributes = ["color_temperature", "current_x", "current_y"]
+        await self.get_attributes(attributes, from_cache=from_cache)
 
     async def fetch_color_capabilities(self, from_cache):
         """Get the color configuration."""
@@ -75,7 +71,7 @@ class ColorChannel(ZigbeeChannel):
                 "color_temperature", from_cache=from_cache
             )
 
-            if result is not self.UNSUPPORTED_ATTRIBUTE:
+            if result is not None and result is not self.UNSUPPORTED_ATTRIBUTE:
                 capabilities |= self.CAPABILITIES_COLOR_TEMP
         self._color_capabilities = capabilities
         await super().async_initialize(from_cache)
