@@ -1,15 +1,10 @@
-"""
-Lightlink channels module for Zigbee Home Automation.
-
-For more details about this component, please refer to the documentation at
-https://home-assistant.io/integrations/zha/
-"""
+"""Lightlink channels module for Zigbee Home Automation."""
 import logging
 
 import zigpy.zcl.clusters.lightlink as lightlink
 
-from . import ZigbeeChannel
 from .. import registries
+from .base import ZigbeeChannel
 
 _LOGGER = logging.getLogger(__name__)
 
