@@ -1,15 +1,10 @@
-"""
-Protocol channels module for Zigbee Home Automation.
-
-For more details about this component, please refer to the documentation at
-https://home-assistant.io/integrations/zha/
-"""
+"""Protocol channels module for Zigbee Home Automation."""
 import logging
 
 import zigpy.zcl.clusters.protocol as protocol
 
 from .. import registries
-from ..channels import ZigbeeChannel
+from .base import ZigbeeChannel
 
 _LOGGER = logging.getLogger(__name__)
 
