@@ -1,13 +1,9 @@
-"""
-Device for Zigbee Home Automation.
-
-For more details about this component, please refer to the documentation at
-https://home-assistant.io/integrations/zha/
-"""
+"""Device for Zigbee Home Automation."""
 import asyncio
 from datetime import timedelta
 from enum import Enum
 import logging
+import random
 import time
 
 from zigpy import types
@@ -23,8 +19,9 @@ from homeassistant.helpers.dispatcher import (
     async_dispatcher_send,
 )
 from homeassistant.helpers.event import async_track_time_interval
+from homeassistant.helpers.typing import HomeAssistantType
 
-from .channels import EventRelayChannel
+from . import channels, typing as zha_typing
 from .const import (
     ATTR_ARGS,
     ATTR_ATTRIBUTE,
@@ -47,14 +44,13 @@ from .const import (
     ATTR_QUIRK_CLASS,
     ATTR_RSSI,
     ATTR_VALUE,
-    CHANNEL_BASIC,
-    CHANNEL_POWER_CONFIGURATION,
-    CHANNEL_ZDO,
     CLUSTER_COMMAND_SERVER,
     CLUSTER_COMMANDS_CLIENT,
     CLUSTER_COMMANDS_SERVER,
     CLUSTER_TYPE_IN,
     CLUSTER_TYPE_OUT,
+    EFFECT_DEFAULT_VARIANT,
+    EFFECT_OKAY,
     POWER_BATTERY_OR_UNKNOWN,
     POWER_MAINS_POWERED,
     SIGNAL_AVAILABLE,
@@ -65,8 +61,9 @@ from .const import (
 from .helpers import LogMixin
 
 _LOGGER = logging.getLogger(__name__)
-_KEEP_ALIVE_INTERVAL = 7200
-_UPDATE_ALIVE_INTERVAL = timedelta(seconds=60)
+_CONSIDER_UNAVAILABLE_MAINS = 60 * 60 * 2  # 2 hours
+_CONSIDER_UNAVAILABLE_BATTERY = 60 * 60 * 6  # 6 hours
+_UPDATE_ALIVE_INTERVAL = (60, 90)
 _CHECKIN_GRACE_PERIODS = 2
 
 
@@ -80,19 +77,21 @@ class DeviceStatus(Enum):
 class ZHADevice(LogMixin):
     """ZHA Zigbee device object."""
 
-    def __init__(self, hass, zigpy_device, zha_gateway):
+    def __init__(
+        self,
+        hass: HomeAssistantType,
+        zigpy_device: zha_typing.ZigpyDeviceType,
+        zha_gateway: zha_typing.ZhaGatewayType,
+    ):
         """Initialize the gateway."""
         self.hass = hass
         self._zigpy_device = zigpy_device
         self._zha_gateway = zha_gateway
-        self.cluster_channels = {}
-        self._relay_channels = {}
-        self._all_channels = []
         self._available = False
         self._available_signal = "{}_{}_{}".format(
             self.name, self.ieee, SIGNAL_AVAILABLE
         )
-        self._checkins_missed_count = 2
+        self._checkins_missed_count = 0
         self._unsub = async_dispatcher_connect(
             self.hass, self._available_signal, self.async_initialize
         )
@@ -101,11 +100,17 @@ class ZHADevice(LogMixin):
             self._zigpy_device.__class__.__module__,
             self._zigpy_device.__class__.__name__,
         )
-        self._available_check = async_track_time_interval(
-            self.hass, self._check_available, _UPDATE_ALIVE_INTERVAL
+        if self.is_mains_powered:
+            self._consider_unavailable_time = _CONSIDER_UNAVAILABLE_MAINS
+        else:
+            self._consider_unavailable_time = _CONSIDER_UNAVAILABLE_BATTERY
+        keep_alive_interval = random.randint(*_UPDATE_ALIVE_INTERVAL)
+        self._cancel_available_check = async_track_time_interval(
+            self.hass, self._check_available, timedelta(seconds=keep_alive_interval)
         )
         self._ha_device_id = None
         self.status = DeviceStatus.CREATED
+        self._channels = channels.Channels(self)
 
     @property
     def device_id(self):
@@ -116,6 +121,22 @@ class ZHADevice(LogMixin):
         """Set the HA device registry device id."""
         self._ha_device_id = device_id
 
+    @property
+    def device(self) -> zha_typing.ZigpyDeviceType:
+        """Return underlying Zigpy device."""
+        return self._zigpy_device
+
+    @property
+    def channels(self) -> zha_typing.ChannelsType:
+        """Return ZHA channels."""
+        return self._channels
+
+    @channels.setter
+    def channels(self, value: zha_typing.ChannelsType) -> None:
+        """Channels setter."""
+        assert isinstance(value, channels.Channels)
+        self._channels = value
+
     @property
     def name(self):
         """Return device name."""
@@ -213,16 +234,16 @@ class ZHADevice(LogMixin):
                 if Groups.cluster_id in clusters:
                     return True
 
+    @property
+    def skip_configuration(self):
+        """Return true if the device should not issue configuration related commands."""
+        return self._zigpy_device.skip_configuration
+
     @property
     def gateway(self):
         """Return the gateway for this device."""
         return self._zha_gateway
 
-    @property
-    def all_channels(self):
-        """Return cluster channels and relay channels for device."""
-        return self._all_channels
-
     @property
     def device_automation_triggers(self):
         """Return the device automation triggers for this device."""
@@ -244,32 +265,53 @@ class ZHADevice(LogMixin):
         """Set availability from restore and prevent signals."""
         self._available = available
 
-    def _check_available(self, *_):
+    @classmethod
+    def new(
+        cls,
+        hass: HomeAssistantType,
+        zigpy_dev: zha_typing.ZigpyDeviceType,
+        gateway: zha_typing.ZhaGatewayType,
+        restored: bool = False,
+    ):
+        """Create new device."""
+        zha_dev = cls(hass, zigpy_dev, gateway)
+        zha_dev.channels = channels.Channels.new(zha_dev)
+        return zha_dev
+
+    async def _check_available(self, *_):
         if self.last_seen is None:
             self.update_available(False)
-        else:
-            difference = time.time() - self.last_seen
-            if difference > _KEEP_ALIVE_INTERVAL:
-                if self._checkins_missed_count < _CHECKIN_GRACE_PERIODS:
-                    self._checkins_missed_count += 1
-                    if (
-                        CHANNEL_BASIC in self.cluster_channels
-                        and self.manufacturer != "LUMI"
-                    ):
-                        self.debug(
-                            "Attempting to checkin with device - missed checkins: %s",
-                            self._checkins_missed_count,
-                        )
-                        self.hass.async_create_task(
-                            self.cluster_channels[CHANNEL_BASIC].get_attribute_value(
-                                ATTR_MANUFACTURER, from_cache=False
-                            )
-                        )
-                else:
-                    self.update_available(False)
-            else:
-                self.update_available(True)
-                self._checkins_missed_count = 0
+            return
+
+        difference = time.time() - self.last_seen
+        if difference < self._consider_unavailable_time:
+            self.update_available(True)
+            self._checkins_missed_count = 0
+            return
+
+        if (
+            self._checkins_missed_count >= _CHECKIN_GRACE_PERIODS
+            or self.manufacturer == "LUMI"
+            or not self._channels.pools
+        ):
+            self.update_available(False)
+            return
+
+        self._checkins_missed_count += 1
+        self.debug(
+            "Attempting to checkin with device - missed checkins: %s",
+            self._checkins_missed_count,
+        )
+        try:
+            pool = self._channels.pools[0]
+            basic_ch = pool.all_channels[f"{pool.id}:0x0000"]
+        except KeyError:
+            self.debug("does not have a mandatory basic cluster")
+            self.update_available(False)
+            return
+        res = await basic_ch.get_attribute_value(ATTR_MANUFACTURER, from_cache=False)
+        if res is not None:
+            self._checkins_missed_count = 0
 
     def update_available(self, available):
         """Set sensor availability."""
@@ -304,112 +346,32 @@ class ZHADevice(LogMixin):
             ATTR_DEVICE_TYPE: self.device_type,
         }
 
-    def add_cluster_channel(self, cluster_channel):
-        """Add cluster channel to device."""
-        # only keep 1 power configuration channel
-        if (
-            cluster_channel.name is CHANNEL_POWER_CONFIGURATION
-            and CHANNEL_POWER_CONFIGURATION in self.cluster_channels
-        ):
-            return
-
-        if isinstance(cluster_channel, EventRelayChannel):
-            self._relay_channels[cluster_channel.unique_id] = cluster_channel
-            self._all_channels.append(cluster_channel)
-        else:
-            self.cluster_channels[cluster_channel.name] = cluster_channel
-            self._all_channels.append(cluster_channel)
-
-    def get_channels_to_configure(self):
-        """Get a deduped list of channels for configuration.
-
-        This goes through all channels and gets a unique list of channels to
-        configure. It first assembles a unique list of channels that are part
-        of entities while stashing relay channels off to the side. It then
-        takse the stashed relay channels and adds them to the list of channels
-        that will be returned if there isn't a channel in the list for that
-        cluster already. This is done to ensure each cluster is only configured
-        once.
-        """
-        channel_keys = []
-        channels = []
-        relay_channels = self._relay_channels.values()
-
-        def get_key(channel):
-            channel_key = "ZDO"
-            if hasattr(channel.cluster, "cluster_id"):
-                channel_key = "{}_{}".format(
-                    channel.cluster.endpoint.endpoint_id, channel.cluster.cluster_id
-                )
-            return channel_key
-
-        # first we get all unique non event channels
-        for channel in self.all_channels:
-            c_key = get_key(channel)
-            if c_key not in channel_keys and channel not in relay_channels:
-                channel_keys.append(c_key)
-                channels.append(channel)
-
-        # now we get event channels that still need their cluster configured
-        for channel in relay_channels:
-            channel_key = get_key(channel)
-            if channel_key not in channel_keys:
-                channel_keys.append(channel_key)
-                channels.append(channel)
-        return channels
-
     async def async_configure(self):
         """Configure the device."""
         self.debug("started configuration")
-        await self._execute_channel_tasks(
-            self.get_channels_to_configure(), "async_configure"
-        )
+        await self._channels.async_configure()
         self.debug("completed configuration")
         entry = self.gateway.zha_storage.async_create_or_update(self)
         self.debug("stored in registry: %s", entry)
 
+        if self._channels.identify_ch is not None:
+            await self._channels.identify_ch.trigger_effect(
+                EFFECT_OKAY, EFFECT_DEFAULT_VARIANT
+            )
+
     async def async_initialize(self, from_cache=False):
         """Initialize channels."""
         self.debug("started initialization")
-        await self._execute_channel_tasks(
-            self.all_channels, "async_initialize", from_cache
-        )
+        await self._channels.async_initialize(from_cache)
         self.debug("power source: %s", self.power_source)
         self.status = DeviceStatus.INITIALIZED
         self.debug("completed initialization")
 
-    async def _execute_channel_tasks(self, channels, task_name, *args):
-        """Gather and execute a set of CHANNEL tasks."""
-        channel_tasks = []
-        semaphore = asyncio.Semaphore(3)
-        zdo_task = None
-        for channel in channels:
-            if channel.name == CHANNEL_ZDO:
-                if zdo_task is None:  # We only want to do this once
-                    zdo_task = self._async_create_task(
-                        semaphore, channel, task_name, *args
-                    )
-            else:
-                channel_tasks.append(
-                    self._async_create_task(semaphore, channel, task_name, *args)
-                )
-        if zdo_task is not None:
-            await zdo_task
-        await asyncio.gather(*channel_tasks)
-
-    async def _async_create_task(self, semaphore, channel, func_name, *args):
-        """Configure a single channel on this device."""
-        try:
-            async with semaphore:
-                await getattr(channel, func_name)(*args)
-                channel.debug("channel: '%s' stage succeeded", func_name)
-        except Exception as ex:  # pylint: disable=broad-except
-            channel.warning("channel: '%s' stage failed ex: %s", func_name, ex)
-
     @callback
-    def async_unsub_dispatcher(self):
-        """Unsubscribe the dispatcher."""
+    def async_cleanup_handles(self) -> None:
+        """Unsubscribe the dispatchers and timers."""
         self._unsub()
+        self._cancel_available_check()
 
     @callback
     def async_update_last_seen(self, last_seen):
