@@ -14,12 +14,13 @@ from homeassistant.components.fan import (
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 
+from .core import discovery
 from .core.const import (
     CHANNEL_FAN,
     DATA_ZHA,
     DATA_ZHA_DISPATCHERS,
+    SIGNAL_ADD_ENTITIES,
     SIGNAL_ATTR_UPDATED,
-    ZHA_DISCOVERY_NEW,
 )
 from .core.registries import ZHA_ENTITIES
 from .entity import ZhaEntity
@@ -52,41 +53,17 @@ STRICT_MATCH = functools.partial(ZHA_ENTITIES.strict_match, DOMAIN)
 
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up the Zigbee Home Automation fan from config entry."""
-
-    async def async_discover(discovery_info):
-        await _async_setup_entities(
-            hass, config_entry, async_add_entities, [discovery_info]
-        )
+    entities_to_create = hass.data[DATA_ZHA][DOMAIN]
 
     unsub = async_dispatcher_connect(
-        hass, ZHA_DISCOVERY_NEW.format(DOMAIN), async_discover
+        hass,
+        SIGNAL_ADD_ENTITIES,
+        functools.partial(
+            discovery.async_add_entities, async_add_entities, entities_to_create
+        ),
     )
     hass.data[DATA_ZHA][DATA_ZHA_DISPATCHERS].append(unsub)
 
-    fans = hass.data.get(DATA_ZHA, {}).get(DOMAIN)
-    if fans is not None:
-        await _async_setup_entities(
-            hass, config_entry, async_add_entities, fans.values()
-        )
-        del hass.data[DATA_ZHA][DOMAIN]
-
-
-async def _async_setup_entities(
-    hass, config_entry, async_add_entities, discovery_infos
-):
-    """Set up the ZHA fans."""
-    entities = []
-    for discovery_info in discovery_infos:
-        zha_dev = discovery_info["zha_device"]
-        channels = discovery_info["channels"]
-
-        entity = ZHA_ENTITIES.get_entity(DOMAIN, zha_dev, channels, ZhaFan)
-        if entity:
-            entities.append(entity(**discovery_info))
-
-    if entities:
-        async_add_entities(entities, update_before_add=True)
-
 
 @STRICT_MATCH(channel_names=CHANNEL_FAN)
 class ZhaFan(ZhaEntity, FanEntity):
@@ -137,10 +114,10 @@ class ZhaFan(ZhaEntity, FanEntity):
         return self.state_attributes
 
     @callback
-    def async_set_state(self, state):
+    def async_set_state(self, attr_id, attr_name, value):
         """Handle state update from channel."""
-        self._state = VALUE_TO_SPEED.get(state, self._state)
-        self.async_schedule_update_ha_state()
+        self._state = VALUE_TO_SPEED.get(value, self._state)
+        self.async_write_ha_state()
 
     async def async_turn_on(self, speed: str = None, **kwargs) -> None:
         """Turn the entity on."""
@@ -156,7 +133,7 @@ class ZhaFan(ZhaEntity, FanEntity):
     async def async_set_speed(self, speed: str) -> None:
         """Set the speed of the fan."""
         await self._fan_channel.async_set_speed(SPEED_TO_VALUE[speed])
-        self.async_set_state(speed)
+        self.async_set_state(0, "fan_mode", speed)
 
     async def async_update(self):
         """Attempt to retrieve on off state from the fan."""
