@@ -27,9 +27,9 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 
 
 def setup_platform(hass, config, add_entities, discovery_info=None):
-    """Set up the ZigBee platform.
+    """Set up the Zigbee platform.
 
-    Uses the 'type' config value to work out which type of ZigBee sensor we're
+    Uses the 'type' config value to work out which type of Zigbee sensor we're
     dealing with and instantiates the relevant classes to handle it.
     """
     typ = config.get(CONF_TYPE)
@@ -37,7 +37,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     try:
         sensor_class, config_class = TYPE_CLASSES[typ]
     except KeyError:
-        _LOGGER.exception("Unknown ZigBee sensor type: %s", typ)
+        _LOGGER.exception("Unknown Zigbee sensor type: %s", typ)
         return
 
     add_entities([sensor_class(hass, config_class(config))], True)
@@ -73,11 +73,11 @@ class ZigBeeTemperatureSensor(Entity):
         except zigbee.ZIGBEE_TX_FAILURE:
             _LOGGER.warning(
                 "Transmission failure when attempting to get sample from "
-                "ZigBee device at address: %s",
+                "Zigbee device at address: %s",
                 hexlify(self._config.address),
             )
         except zigbee.ZIGBEE_EXCEPTION as exc:
-            _LOGGER.exception("Unable to get sample from ZigBee device: %s", exc)
+            _LOGGER.exception("Unable to get sample from Zigbee device: %s", exc)
 
 
 # This must be below the classes to which it refers.
