@@ -39,19 +39,29 @@ from homeassistant.const import (
     CONF_ALIAS,
     CONF_BELOW,
     CONF_CONDITION,
+    CONF_CONTINUE_ON_TIMEOUT,
+    CONF_DELAY,
     CONF_DEVICE_ID,
     CONF_DOMAIN,
     CONF_ENTITY_ID,
     CONF_ENTITY_NAMESPACE,
+    CONF_EVENT,
+    CONF_EVENT_DATA,
+    CONF_EVENT_DATA_TEMPLATE,
     CONF_FOR,
     CONF_PLATFORM,
     CONF_SCAN_INTERVAL,
+    CONF_SCENE,
+    CONF_SERVICE,
+    CONF_SERVICE_TEMPLATE,
     CONF_STATE,
     CONF_TIMEOUT,
     CONF_UNIT_SYSTEM_IMPERIAL,
     CONF_UNIT_SYSTEM_METRIC,
     CONF_VALUE_TEMPLATE,
+    CONF_WAIT_TEMPLATE,
     ENTITY_MATCH_ALL,
+    ENTITY_MATCH_NONE,
     SUN_EVENT_SUNRISE,
     SUN_EVENT_SUNSET,
     TEMP_CELSIUS,
@@ -231,7 +241,9 @@ def entity_ids(value: Union[str, List]) -> List[str]:
     return [entity_id(ent_id) for ent_id in value]
 
 
-comp_entity_ids = vol.Any(vol.All(vol.Lower, ENTITY_MATCH_ALL), entity_ids)
+comp_entity_ids = vol.Any(
+    vol.All(vol.Lower, vol.Any(ENTITY_MATCH_ALL, ENTITY_MATCH_NONE)), entity_ids
+)
 
 
 def entity_domain(domain: str) -> Callable[[Any], str]:
@@ -399,7 +411,20 @@ def service(value: Any) -> str:
     raise vol.Invalid(f"Service {value} does not match format <domain>.<name>")
 
 
-def schema_with_slug_keys(value_schema: Union[T, Callable]) -> Callable:
+def slug(value: Any) -> str:
+    """Validate value is a valid slug."""
+    if value is None:
+        raise vol.Invalid("Slug should not be None")
+    str_value = str(value)
+    slg = util_slugify(str_value)
+    if str_value == slg:
+        return str_value
+    raise vol.Invalid(f"invalid slug {value} (try {slg})")
+
+
+def schema_with_slug_keys(
+    value_schema: Union[T, Callable], *, slug_validator: Callable[[Any], str] = slug
+) -> Callable:
     """Ensure dicts have slugs as keys.
 
     Replacement of vol.Schema({cv.slug: value_schema}) to prevent misleading
@@ -413,24 +438,13 @@ def schema_with_slug_keys(value_schema: Union[T, Callable]) -> Callable:
             raise vol.Invalid("expected dictionary")
 
         for key in value.keys():
-            slug(key)
+            slug_validator(key)
 
         return cast(Dict, schema(value))
 
     return verify
 
 
-def slug(value: Any) -> str:
-    """Validate value is a valid slug."""
-    if value is None:
-        raise vol.Invalid("Slug should not be None")
-    str_value = str(value)
-    slg = util_slugify(str_value)
-    if str_value == slg:
-        return str_value
-    raise vol.Invalid(f"invalid slug {value} (try {slg})")
-
-
 def slugify(value: Any) -> str:
     """Coerce a value to a slug."""
     if value is None:
@@ -585,6 +599,25 @@ def ensure_list_csv(value: Any) -> List:
     return ensure_list(value)
 
 
+class multi_select:
+    """Multi select validator returning list of selected values."""
+
+    def __init__(self, options: dict) -> None:
+        """Initialize multi select."""
+        self.options = options
+
+    def __call__(self, selected: list) -> list:
+        """Validate input."""
+        if not isinstance(selected, list):
+            raise vol.Invalid("Not a list")
+
+        for value in selected:
+            if value not in self.options:
+                raise vol.Invalid(f"{value} is not a valid option")
+
+        return selected
+
+
 def deprecated(
     key: str,
     replacement_key: Optional[str] = None,
@@ -682,6 +715,30 @@ def deprecated(
     return validator
 
 
+def key_value_schemas(
+    key: str, value_schemas: Dict[str, vol.Schema]
+) -> Callable[[Any], Dict[str, Any]]:
+    """Create a validator that validates based on a value for specific key.
+
+    This gives better error messages.
+    """
+
+    def key_value_validator(value: Any) -> Dict[str, Any]:
+        if not isinstance(value, dict):
+            raise vol.Invalid("Expected a dictionary")
+
+        key_value = value.get(key)
+
+        if key_value not in value_schemas:
+            raise vol.Invalid(
+                f"Unexpected value for {key}: '{key_value}'. Expected {', '.join(value_schemas)}"
+            )
+
+        return cast(Dict[str, Any], value_schemas[key_value](value))
+
+    return key_value_validator
+
+
 # Validator helpers
 
 
@@ -710,6 +767,9 @@ def custom_serializer(schema: Any) -> Any:
     if schema is positive_time_period_dict:
         return {"type": "positive_time_period_dict"}
 
+    if isinstance(schema, multi_select):
+        return {"type": "multi_select", "options": schema.options}
+
     return voluptuous_serialize.UNSUPPORTED
 
 
@@ -736,7 +796,9 @@ def make_entity_service_schema(
             {
                 **schema,
                 vol.Optional(ATTR_ENTITY_ID): comp_entity_ids,
-                vol.Optional(ATTR_AREA_ID): vol.All(ensure_list, [str]),
+                vol.Optional(ATTR_AREA_ID): vol.Any(
+                    ENTITY_MATCH_NONE, vol.All(ensure_list, [str])
+                ),
             },
             extra=extra,
         ),
@@ -747,9 +809,9 @@ def make_entity_service_schema(
 EVENT_SCHEMA = vol.Schema(
     {
         vol.Optional(CONF_ALIAS): string,
-        vol.Required("event"): string,
-        vol.Optional("event_data"): dict,
-        vol.Optional("event_data_template"): {match_all: template_complex},
+        vol.Required(CONF_EVENT): string,
+        vol.Optional(CONF_EVENT_DATA): dict,
+        vol.Optional(CONF_EVENT_DATA_TEMPLATE): {match_all: template_complex},
     }
 )
 
@@ -757,14 +819,14 @@ SERVICE_SCHEMA = vol.All(
     vol.Schema(
         {
             vol.Optional(CONF_ALIAS): string,
-            vol.Exclusive("service", "service name"): service,
-            vol.Exclusive("service_template", "service name"): template,
+            vol.Exclusive(CONF_SERVICE, "service name"): service,
+            vol.Exclusive(CONF_SERVICE_TEMPLATE, "service name"): template,
             vol.Optional("data"): dict,
             vol.Optional("data_template"): {match_all: template_complex},
             vol.Optional(CONF_ENTITY_ID): comp_entity_ids,
         }
     ),
-    has_at_least_one_key("service", "service_template"),
+    has_at_least_one_key(CONF_SERVICE, CONF_SERVICE_TEMPLATE),
 )
 
 NUMERIC_STATE_CONDITION_SCHEMA = vol.All(
@@ -872,22 +934,25 @@ DEVICE_CONDITION_BASE_SCHEMA = vol.Schema(
 
 DEVICE_CONDITION_SCHEMA = DEVICE_CONDITION_BASE_SCHEMA.extend({}, extra=vol.ALLOW_EXTRA)
 
-CONDITION_SCHEMA: vol.Schema = vol.Any(
-    NUMERIC_STATE_CONDITION_SCHEMA,
-    STATE_CONDITION_SCHEMA,
-    SUN_CONDITION_SCHEMA,
-    TEMPLATE_CONDITION_SCHEMA,
-    TIME_CONDITION_SCHEMA,
-    ZONE_CONDITION_SCHEMA,
-    AND_CONDITION_SCHEMA,
-    OR_CONDITION_SCHEMA,
-    DEVICE_CONDITION_SCHEMA,
+CONDITION_SCHEMA: vol.Schema = key_value_schemas(
+    CONF_CONDITION,
+    {
+        "numeric_state": NUMERIC_STATE_CONDITION_SCHEMA,
+        "state": STATE_CONDITION_SCHEMA,
+        "sun": SUN_CONDITION_SCHEMA,
+        "template": TEMPLATE_CONDITION_SCHEMA,
+        "time": TIME_CONDITION_SCHEMA,
+        "zone": ZONE_CONDITION_SCHEMA,
+        "and": AND_CONDITION_SCHEMA,
+        "or": OR_CONDITION_SCHEMA,
+        "device": DEVICE_CONDITION_SCHEMA,
+    },
 )
 
 _SCRIPT_DELAY_SCHEMA = vol.Schema(
     {
         vol.Optional(CONF_ALIAS): string,
-        vol.Required("delay"): vol.Any(
+        vol.Required(CONF_DELAY): vol.Any(
             vol.All(time_period, positive_timedelta), template, template_complex
         ),
     }
@@ -896,9 +961,9 @@ _SCRIPT_DELAY_SCHEMA = vol.Schema(
 _SCRIPT_WAIT_TEMPLATE_SCHEMA = vol.Schema(
     {
         vol.Optional(CONF_ALIAS): string,
-        vol.Required("wait_template"): template,
+        vol.Required(CONF_WAIT_TEMPLATE): template,
         vol.Optional(CONF_TIMEOUT): vol.All(time_period, positive_timedelta),
-        vol.Optional("continue_on_timeout"): boolean,
+        vol.Optional(CONF_CONTINUE_ON_TIMEOUT): boolean,
     }
 )
 
@@ -908,19 +973,57 @@ DEVICE_ACTION_BASE_SCHEMA = vol.Schema(
 
 DEVICE_ACTION_SCHEMA = DEVICE_ACTION_BASE_SCHEMA.extend({}, extra=vol.ALLOW_EXTRA)
 
-_SCRIPT_SCENE_SCHEMA = vol.Schema({vol.Required("scene"): entity_domain("scene")})
+_SCRIPT_SCENE_SCHEMA = vol.Schema({vol.Required(CONF_SCENE): entity_domain("scene")})
 
-SCRIPT_SCHEMA = vol.All(
-    ensure_list,
-    [
-        vol.Any(
-            SERVICE_SCHEMA,
-            _SCRIPT_DELAY_SCHEMA,
-            _SCRIPT_WAIT_TEMPLATE_SCHEMA,
-            EVENT_SCHEMA,
-            CONDITION_SCHEMA,
-            DEVICE_ACTION_SCHEMA,
-            _SCRIPT_SCENE_SCHEMA,
-        )
-    ],
-)
+SCRIPT_ACTION_DELAY = "delay"
+SCRIPT_ACTION_WAIT_TEMPLATE = "wait_template"
+SCRIPT_ACTION_CHECK_CONDITION = "condition"
+SCRIPT_ACTION_FIRE_EVENT = "event"
+SCRIPT_ACTION_CALL_SERVICE = "call_service"
+SCRIPT_ACTION_DEVICE_AUTOMATION = "device"
+SCRIPT_ACTION_ACTIVATE_SCENE = "scene"
+
+
+def determine_script_action(action: dict) -> str:
+    """Determine action type."""
+    if CONF_DELAY in action:
+        return SCRIPT_ACTION_DELAY
+
+    if CONF_WAIT_TEMPLATE in action:
+        return SCRIPT_ACTION_WAIT_TEMPLATE
+
+    if CONF_CONDITION in action:
+        return SCRIPT_ACTION_CHECK_CONDITION
+
+    if CONF_EVENT in action:
+        return SCRIPT_ACTION_FIRE_EVENT
+
+    if CONF_DEVICE_ID in action:
+        return SCRIPT_ACTION_DEVICE_AUTOMATION
+
+    if CONF_SCENE in action:
+        return SCRIPT_ACTION_ACTIVATE_SCENE
+
+    return SCRIPT_ACTION_CALL_SERVICE
+
+
+ACTION_TYPE_SCHEMAS: Dict[str, Callable[[Any], dict]] = {
+    SCRIPT_ACTION_CALL_SERVICE: SERVICE_SCHEMA,
+    SCRIPT_ACTION_DELAY: _SCRIPT_DELAY_SCHEMA,
+    SCRIPT_ACTION_WAIT_TEMPLATE: _SCRIPT_WAIT_TEMPLATE_SCHEMA,
+    SCRIPT_ACTION_FIRE_EVENT: EVENT_SCHEMA,
+    SCRIPT_ACTION_CHECK_CONDITION: CONDITION_SCHEMA,
+    SCRIPT_ACTION_DEVICE_AUTOMATION: DEVICE_ACTION_SCHEMA,
+    SCRIPT_ACTION_ACTIVATE_SCENE: _SCRIPT_SCENE_SCHEMA,
+}
+
+
+def script_action(value: Any) -> dict:
+    """Validate a script action."""
+    if not isinstance(value, dict):
+        raise vol.Invalid("expected dictionary")
+
+    return ACTION_TYPE_SCHEMAS[determine_script_action(value)](value)
+
+
+SCRIPT_SCHEMA = vol.All(ensure_list, [script_action])
