@@ -2,7 +2,7 @@
 import asyncio
 from datetime import datetime, timedelta
 import logging
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Awaitable, Dict, List, Optional, Set, cast
 
 from homeassistant.const import EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STOP
 from homeassistant.core import (
@@ -20,9 +20,6 @@ from homeassistant.helpers.json import JSONEncoder
 from homeassistant.helpers.storage import Store
 import homeassistant.util.dt as dt_util
 
-# mypy: allow-untyped-calls, allow-untyped-defs, no-check-untyped-defs
-# mypy: no-warn-return-any
-
 DATA_RESTORE_STATE_TASK = "restore_state_task"
 
 _LOGGER = logging.getLogger(__name__)
@@ -45,7 +42,7 @@ class StoredState:
         self.state = state
         self.last_seen = last_seen
 
-    def as_dict(self) -> Dict:
+    def as_dict(self) -> Dict[str, Any]:
         """Return a dict representation of the stored state."""
         return {"state": self.state.as_dict(), "last_seen": self.last_seen}
 
@@ -104,7 +101,7 @@ class RestoreStateData:
                 load_instance(hass)
             )
 
-        return await task
+        return await cast(Awaitable["RestoreStateData"], task)
 
     def __init__(self, hass: HomeAssistant) -> None:
         """Initialize the restore state data class."""
@@ -174,6 +171,7 @@ class RestoreStateData:
     def async_setup_dump(self, *args: Any) -> None:
         """Set up the restore state listeners."""
 
+        @callback
         def _async_dump_states(*_: Any) -> None:
             self.hass.async_create_task(self.async_dump_states())
 
@@ -210,15 +208,18 @@ class RestoreStateData:
         self.entity_ids.remove(entity_id)
 
 
-def _encode(value):
+def _encode(value: Any) -> Any:
     """Little helper to JSON encode a value."""
     try:
-        return JSONEncoder.default(None, value)
+        return JSONEncoder.default(
+            None,  # type: ignore
+            value,
+        )
     except TypeError:
         return value
 
 
-def _encode_complex(value):
+def _encode_complex(value: Any) -> Any:
     """Recursively encode all values with the JSONEncoder."""
     if isinstance(value, dict):
         return {_encode(key): _encode_complex(value) for key, value in value.items()}
