@@ -7,7 +7,14 @@ from typing import Callable
 import voluptuous as vol
 
 from homeassistant.auth.permissions.const import CAT_ENTITIES, POLICY_CONTROL
-from homeassistant.const import ATTR_AREA_ID, ATTR_ENTITY_ID, ENTITY_MATCH_ALL
+from homeassistant.const import (
+    ATTR_AREA_ID,
+    ATTR_ENTITY_ID,
+    CONF_SERVICE,
+    CONF_SERVICE_TEMPLATE,
+    ENTITY_MATCH_ALL,
+    ENTITY_MATCH_NONE,
+)
 import homeassistant.core as ha
 from homeassistant.exceptions import (
     HomeAssistantError,
@@ -24,8 +31,6 @@ from homeassistant.util.yaml.loader import JSON_TYPE
 
 # mypy: allow-untyped-defs, no-check-untyped-defs
 
-CONF_SERVICE = "service"
-CONF_SERVICE_TEMPLATE = "service_template"
 CONF_SERVICE_ENTITY_ID = "entity_id"
 CONF_SERVICE_DATA = "data"
 CONF_SERVICE_DATA_TEMPLATE = "data_template"
@@ -121,11 +126,25 @@ async def async_extract_entities(hass, entities, service_call, expand_group=True
 
     entity_ids = await async_extract_entity_ids(hass, service_call, expand_group)
 
-    return [
-        entity
-        for entity in entities
-        if entity.available and entity.entity_id in entity_ids
-    ]
+    found = []
+
+    for entity in entities:
+        if entity.entity_id not in entity_ids:
+            continue
+
+        entity_ids.remove(entity.entity_id)
+
+        if not entity.available:
+            continue
+
+        found.append(entity)
+
+    if entity_ids:
+        _LOGGER.warning(
+            "Unable to find referenced entities %s", ", ".join(sorted(entity_ids))
+        )
+
+    return found
 
 
 @bind_hass
@@ -137,12 +156,15 @@ async def async_extract_entity_ids(hass, service_call, expand_group=True):
     entity_ids = service_call.data.get(ATTR_ENTITY_ID)
     area_ids = service_call.data.get(ATTR_AREA_ID)
 
-    if not entity_ids and not area_ids:
-        return []
-
     extracted = set()
 
-    if entity_ids:
+    if entity_ids in (None, ENTITY_MATCH_NONE) and area_ids in (
+        None,
+        ENTITY_MATCH_NONE,
+    ):
+        return extracted
+
+    if entity_ids and entity_ids != ENTITY_MATCH_NONE:
         # Entity ID attr can be a list or a string
         if isinstance(entity_ids, str):
             entity_ids = [entity_ids]
@@ -152,7 +174,7 @@ async def async_extract_entity_ids(hass, service_call, expand_group=True):
 
         extracted.update(entity_ids)
 
-    if area_ids:
+    if area_ids and area_ids != ENTITY_MATCH_NONE:
         if isinstance(area_ids, str):
             area_ids = [area_ids]
 
@@ -294,16 +316,15 @@ async def entity_service_call(hass, platforms, func, call, required_features=Non
 
     # Check the permissions
 
-    # A list with for each platform in platforms a list of entities to call
-    # the service on.
-    platforms_entities = []
+    # A list with entities to call the service on.
+    entity_candidates = []
 
     if entity_perms is None:
         for platform in platforms:
             if target_all_entities:
-                platforms_entities.append(list(platform.entities.values()))
+                entity_candidates.extend(platform.entities.values())
             else:
-                platforms_entities.append(
+                entity_candidates.extend(
                     [
                         entity
                         for entity in platform.entities.values()
@@ -315,7 +336,7 @@ async def entity_service_call(hass, platforms, func, call, required_features=Non
         # If we target all entities, we will select all entities the user
         # is allowed to control.
         for platform in platforms:
-            platforms_entities.append(
+            entity_candidates.extend(
                 [
                     entity
                     for entity in platform.entities.values()
@@ -340,29 +361,20 @@ async def entity_service_call(hass, platforms, func, call, required_features=Non
 
                 platform_entities.append(entity)
 
-            platforms_entities.append(platform_entities)
+            entity_candidates.extend(platform_entities)
 
-    tasks = [
-        _handle_service_platform_call(
-            hass, func, data, entities, call.context, required_features
-        )
-        for platform, entities in zip(platforms, platforms_entities)
-    ]
+    if not target_all_entities:
+        for entity in entity_candidates:
+            entity_ids.remove(entity.entity_id)
 
-    if tasks:
-        done, pending = await asyncio.wait(tasks)
-        assert not pending
-        for future in done:
-            future.result()  # pop exception if have
+        if entity_ids:
+            _LOGGER.warning(
+                "Unable to find referenced entities %s", ", ".join(sorted(entity_ids))
+            )
 
+    entities = []
 
-async def _handle_service_platform_call(
-    hass, func, data, entities, context, required_features
-):
-    """Handle a function call."""
-    tasks = []
-
-    for entity in entities:
+    for entity in entity_candidates:
         if not entity.available:
             continue
 
@@ -372,27 +384,33 @@ async def _handle_service_platform_call(
         ):
             continue
 
-        entity.async_set_context(context)
+        entities.append(entity)
 
-        if isinstance(func, str):
-            result = hass.async_add_job(partial(getattr(entity, func), **data))
-        else:
-            result = hass.async_add_job(func, entity, data)
+    if not entities:
+        return
 
-        # Guard because callback functions do not return a task when passed to async_add_job.
-        if result is not None:
-            result = await result
-
-        if asyncio.iscoroutine(result):
-            _LOGGER.error(
-                "Service %s for %s incorrectly returns a coroutine object. Await result instead in service handler. Report bug to integration author.",
-                func,
-                entity.entity_id,
+    done, pending = await asyncio.wait(
+        [
+            entity.async_request_call(
+                _handle_entity_call(hass, entity, func, data, call.context)
             )
-            await result
+            for entity in entities
+        ]
+    )
+    assert not pending
+    for future in done:
+        future.result()  # pop exception if have
 
-        if entity.should_poll:
-            tasks.append(entity.async_update_ha_state(True))
+    tasks = []
+
+    for entity in entities:
+        if not entity.should_poll:
+            continue
+
+        # Context expires if the turn on commands took a long time.
+        # Set context again so it's there when we update
+        entity.async_set_context(call.context)
+        tasks.append(entity.async_update_ha_state(True))
 
     if tasks:
         done, pending = await asyncio.wait(tasks)
@@ -401,6 +419,28 @@ async def _handle_service_platform_call(
             future.result()  # pop exception if have
 
 
+async def _handle_entity_call(hass, entity, func, data, context):
+    """Handle calling service method."""
+    entity.async_set_context(context)
+
+    if isinstance(func, str):
+        result = hass.async_add_job(partial(getattr(entity, func), **data))
+    else:
+        result = hass.async_add_job(func, entity, data)
+
+    # Guard because callback functions do not return a task when passed to async_add_job.
+    if result is not None:
+        await result
+
+    if asyncio.iscoroutine(result):
+        _LOGGER.error(
+            "Service %s for %s incorrectly returns a coroutine object. Await result instead in service handler. Report bug to integration author.",
+            func,
+            entity.entity_id,
+        )
+        await result
+
+
 @bind_hass
 @ha.callback
 def async_register_admin_service(
@@ -421,7 +461,9 @@ def async_register_admin_service(
             if not user.is_admin:
                 raise Unauthorized(context=call.context)
 
-        await hass.async_add_job(service_func, call)
+        result = hass.async_add_job(service_func, call)
+        if result is not None:
+            await result
 
     hass.services.async_register(domain, service, admin_handler, schema)
 
@@ -442,6 +484,7 @@ def verify_domain_control(hass: HomeAssistantType, domain: str) -> Callable:
                 return await service_handler(call)
 
             user = await hass.auth.async_get_user(call.context.user_id)
+
             if user is None:
                 raise UnknownUser(
                     context=call.context,
@@ -450,14 +493,12 @@ def verify_domain_control(hass: HomeAssistantType, domain: str) -> Callable:
                 )
 
             reg = await hass.helpers.entity_registry.async_get_registry()
-            entities = [
-                entity.entity_id
-                for entity in reg.entities.values()
-                if entity.platform == domain
-            ]
 
-            for entity_id in entities:
-                if user.permissions.check_entity(entity_id, POLICY_CONTROL):
+            for entity in reg.entities.values():
+                if entity.platform != domain:
+                    continue
+
+                if user.permissions.check_entity(entity.entity_id, POLICY_CONTROL):
                     return await service_handler(call)
 
             raise Unauthorized(
