@@ -3,11 +3,12 @@ import logging
 from typing import Any, Dict, Iterable, Optional
 
 from homeassistant.loader import (
+    async_get_config_flows,
     async_get_integration,
     bind_hass,
-    async_get_config_flows,
 )
 from homeassistant.util.json import load_json
+
 from .typing import HomeAssistantType
 
 _LOGGER = logging.getLogger(__name__)
@@ -52,7 +53,7 @@ async def component_translation_file(
     assert integration is not None, domain
 
     if is_platform:
-        filename = "{}.{}.json".format(parts[0], language)
+        filename = f"{parts[0]}.{language}.json"
         return str(integration.file_path / ".translations" / filename)
 
     # If it's a component that is just one file, we don't support translations
