@@ -1,8 +1,8 @@
 """Color util methods."""
-import math
 import colorsys
+import math
+from typing import List, Optional, Tuple
 
-from typing import Tuple, List, Optional
 import attr
 
 # Official CSS3 colors from w3.org:
