@@ -1,35 +1,37 @@
 """Unit system helper class and methods."""
 
 import logging
-from typing import Optional
 from numbers import Number
+from typing import Optional
 
 from homeassistant.const import (
-    TEMP_CELSIUS,
-    TEMP_FAHRENHEIT,
-    LENGTH_MILES,
+    CONF_UNIT_SYSTEM_IMPERIAL,
+    CONF_UNIT_SYSTEM_METRIC,
+    LENGTH,
     LENGTH_KILOMETERS,
-    PRESSURE_PA,
-    PRESSURE_PSI,
-    VOLUME_LITERS,
-    VOLUME_GALLONS,
+    LENGTH_MILES,
+    MASS,
     MASS_GRAMS,
     MASS_KILOGRAMS,
     MASS_OUNCES,
     MASS_POUNDS,
-    CONF_UNIT_SYSTEM_METRIC,
-    CONF_UNIT_SYSTEM_IMPERIAL,
-    LENGTH,
-    MASS,
     PRESSURE,
-    VOLUME,
+    PRESSURE_PA,
+    PRESSURE_PSI,
+    TEMP_CELSIUS,
+    TEMP_FAHRENHEIT,
     TEMPERATURE,
     UNIT_NOT_RECOGNIZED_TEMPLATE,
+    VOLUME,
+    VOLUME_GALLONS,
+    VOLUME_LITERS,
+)
+from homeassistant.util import (
+    distance as distance_util,
+    pressure as pressure_util,
+    temperature as temperature_util,
+    volume as volume_util,
 )
-from homeassistant.util import temperature as temperature_util
-from homeassistant.util import distance as distance_util
-from homeassistant.util import pressure as pressure_util
-from homeassistant.util import volume as volume_util
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -105,7 +107,7 @@ class UnitSystem:
     def temperature(self, temperature: float, from_unit: str) -> float:
         """Convert the given temperature to this unit system."""
         if not isinstance(temperature, Number):
-            raise TypeError("{} is not a numeric value.".format(str(temperature)))
+            raise TypeError(f"{temperature!s} is not a numeric value.")
 
         # type ignore: https://github.com/python/mypy/issues/7207
         return temperature_util.convert(  # type: ignore
@@ -115,7 +117,7 @@ class UnitSystem:
     def length(self, length: Optional[float], from_unit: str) -> float:
         """Convert the given length to this unit system."""
         if not isinstance(length, Number):
-            raise TypeError("{} is not a numeric value.".format(str(length)))
+            raise TypeError(f"{length!s} is not a numeric value.")
 
         # type ignore: https://github.com/python/mypy/issues/7207
         return distance_util.convert(  # type: ignore
@@ -125,7 +127,7 @@ class UnitSystem:
     def pressure(self, pressure: Optional[float], from_unit: str) -> float:
         """Convert the given pressure to this unit system."""
         if not isinstance(pressure, Number):
-            raise TypeError("{} is not a numeric value.".format(str(pressure)))
+            raise TypeError(f"{pressure!s} is not a numeric value.")
 
         # type ignore: https://github.com/python/mypy/issues/7207
         return pressure_util.convert(  # type: ignore
@@ -135,7 +137,7 @@ class UnitSystem:
     def volume(self, volume: Optional[float], from_unit: str) -> float:
         """Convert the given volume to this unit system."""
         if not isinstance(volume, Number):
-            raise TypeError("{} is not a numeric value.".format(str(volume)))
+            raise TypeError(f"{volume!s} is not a numeric value.")
 
         # type ignore: https://github.com/python/mypy/issues/7207
         return volume_util.convert(  # type: ignore
